/****************************************************************************
 * Rohde & Schwarz CMW Communication tester NB IoT instrument driver include
 * file
 ****************************************************************************/

#ifndef __RSCMWINM_HEADER
#define __RSCMWINM_HEADER

#include "rscore.h"
#include "rscmwinm_attributes.h"
#include "rscmwinm_utility.h"

#include <string.h>
#include <stdlib.h>
#include <stdio.h>

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

/*****************************************************************************
 *- Useful Macros & Constants -----------------------------------------------*
 *****************************************************************************/

#define RSCMWINM_SIMULATION_ID_QUERY      "Rohde&Schwarz,CMW,123456/789,1.0.10"  /* Default definition of ID Query Response for simulation */
#define RSCMWINM_VALID_ID_RESPONSE_STRING "Rohde&Schwarz"      /* Valid response for identification query */
#define RSCMWINM_SIMULATION_OPT_QUERY     ""      /* Simulated response for *OPT? command */

#define RSCMWINM_OPC_TIMEOUT              5000L   /* Maximum time to wait for OPC in milliseconds */
#define MAX_OPC_TIME                   60000L

/****************************************************************************
 *----------------- Instrument Driver Revision Information -----------------*
 ****************************************************************************/

/* Class Driver Identification */

#define RSCMWINM_CLASS_DRIVER_DESCRIPTION           ""
#define RSCMWINM_CLASS_DRIVER_PREFIX                ""
#define RSCMWINM_CLASS_DRIVER_VENDOR                ""
#define RSCMWINM_CLASS_DRIVER_REVISION              ""
#define RSCMWINM_CLASS_SPEC_MAJOR_VERSION           1L    /* Class specification major version */
#define RSCMWINM_CLASS_SPEC_MINOR_VERSION           6L    /* Class specification minor version */

/* Driver Identification */

#define RSCMWINM_SPECIFIC_DRIVER_DESCRIPTION        ""
#define RSCMWINM_SPECIFIC_DRIVER_PREFIX             "RSCMWINM"
#define RSCMWINM_SPECIFIC_DRIVER_LOCATOR            ""
#define RSCMWINM_SPECIFIC_DRIVER_VENDOR             ""
#define RSCMWINM_MAJOR_VERSION                      3L    /* Instrument driver major version          */
#define RSCMWINM_MINOR_VERSION                      8L    /* Instrument driver minor version          */
#define RSCMWINM_MINOR_MINOR_VERSION                200L   /* Instrument driver minor minor version    */

/* Driver Capabilities */

#define RSCMWINM_SUPPORTED_INSTRUMENT_MODELS        ""    /* Instrument driver supported model(s)     */
#define RSCMWINM_GROUP_CAPABILITIES                 ""
#define RSCMWINM_FUNCTION_CAPABILITIES              ""

/****************************************************************************
 *---------------------------- Attribute Defines ---------------------------*
 ****************************************************************************/

    /*- Inherent Instrument Specific Attributes ----------------------------*/

        /* User Options */

#define RSCMW_ATTR_RANGE_CHECK                                           RS_ATTR_RANGE_CHECK                                     /* ViBoolean */
#define RSCMW_ATTR_QUERY_INSTRUMENT_STATUS                               RS_ATTR_QUERY_INSTRUMENT_STATUS                         /* ViBoolean */
#define RSCMW_ATTR_CACHE                                                 RS_ATTR_CACHE                                           /* ViBoolean */
#define RSCMW_ATTR_SIMULATE                                              RS_ATTR_SIMULATE                                        /* ViBoolean */
#define RSCMW_ATTR_RECORD_COERCIONS                                      RS_ATTR_RECORD_COERCIONS                                /* ViBoolean */
#define RSCMW_ATTR_INTERCHANGE_CHECK                                     RS_ATTR_INTERCHANGE_CHECK                               /* ViBoolean */
#define RSCMW_ATTR_SPY                                                   RS_ATTR_SPY                                             /* ViBoolean */
#define RSCMW_ATTR_USE_SPECIFIC_SIMULATION                               RS_ATTR_USE_SPECIFIC_SIMULATION                         /* ViBoolean */

        /* Class Driver Identification */

#define RSCMW_ATTR_CLASS_DRIVER_DESCRIPTION                              RS_ATTR_CLASS_DRIVER_DESCRIPTION                        /* ViString, read-only */
#define RSCMW_ATTR_CLASS_DRIVER_PREFIX                                   RS_ATTR_CLASS_DRIVER_PREFIX                             /* ViString, read-only */
#define RSCMW_ATTR_CLASS_DRIVER_VENDOR                                   RS_ATTR_CLASS_DRIVER_VENDOR                             /* ViString, read-only */
#define RSCMW_ATTR_CLASS_DRIVER_REVISION                                 RS_ATTR_CLASS_DRIVER_REVISION                           /* ViString, read-only */
#define RSCMW_ATTR_CLASS_DRIVER_CLASS_SPEC_MAJOR_VERSION                 RS_ATTR_CLASS_DRIVER_CLASS_SPEC_MAJOR_VERSION           /* ViInt32,  read-only */
#define RSCMW_ATTR_CLASS_DRIVER_CLASS_SPEC_MINOR_VERSION                 RS_ATTR_CLASS_DRIVER_CLASS_SPEC_MINOR_VERSION           /* ViInt32,  read-only */

        /* Driver Identification */

#define RSCMW_ATTR_SPECIFIC_DRIVER_DESCRIPTION                           RS_ATTR_SPECIFIC_DRIVER_DESCRIPTION                     /* ViString, read-only */
#define RSCMW_ATTR_SPECIFIC_DRIVER_PREFIX                                RS_ATTR_SPECIFIC_DRIVER_PREFIX                          /* ViString, read-only */
#define RSCMW_ATTR_SPECIFIC_DRIVER_LOCATOR                               RS_ATTR_SPECIFIC_DRIVER_LOCATOR                         /* ViString, read-only */
#define RSCMW_ATTR_SPECIFIC_DRIVER_VENDOR                                RS_ATTR_SPECIFIC_DRIVER_VENDOR                          /* ViString, read-only */
#define RSCMW_ATTR_SPECIFIC_DRIVER_REVISION                              RS_ATTR_SPECIFIC_DRIVER_REVISION                        /* ViString, read-only */
#define RSCMW_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION              RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION        /* ViInt32,  read-only */
#define RSCMW_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION              RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION        /* ViInt32,  read-only */

        /* Driver Capabilities */

#define RSCMW_ATTR_SUPPORTED_INSTRUMENT_MODELS                           RS_ATTR_SUPPORTED_INSTRUMENT_MODELS                     /* ViString, read-only */
#define RSCMW_ATTR_GROUP_CAPABILITIES                                    RS_ATTR_GROUP_CAPABILITIES                              /* ViString, read-only */
#define RSCMW_ATTR_FUNCTION_CAPABILITIES                                 RS_ATTR_FUNCTION_CAPABILITIES                           /* ViString, read-only */
#define RSCMW_ATTR_CHANNEL_COUNT                                         RS_ATTR_CHANNEL_COUNT                                   /* ViInt32,  read-only */

        /* Driver Setup */

#define RSCMW_ATTR_DRIVER_SETUP                                          RS_ATTR_DRIVER_SETUP                                    /* ViString            */

        /* Instrument Identification */

#define RSCMW_ATTR_INSTRUMENT_MANUFACTURER                               RS_ATTR_INSTRUMENT_MANUFACTURER                         /* ViString, read-only */
#define RSCMW_ATTR_INSTRUMENT_MODEL                                      RS_ATTR_INSTRUMENT_MODEL                                /* ViString, read-only */
#define RSCMW_ATTR_INSTRUMENT_FIRMWARE_REVISION                          RS_ATTR_INSTRUMENT_FIRMWARE_REVISION                    /* ViString, read-only */

        /* Advanced Session Information */

#define RSCMW_ATTR_IO_RESOURCE_DESCRIPTOR                                RS_ATTR_IO_RESOURCE_DESCRIPTOR                          /* ViString, read-only */
#define RSCMW_ATTR_LOGICAL_NAME                                          RS_ATTR_LOGICAL_NAME                                    /* ViString, read-only */

    /*- Instrument-Specific Attributes -------------------------------------*/

/* BEGIN GENERATE */
#define RSCMWINM_ATTR_MEASURE_PROTOCOL_TEST                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 1
#define RSCMWINM_ATTR_ROUTING_SCENARIO                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 2
#define RSCMWINM_ATTR_INPUT_EXTERNAL_ATTENUTATION                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 3
#define RSCMWINM_ATTR_ANALYZER_OPERATING_BAND                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 4
#define RSCMWINM_ATTR_ANALYZER_CENTER_FREQUENCY                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 5
#define RSCMWINM_ATTR_ANALYZER_FREQUENCY_OFFSET                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 6
#define RSCMWINM_ATTR_ANALYZER_EXPECTED_NOMINAL_POWER                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 7
#define RSCMWINM_ATTR_ANALYZER_USER_MARGIN                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 8
#define RSCMWINM_ATTR_ANALYZER_MIXER_LEVEL_OFFSET                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 9
#define RSCMWINM_ATTR_MULTI_EVAL_MEASUREMENT_RESULT_EVM                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 10
#define RSCMWINM_ATTR_MULTI_EVAL_MEASUREMENT_RESULT_MAGNITUDE_ERROR         RS_SPECIFIC_PUBLIC_ATTR_BASE + 11
#define RSCMWINM_ATTR_MULTI_EVAL_MEASUREMENT_RESULT_PHASE_ERROR             RS_SPECIFIC_PUBLIC_ATTR_BASE + 12
#define RSCMWINM_ATTR_MULTI_EVAL_MEASUREMENT_RESULT_INBAND_EMISSIONS        RS_SPECIFIC_PUBLIC_ATTR_BASE + 13
#define RSCMWINM_ATTR_MULTI_EVAL_MEASUREMENT_RESULT_IQ_CONSTELLATION_DIAGRAM RS_SPECIFIC_PUBLIC_ATTR_BASE + 14
#define RSCMWINM_ATTR_MULTI_EVAL_MEASUREMENT_RESULT_TX_MEASUREMENT          RS_SPECIFIC_PUBLIC_ATTR_BASE + 15
#define RSCMWINM_ATTR_MULTI_EVAL_MEASUREMENT_RESULT_SPECTRUM_EMISSION_MASK  RS_SPECIFIC_PUBLIC_ATTR_BASE + 16
#define RSCMWINM_ATTR_MULTI_EVAL_MEASUREMENT_RESULT_ACLR                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 17
#define RSCMWINM_ATTR_MULTI_EVAL_MEASUREMENT_RESULT_POWER_MONITOR           RS_SPECIFIC_PUBLIC_ATTR_BASE + 18
#define RSCMWINM_ATTR_MULTI_EVAL_MEASUREMENT_RESULT_POWER_DYNAMICS          RS_SPECIFIC_PUBLIC_ATTR_BASE + 19
#define RSCMWINM_ATTR_MULTI_EVAL_MEASUREMENT_INIT                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 20
#define RSCMWINM_ATTR_MULTI_EVAL_MEASUREMENT_ABORT                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 21
#define RSCMWINM_ATTR_MULTI_EVAL_MEASUREMENT_STOP                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 22
#define RSCMWINM_ATTR_MULTI_EVAL_MEASUREMENT_TIMEOUT                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 23
#define RSCMWINM_ATTR_MULTI_EVAL_MEASUREMENT_REPETITION_MODE                RS_SPECIFIC_PUBLIC_ATTR_BASE + 24
#define RSCMWINM_ATTR_MULTI_EVAL_MEASUREMENT_STOP_CONDITION                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 25
#define RSCMWINM_ATTR_MULTI_EVAL_MEASUREMENT_MEAS_MODE                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 26
#define RSCMWINM_ATTR_MULTI_EVAL_MEASUREMENT_MEASURE_ON_EXCEPTION           RS_SPECIFIC_PUBLIC_ATTR_BASE + 27
#define RSCMWINM_ATTR_MULTI_EVAL_MEASUREMENT_NUMBER_OF_MEASURE_SLOTS        RS_SPECIFIC_PUBLIC_ATTR_BASE + 28
#define RSCMWINM_ATTR_MULTI_EVAL_MEASUREMENT_SUBCARRIER_SPACING             RS_SPECIFIC_PUBLIC_ATTR_BASE + 29
#define RSCMWINM_ATTR_MULTI_EVAL_MEASUREMENT_NPUSCH_FORMAT                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 30
#define RSCMWINM_ATTR_MULTI_EVAL_MEASUREMENT_NUMBER_OF_RESOURCE_UNITS       RS_SPECIFIC_PUBLIC_ATTR_BASE + 31
#define RSCMWINM_ATTR_MULTI_EVAL_MEASUREMENT_NUMBER_OF_REPETITIONS          RS_SPECIFIC_PUBLIC_ATTR_BASE + 32
#define RSCMWINM_ATTR_MULTI_EVAL_MEASUREMENT_PHYSICAL_CELL_ID               RS_SPECIFIC_PUBLIC_ATTR_BASE + 33
#define RSCMWINM_ATTR_MULTI_EVAL_MEASUREMENT_DELTA_SEQUENCE_SHIFT           RS_SPECIFIC_PUBLIC_ATTR_BASE + 34
#define RSCMWINM_ATTR_MULTI_EVAL_MEASUREMENT_FSR                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 55
#define RSCMWINM_ATTR_MULTI_EVAL_MEASUREMENT_MODULATION_SCHEME              RS_SPECIFIC_PUBLIC_ATTR_BASE + 35
#define RSCMWINM_ATTR_MULTI_EVAL_MEASUREMENT_MODULATION_STATISTIC_COUNT     RS_SPECIFIC_PUBLIC_ATTR_BASE + 36
#define RSCMWINM_ATTR_MULTI_EVAL_MEASUREMENT_SPECTRUM_EMISSION_MASK_STATISTIC_COUNT RS_SPECIFIC_PUBLIC_ATTR_BASE + 37
#define RSCMWINM_ATTR_MULTI_EVAL_MEASUREMENT_SPECTRUM_ACLR_STATISTIC_COUNT  RS_SPECIFIC_PUBLIC_ATTR_BASE + 38
#define RSCMWINM_ATTR_MULTI_EVAL_MEASUREMENT_POWER_STATISTIC_COUNT          RS_SPECIFIC_PUBLIC_ATTR_BASE + 39
#define RSCMWINM_ATTR_MULTI_EVAL_MEASUREMENT_LEADING                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 56
#define RSCMWINM_ATTR_MULTI_EVAL_MEASUREMENT_LAGGING                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 57
#define RSCMWINM_ATTR_MULTI_EVAL_MEASUREMENT_OBW_MODE                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 64
#define RSCMWINM_ATTR_MULTI_EVAL_MEASUREMENT_TRIGGER_SOURCE                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 40
#define RSCMWINM_ATTR_MULTI_EVAL_MEASUREMENT_TRIGGER_SLOPE                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 41
#define RSCMWINM_ATTR_MULTI_EVAL_MEASUREMENT_TRIGGER_THRESHOLD              RS_SPECIFIC_PUBLIC_ATTR_BASE + 42
#define RSCMWINM_ATTR_MULTI_EVAL_MEASUREMENT_TRIGGER_DELAY                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 43
#define RSCMWINM_ATTR_MULTI_EVAL_MEASUREMENT_TRIGGER_TIMEOUT_ENABLED        RS_SPECIFIC_PUBLIC_ATTR_BASE + 44
#define RSCMWINM_ATTR_MULTI_EVAL_MEASUREMENT_TRIGGER_TIMEOUT                RS_SPECIFIC_PUBLIC_ATTR_BASE + 45
#define RSCMWINM_ATTR_MULTI_EVAL_MEASUREMENT_TRIGGER_GAP                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 46
#define RSCMWINM_ATTR_MULTI_EVAL_MEASUREMENT_SPECTRUM_OBW_LIMIT_ENABLED     RS_SPECIFIC_PUBLIC_ATTR_BASE + 47
#define RSCMWINM_ATTR_MULTI_EVAL_MEASUREMENT_SPECTRUM_OBW_LIMIT             RS_SPECIFIC_PUBLIC_ATTR_BASE + 48
#define RSCMWINM_ATTR_MULTI_EVAL_MEASUREMENT_LIST_ENABLED                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 58
#define RSCMWINM_ATTR_MULTI_EVAL_MEASUREMENT_LIST_OFFLINE_MODE_DISABLED     RS_SPECIFIC_PUBLIC_ATTR_BASE + 59
#define RSCMWINM_ATTR_MULTI_EVAL_MEASUREMENT_LIST_OFFLINE_MODE_INDEX        RS_SPECIFIC_PUBLIC_ATTR_BASE + 60
#define RSCMWINM_ATTR_MULTI_EVAL_MEASUREMENT_LIST_CONNECTOR_MODE            RS_SPECIFIC_PUBLIC_ATTR_BASE + 61
#define RSCMWINM_ATTR_MULTI_EVAL_MEASUREMENT_CMWS_CONNECTOR                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 62
#define RSCMWINM_ATTR_MULTI_EVAL_MEASUREMENT_LIST_MODE                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 63
#define RSCMWINM_ATTR_SYSTEM_VERSION                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 49
#define RSCMWINM_ATTR_SYSTEM_ERROR                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 50
#define RSCMWINM_ATTR_SYSTEM_ALL_ERRORS                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 51
#define RSCMWINM_ATTR_SYSTEM_PRESET                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 52
#define RSCMWINM_ATTR_ID_QUERY_RESPONSE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 53
#define RSCMWINM_ATTR_PROCESS_ALL_PREVIOUS_COMMANDS                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 54

// rscmwinm_rngRoutingScenario
#define RSCMWINM_VAL_SCENARIO_SAL                                           0
#define RSCMWINM_VAL_SCENARIO_MAPR                                          1

// rscmwinm_rngRepetitionMode
#define RSCMWINM_VAL_REPETITION_SINGLE                                      0
#define RSCMWINM_VAL_REPETITION_CONT                                        1

// rscmwinm_rngStopCondition
#define RSCMWINM_VAL_NONE                                                   0
#define RSCMWINM_VAL_LIM_FAIL                                               1

// rscmwinm_rngMeasMode
#define RSCMWINM_VAL_MEAS_MODE_NORMAL                                       0
#define RSCMWINM_VAL_MEAS_MODE_MEL_MODE                                     1

// rscmwinm_rngMultiEvalMeasurementSubcarrierSpacing
#define RSCMWINM_VAL_SUBCARRIER_SPACING_3K75                                0
#define RSCMWINM_VAL_SUBCARRIER_SPACING_15K                                 1

// rscmwinm_rngMultiEvalMeasurementNPUSCHFormat
#define RSCMWINM_VAL_NPUSCH_FORMAT_1                                        1
#define RSCMWINM_VAL_NPUSCH_FORMAT_2                                        2

// rscmwinm_rngMultiEvalMeasurementNumberOfResourceUnits
#define RSCMWINM_VAL_RESOURCE_UNITS_1                                       1
#define RSCMWINM_VAL_RESOURCE_UNITS_2                                       2
#define RSCMWINM_VAL_RESOURCE_UNITS_3                                       3
#define RSCMWINM_VAL_RESOURCE_UNITS_4                                       4
#define RSCMWINM_VAL_RESOURCE_UNITS_5                                       5
#define RSCMWINM_VAL_RESOURCE_UNITS_6                                       6
#define RSCMWINM_VAL_RESOURCE_UNITS_8                                       8
#define RSCMWINM_VAL_RESOURCE_UNITS_10                                      10

// rscmwinm_rngMultiEvalMeasurementNumberOfRepetitions
#define RSCMWINM_VAL_REPETITIONS_1                                          0
#define RSCMWINM_VAL_REPETITIONS_2                                          1
#define RSCMWINM_VAL_REPETITIONS_4                                          2
#define RSCMWINM_VAL_REPETITIONS_8                                          3
#define RSCMWINM_VAL_REPETITIONS_16                                         4
#define RSCMWINM_VAL_REPETITIONS_32                                         5
#define RSCMWINM_VAL_REPETITIONS_64                                         6
#define RSCMWINM_VAL_REPETITIONS_128                                        7
#define RSCMWINM_VAL_REPETITIONS_256                                        8
#define RSCMWINM_VAL_REPETITIONS_512                                        9
#define RSCMWINM_VAL_REPETITIONS_1024                                       10
#define RSCMWINM_VAL_REPETITIONS_2048                                       11

// rscmwinm_rngMultiEvalMeasurementModulationScheme
#define RSCMWINM_VAL_MODULATION_SCHEME_BPSK                                 0
#define RSCMWINM_VAL_MODULATION_SCHEME_QPSK                                 1
#define RSCMWINM_VAL_MODULATION_SCHEME_Q16                                  2

// rscmwinm_rngMultiEvalMeasurementTriggerSlope
#define RSCMWINM_VAL_TRIGGER_SLOPE_RISING                                   0
#define RSCMWINM_VAL_TRIGGER_SLOPE_FALLING                                  1

// rscmwinm_rngMEvalListConnector
#define RSCMWINM_MEVAL_LIST_CONNECTOR_GLOBAL                                0
#define RSCMWINM_MEVAL_LIST_CONNECTOR_LIST                                  1

// rscmwinm_rngMEvalListMode
#define RSCMWINM_MEVAL_LIST_MODE_ONCE                                       0
#define RSCMWINM_MEVAL_LIST_MODE_SEGMENT                                    1

// rscmwinm_rngMEvalExclusionPeriod
#define RSCMWINM_VAL_MEVAL_EXCLUSION_PERIOD_OFF                             0
#define RSCMWINM_VAL_MEVAL_EXCLUSION_PERIOD_S1                              1

// rscmwinm_rngBand
#define RSCMWINM_VAL_BAND_UDEF                                              0
#define RSCMWINM_VAL_BAND_OB1                                               1
#define RSCMWINM_VAL_BAND_OB2                                               2
#define RSCMWINM_VAL_BAND_OB3                                               3
#define RSCMWINM_VAL_BAND_OB4                                               4
#define RSCMWINM_VAL_BAND_OB5                                               5
#define RSCMWINM_VAL_BAND_OB7                                               6
#define RSCMWINM_VAL_BAND_OB8                                               7
#define RSCMWINM_VAL_BAND_OB9                                               8
#define RSCMWINM_VAL_BAND_OB10                                              9
#define RSCMWINM_VAL_BAND_OB11                                              10
#define RSCMWINM_VAL_BAND_OB12                                              11
#define RSCMWINM_VAL_BAND_OB13                                              12
#define RSCMWINM_VAL_BAND_OB14                                              13
#define RSCMWINM_VAL_BAND_OB17                                              14
#define RSCMWINM_VAL_BAND_OB18                                              15
#define RSCMWINM_VAL_BAND_OB19                                              16
#define RSCMWINM_VAL_BAND_OB20                                              17
#define RSCMWINM_VAL_BAND_OB21                                              18
#define RSCMWINM_VAL_BAND_OB22                                              19
#define RSCMWINM_VAL_BAND_OB24                                              20
#define RSCMWINM_VAL_BAND_OB25                                              21
#define RSCMWINM_VAL_BAND_OB26                                              22
#define RSCMWINM_VAL_BAND_OB27                                              23
#define RSCMWINM_VAL_BAND_OB28                                              24
#define RSCMWINM_VAL_BAND_OB30                                              25
#define RSCMWINM_VAL_BAND_OB31                                              26
#define RSCMWINM_VAL_BAND_OB65                                              27
#define RSCMWINM_VAL_BAND_OB66                                              28
#define RSCMWINM_VAL_BAND_OB68                                              29
#define RSCMWINM_VAL_BAND_OB70                                              30
#define RSCMWINM_VAL_BAND_OB71                                              31
#define RSCMWINM_VAL_BAND_OB72                                              32
#define RSCMWINM_VAL_BAND_OB73                                              33
#define RSCMWINM_VAL_BAND_OB74                                              34
#define RSCMWINM_VAL_BAND_OB85                                              35

// rscmwinm_rngMEvalMeasCMWSConnector
#define RSCMWINM_VAL_CMWS_CONNECTOR_R11                                     0
#define RSCMWINM_VAL_CMWS_CONNECTOR_R12                                     1
#define RSCMWINM_VAL_CMWS_CONNECTOR_R13                                     2
#define RSCMWINM_VAL_CMWS_CONNECTOR_R14                                     3
#define RSCMWINM_VAL_CMWS_CONNECTOR_R15                                     4
#define RSCMWINM_VAL_CMWS_CONNECTOR_R16                                     5
#define RSCMWINM_VAL_CMWS_CONNECTOR_R17                                     6
#define RSCMWINM_VAL_CMWS_CONNECTOR_R18                                     7
#define RSCMWINM_VAL_CMWS_CONNECTOR_R21                                     8
#define RSCMWINM_VAL_CMWS_CONNECTOR_R22                                     9
#define RSCMWINM_VAL_CMWS_CONNECTOR_R23                                     10
#define RSCMWINM_VAL_CMWS_CONNECTOR_R24                                     11
#define RSCMWINM_VAL_CMWS_CONNECTOR_R25                                     12
#define RSCMWINM_VAL_CMWS_CONNECTOR_R26                                     13
#define RSCMWINM_VAL_CMWS_CONNECTOR_R27                                     14
#define RSCMWINM_VAL_CMWS_CONNECTOR_R28                                     15
#define RSCMWINM_VAL_CMWS_CONNECTOR_R31                                     16
#define RSCMWINM_VAL_CMWS_CONNECTOR_R32                                     17
#define RSCMWINM_VAL_CMWS_CONNECTOR_R33                                     18
#define RSCMWINM_VAL_CMWS_CONNECTOR_R34                                     19
#define RSCMWINM_VAL_CMWS_CONNECTOR_R35                                     20
#define RSCMWINM_VAL_CMWS_CONNECTOR_R36                                     21
#define RSCMWINM_VAL_CMWS_CONNECTOR_R37                                     22
#define RSCMWINM_VAL_CMWS_CONNECTOR_R38                                     23
#define RSCMWINM_VAL_CMWS_CONNECTOR_RA1                                     24
#define RSCMWINM_VAL_CMWS_CONNECTOR_RA2                                     25
#define RSCMWINM_VAL_CMWS_CONNECTOR_RA3                                     26
#define RSCMWINM_VAL_CMWS_CONNECTOR_RA4                                     27
#define RSCMWINM_VAL_CMWS_CONNECTOR_RA5                                     28
#define RSCMWINM_VAL_CMWS_CONNECTOR_RA6                                     29
#define RSCMWINM_VAL_CMWS_CONNECTOR_RA7                                     30
#define RSCMWINM_VAL_CMWS_CONNECTOR_RA8                                     31
#define RSCMWINM_VAL_CMWS_CONNECTOR_RB1                                     32
#define RSCMWINM_VAL_CMWS_CONNECTOR_RB2                                     33
#define RSCMWINM_VAL_CMWS_CONNECTOR_RB3                                     34
#define RSCMWINM_VAL_CMWS_CONNECTOR_RB4                                     35

// rscmwinm_rngMultiEvalMeasurementFSR
#define RSCMWINM_VAL_MEVAL_FSR_LOW                                          0
#define RSCMWINM_VAL_MEVAL_FSR_HIGH                                         1

// rscmwinm_rngOBWMode
#define RSCMWINM_VAL_OBW_MODE_BW99                                          0
#define RSCMWINM_VAL_OBW_MODE_M26                                           1

// rscmwinm_rngSubcarriers
#define RSCMWINM_VAL_SUBCARRIERS_SC1                                        0
#define RSCMWINM_VAL_SUBCARRIERS_SC3                                        1
#define RSCMWINM_VAL_SUBCARRIERS_SC6                                        2
#define RSCMWINM_VAL_SUBCARRIERS_SC12                                       3

//repcap instance
#define RSCMWINM_REPCAP_INSTANCE_I1                                         1
#define RSCMWINM_REPCAP_INSTANCE_I2                                         2
#define RSCMWINM_REPCAP_INSTANCE_I3                                         3
#define RSCMWINM_REPCAP_INSTANCE_I4                                         4
#define RSCMWINM_REPCAP_INSTANCE_I5                                         5
#define RSCMWINM_REPCAP_INSTANCE_I6                                         6
#define RSCMWINM_REPCAP_INSTANCE_I7                                         7
#define RSCMWINM_REPCAP_INSTANCE_I8                                         8
#define RSCMWINM_REPCAP_INSTANCE_I9                                         9
#define RSCMWINM_REPCAP_INSTANCE_I10                                        10
#define RSCMWINM_REPCAP_INSTANCE_I11                                        11
#define RSCMWINM_REPCAP_INSTANCE_I12                                        12
#define RSCMWINM_REPCAP_INSTANCE_I13                                        13
#define RSCMWINM_REPCAP_INSTANCE_I14                                        14
#define RSCMWINM_REPCAP_INSTANCE_I15                                        15
#define RSCMWINM_REPCAP_INSTANCE_I16                                        16
#define RSCMWINM_REPCAP_INSTANCE_I17                                        17
#define RSCMWINM_REPCAP_INSTANCE_I18                                        18
#define RSCMWINM_REPCAP_INSTANCE_I19                                        19
#define RSCMWINM_REPCAP_INSTANCE_I20                                        20
#define RSCMWINM_REPCAP_INSTANCE_I21                                        21
#define RSCMWINM_REPCAP_INSTANCE_I22                                        22
#define RSCMWINM_REPCAP_INSTANCE_I23                                        23
#define RSCMWINM_REPCAP_INSTANCE_I24                                        24
#define RSCMWINM_REPCAP_INSTANCE_I25                                        25
#define RSCMWINM_REPCAP_INSTANCE_I26                                        26
#define RSCMWINM_REPCAP_INSTANCE_I27                                        27
#define RSCMWINM_REPCAP_INSTANCE_I28                                        28
#define RSCMWINM_REPCAP_INSTANCE_I29                                        29
#define RSCMWINM_REPCAP_INSTANCE_I30                                        30
#define RSCMWINM_REPCAP_INSTANCE_I31                                        31
#define RSCMWINM_REPCAP_INSTANCE_I32                                        32
/* END GENERATE */

/*****************************************************************************
 *- Hidden Attribute Declarations -------------------------------------------*
 *****************************************************************************/

#define RSCMWINM_ATTR_OPC_TIMEOUT               (RS_ATTR_OPC_TIMEOUT)           /* ViInt32 */
#define RSCMWINM_ATTR_IO_SESSION                (RS_ATTR_IO_SESSION)            /* ViSession */
#define RSCMWINM_ATTR_OPC_CALLBACK              (RS_ATTR_OPC_CALLBACK)          /* ViAddr */
#define RSCMWINM_ATTR_CHECK_STATUS_CALLBACK     (RS_ATTR_CHECK_STATUS_CALLBACK) /* ViAddr */

/****************************************************************************
 *---------------- Constant definition  ------------------------------------*
 ****************************************************************************/

#define RSCMWINM_VAL_NAV            -1

#define RSCMWINM_VAL_RESULT_CURRENT 0
#define RSCMWINM_VAL_RESULT_AVERAGE 1
#define RSCMWINM_VAL_RESULT_MAX     2
#define RSCMWINM_VAL_RESULT_MIN     3
#define RSCMWINM_VAL_RESULT_EXTREME 4
#define RSCMWINM_VAL_RESULT_SDEV    5

#define RSCMWINM_VAL_ANALYZER_CONNECTOR_RF1C 0
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_RF2C 1
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_RF3C 2
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_RF4C 3
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_RFAC 4
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_RFBC 5
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_R11  6
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_R12  7
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_R13  8
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_R14  9
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_R15  10
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_R16  11
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_R17  12
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_R18  13
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_R21  14
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_R22  15
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_R23  16
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_R24  17
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_R25  18
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_R26  19
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_R27  20
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_R28  21
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_R31  22
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_R32  23
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_R33  24
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_R34  25
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_R35  26
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_R36  27
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_R37  28
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_R38  29
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_R41  30
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_R42  31
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_R43  32
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_R44  33
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_R45  34
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_R46  35
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_R47  36
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_R48  37
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_RA1  38
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_RA2  39
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_RA3  40
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_RA4  41
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_RA5  42
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_RA6  43
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_RA7  44
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_RA8  45
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_RB1  46
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_RB2  47
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_RB3  48
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_RB4  49
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_RB5  50
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_RB6  51
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_RB7  52
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_RB8  53
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_R11C 54
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_R12C 55
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_R13C 56
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_R14C 57
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_R21C 58
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_R22C 59
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_R23C 60
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_R24C 61
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_R31C 62
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_R32C 63
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_R33C 64
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_R34C 65
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_R41C 66
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_R42C 67
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_R43C 68
#define RSCMWINM_VAL_ANALYZER_CONNECTOR_R44C 69

#define RSCMWINM_VAL_ANALYZER_SAL_CONV_RX1  0
#define RSCMWINM_VAL_ANALYZER_SAL_CONV_RX2  1
#define RSCMWINM_VAL_ANALYZER_SAL_CONV_RX3  2
#define RSCMWINM_VAL_ANALYZER_SAL_CONV_RX4  3
#define RSCMWINM_VAL_ANALYZER_SAL_CONV_RX11 4
#define RSCMWINM_VAL_ANALYZER_SAL_CONV_RX12 5
#define RSCMWINM_VAL_ANALYZER_SAL_CONV_RX13 6
#define RSCMWINM_VAL_ANALYZER_SAL_CONV_RX14 7
#define RSCMWINM_VAL_ANALYZER_SAL_CONV_RX21 8
#define RSCMWINM_VAL_ANALYZER_SAL_CONV_RX22 9
#define RSCMWINM_VAL_ANALYZER_SAL_CONV_RX23 10
#define RSCMWINM_VAL_ANALYZER_SAL_CONV_RX24 11
#define RSCMWINM_VAL_ANALYZER_SAL_CONV_RX31 12
#define RSCMWINM_VAL_ANALYZER_SAL_CONV_RX32 13
#define RSCMWINM_VAL_ANALYZER_SAL_CONV_RX33 14
#define RSCMWINM_VAL_ANALYZER_SAL_CONV_RX34 15
#define RSCMWINM_VAL_ANALYZER_SAL_CONV_RX41 16
#define RSCMWINM_VAL_ANALYZER_SAL_CONV_RX42 17
#define RSCMWINM_VAL_ANALYZER_SAL_CONV_RX43 18
#define RSCMWINM_VAL_ANALYZER_SAL_CONV_RX44 19

#define RSCMWINM_VAL_SCENARIO_SAL  0
#define RSCMWINM_VAL_SCENARIO_MAPR 1
#define RSCMWINM_VAL_SCENARIO_CSP  2

#define RSCMWINM_VAL_MOD   0
#define RSCMWINM_VAL_SEM   1
#define RSCMWINM_VAL_ACLR  2
#define RSCMWINM_VAL_POWER 3

#define RSCMWINM_VAL_RES_EVM  0
#define RSCMWINM_VAL_RES_MERR 1
#define RSCMWINM_VAL_RES_PERR 2
#define RSCMWINM_VAL_RES_IEM  3
#define RSCMWINM_VAL_RES_IQ   4
#define RSCMWINM_VAL_RES_TXM  5
#define RSCMWINM_VAL_RES_SEM  6
#define RSCMWINM_VAL_RES_ACLR 7
#define RSCMWINM_VAL_RES_PMON 8
#define RSCMWINM_VAL_RES_PDYN 9

#define RSCMWINM_VAL_STATE_OFF 0
#define RSCMWINM_VAL_STATE_ON  1
#define RSCMWINM_VAL_STATE_VAL 2

#define RSCMWINM_VAL_RES_EVM  0
#define RSCMWINM_VAL_RES_MERR 1
#define RSCMWINM_VAL_RES_PERR 2

#define RSCMWINM_VAL_GSM  0
#define RSCMWINM_VAL_UTRA 1

#define RSCMWINM_VAL_TYPE_RMS  0
#define RSCMWINM_VAL_TYPE_PEAK 1

#define RSCMWINM_VAL_NEGATIVE 0
#define RSCMWINM_VAL_POSITIVE 1

#define RSCMWINM_VAL_START 0
#define RSCMWINM_VAL_END   1

#define RSCMWINM_VAL_NPUSCH_FORMAT_F1 0
#define RSCMWINM_VAL_NPUSCH_FORMAT_F2 1

#define RSCMWINM_VAL_RESOURCE_UNIT_NRU01 0
#define RSCMWINM_VAL_RESOURCE_UNIT_NRU02 1
#define RSCMWINM_VAL_RESOURCE_UNIT_NRU03 2
#define RSCMWINM_VAL_RESOURCE_UNIT_NRU04 3
#define RSCMWINM_VAL_RESOURCE_UNIT_NRU05 4
#define RSCMWINM_VAL_RESOURCE_UNIT_NRU06 5
#define RSCMWINM_VAL_RESOURCE_UNIT_NRU08 6
#define RSCMWINM_VAL_RESOURCE_UNIT_NRU10 7

#define RSCMWINM_VAL_REPETITIONS_1    0
#define RSCMWINM_VAL_REPETITIONS_2    1
#define RSCMWINM_VAL_REPETITIONS_4    2
#define RSCMWINM_VAL_REPETITIONS_8    3
#define RSCMWINM_VAL_REPETITIONS_16   4
#define RSCMWINM_VAL_REPETITIONS_32   5
#define RSCMWINM_VAL_REPETITIONS_64   6
#define RSCMWINM_VAL_REPETITIONS_128  7
#define RSCMWINM_VAL_REPETITIONS_256  8
#define RSCMWINM_VAL_REPETITIONS_512  9
#define RSCMWINM_VAL_REPETITIONS_1024 10
#define RSCMWINM_VAL_REPETITIONS_2056 11

#define RSCMWINM_VAL_RETRIGGER_FLAG_OFF 0
#define RSCMWINM_VAL_RETRIGGER_FLAG_ON  1
#define RSCMWINM_VAL_RETRIGGER_FLAG_IFP 2

/****************************************************************************
 *---------------- Instrument Driver Function Declarations -----------------*
 ****************************************************************************/
ViStatus _VI_FUNC rscmwinm_init(ViRsrc     resourceName,
                                ViBoolean  IDQuery,
                                ViBoolean  resetDevice,
                                ViSession* instrumentHandle);

ViStatus _VI_FUNC rscmwinm_InitWithOptions(ViRsrc     resourceName,
                                           ViBoolean  IDQuery,
                                           ViBoolean  resetDevice,
                                           ViString   optionString,
                                           ViSession* instrumentHandle);

ViStatus _VI_FUNC rscmwinm_ConfigureAnalyzerStandAloneScenario(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   RXConnector,
                            ViInt32   RFConverter);

ViStatus _VI_FUNC rscmwinm_AnalyzerMeasureProtocolTestScenario(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViString  controller);

ViStatus _VI_FUNC rscmwinm_QueryAnalyzerRoutingSettings(ViSession instrumentHandle,
                                                        ViInt32   instance,
                                                        ViInt32*  scenario,
                                                        ViChar    _VI_FAR controller[],
                                                        ViInt32*  RXConnector,
                                                        ViInt32*  RFConverter);

ViStatus _VI_FUNC rscmwinm_ConfigureAnalyzerExternalAttenuation(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViReal64  externalAttenuation);

ViStatus _VI_FUNC rscmwinm_ConfigureAnalyzer(ViSession instrumentHandle,
                                             ViInt32   instance,
                                             ViReal64  expectedNominalPower,
                                             ViReal64  margin,
                                             ViReal64  centerFrequency,
                                             ViReal64  frequencyOffset,
                                             ViReal64  mixerLevelOffset);

ViStatus _VI_FUNC rscmwinm_ConfigureAnalyzerBand(ViSession instrumentHandle,
                                                 ViInt32   instance,
                                                 ViInt32   band);

ViStatus _VI_FUNC rscmwinm_ConfigureAnalyzerScenario(ViSession instrumentHandle,
                                                     ViInt32   instance,
                                                     ViString  master,
                                                     ViInt32   carrier);

ViStatus _VI_FUNC rscmwinm_ConfigureMEvalMeasStatistics(ViSession instrumentHandle,
                                                        ViInt32   instance,
                                                        ViInt32   repetition,
                                                        ViInt32   stopCondition,
                                                        ViBoolean measureOnException);

ViStatus _VI_FUNC rscmwinm_ConfigureMEvalMeasStatisticsCount(ViSession instrumentHandle,
                                                             ViInt32   instance,
                                                             ViInt32   measurement,
                                                             ViInt32   statisticCount);

ViStatus _VI_FUNC rscmwinm_ConfigureMEvalMeasTimeout(ViSession instrumentHandle,
                                                     ViInt32   instance,
                                                     ViReal64  timeout);

ViStatus _VI_FUNC rscmwinm_ConfigureMEvalMeasResults(ViSession instrumentHandle,
                                                     ViInt32   instance,
                                                     ViInt32   measurement,
                                                     ViBoolean state);

ViStatus _VI_FUNC rscmwinm_ConfigureMEvalMeasResultsAll(ViSession instrumentHandle,
                                                        ViInt32   instance,
                                                        ViInt32   arraySize,
                                                        ViBoolean _VI_FAR states[]);

ViStatus _VI_FUNC rscmwinm_ConfigureMEvalMeasParameters(ViSession instrumentHandle,
                                                        ViInt32   instance,
                                                        ViInt32   measurementMode,
                                                        ViInt32   numberOfMeasureSlots,
                                                        ViInt32   subcarrierSpacing,
                                                        ViInt32   NPUSCHFormat,
                                                        ViInt32   physicalCellID,
                                                        ViInt32   deltaSequenceShift,
                                                        ViInt32   modulationScheme);

ViStatus _VI_FUNC rscmwinm_ConfigureMEvalMeasNPUSChLeading(ViSession instrumentHandle,
                                                           ViInt32   instance,
                                                           ViInt32   leading);

ViStatus _VI_FUNC rscmwinm_ConfigureMEvalMeasNPUSChLagging(ViSession instrumentHandle,
                                                           ViInt32   instance,
                                                           ViInt32   lagging);

ViStatus _VI_FUNC rscmwinm_ConfigureMEvalMeasOBWMode(ViSession instrumentHandle,
                                                     ViInt32   instance,
                                                     ViInt32   mode);

ViStatus _VI_FUNC rscmwinm_ConfigureMEvalMeasFreqSyncRange(ViSession instrumentHandle,
                                                           ViInt32   instance,
                                                           ViInt32   freqSyncRange);

ViStatus _VI_FUNC rscmwinm_ConfigureMEvalMeasResourceAllocation(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   numberOfSubcarriers,
                            ViInt32   offset,
                            ViInt32   numberOfResourceUnits,
                            ViInt32   numberOfRepetitions);

ViStatus _VI_FUNC rscmwinm_ConfigureMEvalMeasSelectSpectrumACLR(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViBoolean UTRA,
                            ViBoolean GSM);

ViStatus _VI_FUNC rscmwinm_ConfigureMEvalMeasUserDefinedUplink(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   set,
                            ViInt32   subcarriers,
                            ViInt32   startSubcarrier,
                            ViInt32   MCSIndex,
                            ViInt32   resourceUnits,
                            ViInt32   repetitions);

ViStatus _VI_FUNC rscmwinm_ConfigureMEvalMeasTrigger(ViSession instrumentHandle,
                                                     ViInt32   instance,
                                                     ViString  source,
                                                     ViInt32   slope,
                                                     ViReal64  threshold,
                                                     ViReal64  delay,
                                                     ViInt32   timeoutStatus,
                                                     ViReal64  timeout,
                                                     ViReal64  minTriggerGap);

ViStatus _VI_FUNC rscmwinm_QueryMEvalMeasTriggerSourceCatalog(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViChar    _VI_FAR catalog[]);

ViStatus _VI_FUNC rscmwinm_ConfigureMEvalMeasListEnabled(ViSession instrumentHandle,
                                                         ViInt32   instance,
                                                         ViBoolean enabled);

ViStatus _VI_FUNC rscmwinm_ConfigureMEvalMeasListMode(ViSession instrumentHandle,
                                                      ViInt32   instance,
                                                      ViInt32   mode);

ViStatus _VI_FUNC rscmwinm_ConfigureMEvalMeasListOfflineMode(ViSession instrumentHandle,
                                                             ViInt32   instance,
                                                             ViBoolean enabled,
                                                             ViInt32   index);

ViStatus _VI_FUNC rscmwinm_ConfigureMEvalMeasListConnectorMode(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   mode);

ViStatus _VI_FUNC rscmwinm_ConfigureMEvalMeasListCMWSConnector(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   segment,
                            ViInt32   connector);

ViStatus _VI_FUNC rscmwinm_ConfigureMEvalMeasListRangeOfMeasuredSegments(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   startIndex,
                            ViInt32   segments);

ViStatus _VI_FUNC rscmwinm_ConfigureMEvalMeasListACLR(ViSession instrumentHandle,
                                                      ViInt32   instance,
                                                      ViInt32   segment,
                                                      ViInt32   length,
                                                      ViBoolean ACLR,
                                                      ViBoolean UTRA,
                                                      ViBoolean GSM);

ViStatus _VI_FUNC rscmwinm_ConfigureMEvalMeasListModulation(ViSession instrumentHandle,
                                                            ViInt32   instance,
                                                            ViInt32   segment,
                                                            ViInt32   length,
                                                            ViBoolean modulation,
                                                            ViBoolean EVM,
                                                            ViBoolean magnitudeError,
                                                            ViBoolean phaseError,
                                                            ViBoolean IBE,
                                                            ViInt32   modulationScheme);

ViStatus _VI_FUNC rscmwinm_ConfigureMEvalMeasListSpectrumEmission(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   segment,
                            ViInt32   length,
                            ViBoolean SEM);

ViStatus _VI_FUNC rscmwinm_ConfigureMEvalMeasListSetup(ViSession instrumentHandle,
                                                       ViInt32   instance,
                                                       ViInt32   segment,
                                                       ViInt32   length,
                                                       ViReal64  level,
                                                       ViInt32   band,
                                                       ViReal64  frequency,
                                                       ViInt32   NPUSChFormat,
                                                       ViInt32   subcarriers,
                                                       ViInt32   startSubcarrier,
                                                       ViInt32   resourceUnits,
                                                       ViInt32   repetitions,
                                                       ViInt32   retriggerFlag,
                                                       ViInt32   evaluationOffset);

ViStatus _VI_FUNC rscmwinm_ConfigureMEvalLimitsModulation(ViSession instrumentHandle,
                                                          ViInt32   instance,
                                                          ViInt32   modulationCharacteristic,
                                                          ViReal64  RMSLimitValue,
                                                          ViInt32   RMSLimitStatus,
                                                          ViReal64  peakLimitValue,
                                                          ViInt32   peakLimitStatus);

ViStatus _VI_FUNC rscmwinm_ConfigureMEvalLimitsFrequencyError(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViBoolean state,
                            ViReal64  limitLower,
                            ViReal64  limitUpper);

ViStatus _VI_FUNC rscmwinm_ConfigureMEvalLimitsIQOffset(ViSession instrumentHandle,
                                                        ViInt32   instance,
                                                        ViBoolean enable,
                                                        ViReal64  _0DBmLimit,
                                                        ViReal64  _30DBmLimit,
                                                        ViReal64  _40DBmLimit);

ViStatus _VI_FUNC rscmwinm_ConfigureMEvalLimitsInbandEmissions(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViBoolean enable,
                            ViReal64  minimumLimit,
                            ViReal64  SCPowerLimit,
                            ViReal64  IQImageLimit);

ViStatus _VI_FUNC rscmwinm_ConfigureMEvalLimitsInbandEmissionsIQOffset(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViReal64  _0DBmLimit,
                            ViReal64  _30DBmLimit,
                            ViReal64  _40DBmLimit);

ViStatus _VI_FUNC rscmwinm_ConfigureMEvalLimitsOBW(ViSession instrumentHandle,
                                                   ViInt32   instance,
                                                   ViReal64  limitValue,
                                                   ViInt32   limitStatus);

ViStatus _VI_FUNC rscmwinm_ConfigureMEvalLimitsSpectrumEmissionMask(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   area,
                            ViBoolean enable,
                            ViReal64  frequencyStart,
                            ViReal64  frequencyStop,
                            ViReal64  powerStart,
                            ViReal64  powerStop);

ViStatus _VI_FUNC rscmwinm_ConfigureMEvalLimitsACLR(ViSession instrumentHandle,
                                                    ViInt32   instance,
                                                    ViInt32   measurement,
                                                    ViReal64  relativeLimitValue,
                                                    ViInt32   relativeLimitStatus,
                                                    ViReal64  absoluteLimitValue,
                                                    ViInt32   absoluteLimitStatus);

ViStatus _VI_FUNC rscmwinm_ConfigureMEvalLimitsPowerDynamics(ViSession instrumentHandle,
                                                             ViInt32   instance,
                                                             ViBoolean enable,
                                                             ViReal64  onPowerUpperLimit,
                                                             ViReal64  onPowerLowerLimit,
                                                             ViReal64  offPowerUpperLimit);

ViStatus _VI_FUNC rscmwinm_MEvalMeasInit(ViSession instrumentHandle,
                                         ViInt32   instance);

ViStatus _VI_FUNC rscmwinm_MEvalMeasAbort(ViSession instrumentHandle,
                                          ViInt32   instance);

ViStatus _VI_FUNC rscmwinm_MEvalMeasStop(ViSession instrumentHandle,
                                         ViInt32   instance);

ViStatus _VI_FUNC rscmwinm_QueryMEvalMeasurementStatus(ViSession instrumentHandle,
                                                       ViInt32   instance,
                                                       ViInt32*  mainState,
                                                       ViInt32*  syncState,
                                                       ViInt32*  resourcesState);

ViStatus _VI_FUNC rscmwinm_ReadMEvalMeasEVMTrace(ViSession instrumentHandle,
                                                 ViInt32   instance,
                                                 ViInt32   resultType,
                                                 ViInt32   arraySize,
                                                 ViInt32*  reliability,
                                                 ViReal64  _VI_FAR results[],
                                                 ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwinm_FetchMEvalMeasEVMTrace(ViSession instrumentHandle,
                                                  ViInt32   instance,
                                                  ViInt32   resultType,
                                                  ViInt32   arraySize,
                                                  ViInt32*  reliability,
                                                  ViReal64  _VI_FAR results[],
                                                  ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwinm_ReadMEvalMeasEVMSCFDMASymbols(ViSession instrumentHandle,
                                                         ViInt32   instance,
                                                         ViInt32   resultType,
                                                         ViInt32   type,
                                                         ViInt32   arraySize,
                                                         ViInt32*  reliability,
                                                         ViReal64  _VI_FAR results[],
                                                         ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwinm_FetchMEvalMeasEVMSCFDMASymbols(ViSession instrumentHandle,
                                                          ViInt32   instance,
                                                          ViInt32   resultType,
                                                          ViInt32   type,
                                                          ViInt32   arraySize,
                                                          ViInt32*  reliability,
                                                          ViReal64  _VI_FAR results[],
                                                          ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwinm_ReadMEvalMeasMagnitudeErrorSCFDMASymbols(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  _VI_FAR results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwinm_FetchMEvalMeasMagnitudeErrorSCFDMASymbols(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  _VI_FAR results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwinm_ReadMEvalMeasPhaseErrorSCFDMASymbols(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  _VI_FAR results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwinm_FetchMEvalMeasPhaseErrorSCFDMASymbols(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  _VI_FAR results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwinm_ReadMEvalMeasInbandEmissionTrace(ViSession instrumentHandle,
                                                            ViInt32   instance,
                                                            ViInt32   arraySize,
                                                            ViInt32*  reliability,
                                                            ViReal64  _VI_FAR results[],
                                                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwinm_FetchMEvalMeasInbandEmissionTrace(ViSession instrumentHandle,
                                                             ViInt32   instance,
                                                             ViInt32   arraySize,
                                                             ViInt32*  reliability,
                                                             ViReal64  _VI_FAR results[],
                                                             ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwinm_FetchMEvalMeasInbandEmissionMargin(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32*  reliability,
                            ViReal64* outOfTolerance,
                            ViReal64* margin);

ViStatus _VI_FUNC rscmwinm_FetchMEvalMeasInbandEmissionMarginStandardDeviation(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32*  reliability,
                            ViReal64* outOfTolerance,
                            ViReal64* margin);

ViStatus _VI_FUNC rscmwinm_FetchMEvalMeasInbandEmissionMarginSCIndex(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32*  reliability,
                            ViReal64* outOfTolerance,
                            ViInt32*  SCIndex);

ViStatus _VI_FUNC rscmwinm_ReadMEvalMeasSpectrumEmissionMaskTrace(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  _VI_FAR results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwinm_FetchMEvalMeasSpectrumEmissionMaskTrace(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  _VI_FAR results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwinm_ReadMEvalMeasSpectrumEmissionMask(ViSession instrumentHandle,
                                                             ViInt32   instance,
                                                             ViInt32   resultType,
                                                             ViInt32   arraySize,
                                                             ViInt32*  reliability,
                                                             ViReal64  _VI_FAR results[],
                                                             ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwinm_FetchMEvalMeasSpectrumEmissionMask(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  _VI_FAR results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwinm_ReadMEvalMeasSpectrumEmissionMaskStandardDeviation(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  _VI_FAR results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwinm_FetchMEvalMeasSpectrumEmissionMaskStandardDeviation(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  _VI_FAR results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwinm_QueryMEvalMeasSpectrumEmissionMaskLimitCheckResult(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   _VI_FAR results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwinm_FetchMEvalMeasSpectrumEmissionMaskAllMargins(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  _VI_FAR results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwinm_FetchMEvalMeasSpectrumEmissionMaskMargin(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   marginType,
                            ViInt32*  reliability,
                            ViReal64* outOfTolerance,
                            ViReal64  _VI_FAR marginX[],
                            ViReal64  _VI_FAR marginY[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwinm_ReadMEvalMeasSpectrumACLRTrace(ViSession instrumentHandle,
                                                          ViInt32   instance,
                                                          ViInt32   resultType,
                                                          ViInt32   arraySize,
                                                          ViInt32*  reliability,
                                                          ViReal64  _VI_FAR results[],
                                                          ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwinm_FetchMEvalMeasSpectrumACLRTrace(ViSession instrumentHandle,
                                                           ViInt32   instance,
                                                           ViInt32   resultType,
                                                           ViInt32   arraySize,
                                                           ViInt32*  reliability,
                                                           ViReal64  _VI_FAR results[],
                                                           ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwinm_ReadMEvalMeasSpectrumACLR(ViSession instrumentHandle,
                                                     ViInt32   instance,
                                                     ViInt32   resultType,
                                                     ViInt32   arraySize,
                                                     ViInt32*  reliability,
                                                     ViReal64  _VI_FAR results[],
                                                     ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwinm_FetchMEvalMeasSpectrumACLR(ViSession instrumentHandle,
                                                      ViInt32   instance,
                                                      ViInt32   resultType,
                                                      ViInt32   arraySize,
                                                      ViInt32*  reliability,
                                                      ViReal64  _VI_FAR results[],
                                                      ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwinm_QueryMEvalMeasSpectrumACLRLimitCheckResult(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   _VI_FAR results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwinm_FetchMEvalMeasIQTrace(ViSession instrumentHandle,
                                                 ViInt32   instance,
                                                 ViInt32   arraySize,
                                                 ViInt32*  reliability,
                                                 ViReal64  _VI_FAR i[],
                                                 ViReal64  _VI_FAR q[],
                                                 ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwinm_ReadMEvalMeasPowerMonitorTrace(ViSession instrumentHandle,
                                                          ViInt32   instance,
                                                          ViInt32   arraySize,
                                                          ViInt32*  reliability,
                                                          ViReal64  _VI_FAR results[],
                                                          ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwinm_FetchMEvalMeasPowerMonitorTrace(ViSession instrumentHandle,
                                                           ViInt32   instance,
                                                           ViInt32   arraySize,
                                                           ViInt32*  reliability,
                                                           ViReal64  _VI_FAR results[],
                                                           ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwinm_ReadMEvalMeasPowerDynamicsTrace(ViSession instrumentHandle,
                                                           ViInt32   instance,
                                                           ViInt32   resultType,
                                                           ViInt32   powerType,
                                                           ViInt32   arraySize,
                                                           ViInt32*  reliability,
                                                           ViReal64  _VI_FAR results[],
                                                           ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwinm_FetchMEvalMeasPowerDynamicsTrace(ViSession instrumentHandle,
                                                            ViInt32   instance,
                                                            ViInt32   resultType,
                                                            ViInt32   powerType,
                                                            ViInt32   arraySize,
                                                            ViInt32*  reliability,
                                                            ViReal64  _VI_FAR results[],
                                                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwinm_ReadMEvalMeasPowerDynamics(ViSession instrumentHandle,
                                                      ViInt32   instance,
                                                      ViInt32   resultType,
                                                      ViInt32   arraySize,
                                                      ViInt32*  reliability,
                                                      ViReal64  _VI_FAR results[],
                                                      ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwinm_FetchMEvalMeasPowerDynamics(ViSession instrumentHandle,
                                                       ViInt32   instance,
                                                       ViInt32   resultType,
                                                       ViInt32   arraySize,
                                                       ViInt32*  reliability,
                                                       ViReal64  _VI_FAR results[],
                                                       ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwinm_ReadMEvalMeasPowerDynamicsStandardDeviation(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  _VI_FAR results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwinm_FetchMEvalMeasPowerDynamicsStandardDeviation(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  _VI_FAR results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwinm_QueryMEvalMeasPowerDynamicsLimitCheckResult(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   _VI_FAR results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwinm_ReadMEvalMeasModulationResults(ViSession instrumentHandle,
                                                          ViInt32   instance,
                                                          ViInt32   resultType,
                                                          ViInt32   arraySize,
                                                          ViInt32*  reliability,
                                                          ViReal64  _VI_FAR results[],
                                                          ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwinm_FetchMEvalMeasModulationResults(ViSession instrumentHandle,
                                                           ViInt32   instance,
                                                           ViInt32   resultType,
                                                           ViInt32   arraySize,
                                                           ViInt32*  reliability,
                                                           ViReal64  _VI_FAR results[],
                                                           ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwinm_ReadMEvalMeasModulationStandardDeviation(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  _VI_FAR results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwinm_FetchMEvalMeasModulationStandardDeviation(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  _VI_FAR results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwinm_QueryMEvalMeasModulationResultsLimitsCheckResult(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   _VI_FAR results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwinm_FetchMEvalMeasListACLR(ViSession instrumentHandle,
                                                  ViInt32   instance,
                                                  ViInt32   segment,
                                                  ViInt32   resultType,
                                                  ViInt32   arraySize,
                                                  ViInt32*  reliability,
                                                  ViInt32*  segmentReliability,
                                                  ViReal64  _VI_FAR results[],
                                                  ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwinm_FetchMEvalMeasListInbandEmission(ViSession instrumentHandle,
                                                            ViInt32   instance,
                                                            ViInt32   segment,
                                                            ViInt32   resultType,
                                                            ViInt32   arraySize,
                                                            ViInt32*  reliability,
                                                            ViInt32*  segmentReliability,
                                                            ViReal64  _VI_FAR results[],
                                                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwinm_FetchMEvalMeasListInbandEmissionSCIndex(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   segment,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32*  segmentReliability,
                            ViReal64  _VI_FAR results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwinm_FetchMEvalMeasListModulation(ViSession instrumentHandle,
                                                        ViInt32   instance,
                                                        ViInt32   segment,
                                                        ViInt32   resultType,
                                                        ViInt32   arraySize,
                                                        ViInt32*  reliability,
                                                        ViInt32*  segmentReliability,
                                                        ViReal64  _VI_FAR results[],
                                                        ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwinm_FetchMEvalMeasListModulationExtreme(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   segment,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32*  segmentReliability,
                            ViReal64  _VI_FAR results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwinm_FetchMEvalMeasListSpectrumEmissionMask(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   segment,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32*  segmentReliability,
                            ViReal64  _VI_FAR results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwinm_FetchMEvalMeasListSpectrumEmissionMaskExtreme(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   segment,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32*  segmentReliability,
                            ViReal64  _VI_FAR results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwinm_FetchMEvalMeasListSpectrumEmissionMaskMarginAll(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   segment,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32*  segmentReliability,
                            ViReal64  _VI_FAR results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwinm_FetchMEvalMeasListSpectrumEmissionMaskMargin(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   segment,
                            ViInt32   resultType,
                            ViInt32   marginType,
                            ViInt32*  reliability,
                            ViInt32*  segmentReliability,
                            ViInt32*  statisticExpired,
                            ViReal64* outOfTolerance,
                            ViReal64  _VI_FAR marginX[],
                            ViReal64  _VI_FAR marginY[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwinm_FetchMEvalMeasListSegmentReliability(
                            ViSession instrumentHandle,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   _VI_FAR segmentReliability[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwinm_reset(ViSession instrumentHandle);

ViStatus _VI_FUNC rscmwinm_self_test(ViSession instrumentHandle,
                                     ViInt16*  selfTestResult,
                                     ViChar    _VI_FAR selfTestMessage[]);

ViStatus _VI_FUNC rscmwinm_revision_query(ViSession instrumentHandle,
                                          ViChar    _VI_FAR instrumentDriverRevision[],
                                          ViChar    _VI_FAR firmwareRevision[]);

ViStatus _VI_FUNC rscmwinm_SystemVersion(ViSession instrumentHandle,
                                         ViInt32   length,
                                         ViChar    _VI_FAR systemVersion[]);

ViStatus _VI_FUNC rscmwinm_error_query(ViSession instrumentHandle,
                                       ViInt32*  errorCode,
                                       ViChar    _VI_FAR errorMessage[]);

ViStatus _VI_FUNC rscmwinm_ErrorList(ViSession instrumentHandle,
                                     ViInt32   bufferSize,
                                     ViChar    _VI_FAR errors[]);

ViStatus _VI_FUNC rscmwinm_error_message(ViSession instrumentHandle,
                                         ViStatus  errorCode,
                                         ViChar    _VI_FAR errorMessage[]);

ViStatus _VI_FUNC rscmwinm_ReliabilityIndicator(ViSession instrumentHandle,
                                                ViInt32   reliabilityCode,
                                                ViChar    _VI_FAR reliabilityMessage[]);

ViStatus _VI_FUNC rscmwinm_Preset(ViSession instrumentHandle);

ViStatus _VI_FUNC rscmwinm_ConfigureErrorChecking(ViSession instrumentHandle,
                                                  ViBoolean optionChecking,
                                                  ViBoolean rangeChecking,
                                                  ViBoolean statusChecking);

ViStatus _VI_FUNC rscmwinm_SetOPCTimeout(ViSession instrumentHandle,
                                         ViUInt32  OPCTimeout);

ViStatus _VI_FUNC rscmwinm_GetOPCTimeout(ViSession instrumentHandle,
                                         ViUInt32* timeout);

ViStatus _VI_FUNC rscmwinm_SetVISATimeout(ViSession instrumentHandle,
                                          ViUInt32  VISATimeout);

ViStatus _VI_FUNC rscmwinm_GetVISATimeout(ViSession instrumentHandle,
                                          ViUInt32* VISATimeout);

ViStatus _VI_FUNC rscmwinm_ClearStatus(ViSession instrumentHandle);

ViStatus _VI_FUNC rscmwinm_IDQueryResponse(ViSession instrumentHandle,
                                           ViUInt32  bufferSize,
                                           ViChar    _VI_FAR IDQueryResponse[]);

ViStatus _VI_FUNC rscmwinm_ProcessAllPreviousCommands(ViSession instrumentHandle);

ViStatus _VI_FUNC rscmwinm_QueryOPC(ViSession instrumentHandle,
                                    ViInt32*  OPC);

ViStatus _VI_FUNC rscmwinm_ConfigureAutoSystemErrQuery(ViSession instrumentHandle,
                                                       ViBoolean autoSystErrQuery);

ViStatus _VI_FUNC rscmwinm_ConfigureMultiThreadLocking(ViSession instrumentHandle,
                                                       ViBoolean multiThreadLocking);

ViStatus _VI_FUNC rscmwinm_GetError(ViSession instrumentHandle,
                                    ViStatus* code,
                                    ViInt32   bufferSize,
                                    ViChar    _VI_FAR description[]);

ViStatus _VI_FUNC rscmwinm_ClearError(ViSession instrumentHandle);

ViStatus _VI_FUNC rscmwinm_WriteFromFileToInstrument(ViSession instrumentHandle,
                                                     ViString  source,
                                                     ViString  destination);

ViStatus _VI_FUNC rscmwinm_ReadToFileFromInstrument(ViSession instrumentHandle,
                                                    ViString  source,
                                                    ViString  destination);

ViStatus _VI_FUNC rscmwinm_WriteInstrData(ViSession instrumentHandle,
                                          ViString  writeBuffer);

ViStatus _VI_FUNC rscmwinm_ReadInstrData(ViSession instrumentHandle,
                                         ViInt32   numberOfBytesToRead,
                                         ViChar    _VI_FAR readBuffer[],
                                         ViUInt32* numBytesRead);

ViStatus _VI_FUNC rscmwinm_QueryViBoolean(ViSession  instrumentHandle,
                                          ViString   command,
                                          ViBoolean* value);

ViStatus _VI_FUNC rscmwinm_QueryViInt32(ViSession instrumentHandle,
                                        ViString  command,
                                        ViInt32*  value);

ViStatus _VI_FUNC rscmwinm_QueryViReal64(ViSession instrumentHandle,
                                         ViString  command,
                                         ViReal64* value);

ViStatus _VI_FUNC rscmwinm_QueryViString(ViSession instrumentHandle,
                                         ViString  command,
                                         ViInt32   bufferSize,
                                         ViChar    _VI_FAR value[]);

ViStatus _VI_FUNC rscmwinm_SetAttributeViInt32(ViSession instrumentHandle,
                                               ViString  repeatedCapabilityName,
                                               ViAttr    attributeID,
                                               ViInt32   attributeValue);

ViStatus _VI_FUNC rscmwinm_SetAttributeViInt64(ViSession instrumentHandle,
                                               ViString  repeatedCapabilityName,
                                               ViAttr    attributeID,
                                               ViInt64   attributeValue);

ViStatus _VI_FUNC rscmwinm_SetAttributeViReal64(ViSession instrumentHandle,
                                                ViString  repeatedCapabilityName,
                                                ViAttr    attributeID,
                                                ViReal64  attributeValue);

ViStatus _VI_FUNC rscmwinm_SetAttributeViString(ViSession instrumentHandle,
                                                ViString  repeatedCapabilityName,
                                                ViAttr    attributeID,
                                                ViString  attributeValue);

ViStatus _VI_FUNC rscmwinm_SetAttributeRawString(ViSession instrumentHandle,
                                                 ViString  repeatedCapabilityName,
                                                 ViUInt32  attributeID,
                                                 ViString  attributeValue);

ViStatus _VI_FUNC rscmwinm_SetAttributeViBoolean(ViSession instrumentHandle,
                                                 ViString  repeatedCapabilityName,
                                                 ViAttr    attributeID,
                                                 ViBoolean attributeValue);

ViStatus _VI_FUNC rscmwinm_SetAttributeViSession(ViSession instrumentHandle,
                                                 ViString  repeatedCapabilityName,
                                                 ViAttr    attributeID,
                                                 ViSession attributeValue);

ViStatus _VI_FUNC rscmwinm_GetAttributeViInt32(ViSession instrumentHandle,
                                               ViString  repeatedCapabilityName,
                                               ViAttr    attributeID,
                                               ViInt32*  attributeValue);

ViStatus _VI_FUNC rscmwinm_GetAttributeViInt64(ViSession instrumentHandle,
                                               ViString  repeatedCapabilityName,
                                               ViAttr    attributeID,
                                               ViInt64*  attributeValue);

ViStatus _VI_FUNC rscmwinm_GetAttributeViReal64(ViSession instrumentHandle,
                                                ViString  repeatedCapabilityName,
                                                ViAttr    attributeID,
                                                ViReal64* attributeValue);

ViStatus _VI_FUNC rscmwinm_GetAttributeViString(ViSession instrumentHandle,
                                                ViString  repeatedCapabilityName,
                                                ViAttr    attributeID,
                                                ViInt32   bufferSize,
                                                ViChar    _VI_FAR attributeValue[]);

ViStatus _VI_FUNC rscmwinm_GetAttributeRawString(ViSession instrumentHandle,
                                                 ViString  repeatedCapabilityName,
                                                 ViUInt32  attributeID,
                                                 ViInt32   bufferSize,
                                                 ViChar    _VI_FAR attributeValue[]);

ViStatus _VI_FUNC rscmwinm_GetAttributeViBoolean(ViSession  instrumentHandle,
                                                 ViString   repeatedCapabilityName,
                                                 ViAttr     attributeID,
                                                 ViBoolean* attributeValue);

ViStatus _VI_FUNC rscmwinm_GetAttributeViSession(ViSession  instrumentHandle,
                                                 ViString   repeatedCapabilityName,
                                                 ViAttr     attributeID,
                                                 ViSession* attributeValue);

ViStatus _VI_FUNC rscmwinm_GetAttributeRepCapName(ViSession instrumentHandle,
                                                  ViUInt32  attributeID,
                                                  ViString  repCapNameID,
                                                  ViInt32   index,
                                                  ViInt32   bufferSize,
                                                  ViChar    _VI_FAR repCapName[]);

ViStatus _VI_FUNC rscmwinm_GetAttributeRepeatedCapabilityIds(ViSession instrumentHandle,
                                                             ViUInt32  attributeID,
                                                             ViInt32   bufferSize,
                                                             ViChar    _VI_FAR repeatedCapabilityId_s[]);

ViStatus _VI_FUNC rscmwinm_GetAttributeRepeatedCapabilityIdNames(
                            ViSession instrumentHandle,
                            ViUInt32  attributeID,
                            ViString  repeatedCapabilityId,
                            ViInt32   bufferSize,
                            ViChar    _VI_FAR repeatedCapabilityIdName_s[]);

ViStatus _VI_FUNC rscmwinm_CheckAttributeViInt32(ViSession instrumentHandle,
                                                 ViString  repeatedCapabilityName,
                                                 ViAttr    attributeID,
                                                 ViInt32   attributeValue);

ViStatus _VI_FUNC rscmwinm_CheckAttributeViReal64(ViSession instrumentHandle,
                                                  ViString  repeatedCapabilityName,
                                                  ViAttr    attributeID,
                                                  ViReal64  attributeValue);

ViStatus _VI_FUNC rscmwinm_CheckAttributeViString(ViSession instrumentHandle,
                                                  ViString  repeatedCapabilityName,
                                                  ViAttr    attributeID,
                                                  ViString  attributeValue);

ViStatus _VI_FUNC rscmwinm_CheckAttributeViBoolean(ViSession instrumentHandle,
                                                   ViString  repeatedCapabilityName,
                                                   ViAttr    attributeID,
                                                   ViBoolean attributeValue);

ViStatus _VI_FUNC rscmwinm_CheckAttributeViSession(ViSession instrumentHandle,
                                                   ViString  repeatedCapabilityName,
                                                   ViAttr    attributeID,
                                                   ViSession attributeValue);

ViStatus _VI_FUNC rscmwinm_close(ViSession instrumentHandle);

/****************************************************************************
 *------------------------ Error And Completion Codes ----------------------*
 ****************************************************************************/

#define RSCMWINM_WARN_MEASURE_UNCALIBRATED    (RS_CLASS_WARN_BASE + 0x0001L)
#define RSCMWINM_WARN_OVER_RANGE              (RS_CLASS_WARN_BASE + 0x0002L)

#define RSCMWINM_ERROR_INCORRECT_STATE        (RS_CLASS_ERROR_BASE + 0x0003L)
#define RSCMWINM_ERROR_INCORRECT_RESPONSE     (RS_CLASS_ERROR_BASE + 0x0002L)
#define RSCMWINM_ERROR_MAX_TIME_EXCEEDED      (RS_CLASS_ERROR_BASE + 0x0001L)
#define RSCMWINM_ERROR_RELIABILITY_INDICATOR  (RS_SPECIFIC_ERROR_BASE + 0x0004L)

#define RSCMWINM_WARNMSG_MEASURE_UNCALIBRATED "Uncalibrated measurement"
#define RSCMWINM_WARNMSG_OVER_RANGE           "Measurement overrange"
#define RSCMWINM_ERRMSG_RELIABILITY_INDICATOR "Reliability Indicator error"

#define RSCMWINM_ERRMSG_INCORRECT_STATE     "Instrument in incorrect state"
#define RSCMWINM_ERRMSG_INCORRECT_RESPONSE      "Response incorrect; report problem to R&S support!"
#define RSCMWINM_ERRMSG_MAX_TIME_EXCEEDED     "Max Time Exceeded"

#define RSCMWINM_ERROR_CODES_AND_MSGS \
    {RSCMWINM_WARN_MEASURE_UNCALIBRATED,  RSCMWINM_WARNMSG_MEASURE_UNCALIBRATED},\
    {RSCMWINM_WARN_OVER_RANGE,            RSCMWINM_WARNMSG_OVER_RANGE},\
    {RSCMWINM_ERROR_INCORRECT_STATE ,   RSCMWINM_ERRMSG_INCORRECT_STATE },\
    {RSCMWINM_ERROR_INCORRECT_RESPONSE,     RSCMWINM_ERRMSG_INCORRECT_RESPONSE},\
    {RSCMWINM_ERROR_MAX_TIME_EXCEEDED,    RSCMWINM_ERRMSG_MAX_TIME_EXCEEDED},\
    {RSCMWINM_ERROR_RELIABILITY_INDICATOR, RSCMWINM_ERRMSG_RELIABILITY_INDICATOR}

/****************************************************************************
 *---------------------------- End Include File ----------------------------*
 ****************************************************************************/

#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif
#endif /* __RSCMWINM_HEADER */
