/*****************************************************************************
 *  Rohde & Schwarz CMW Communication tester NB IoT instrument driver
 *  Callbacks
 *
 *  Original Release: December 2017
 *  By: Martin Krcmar
 *
 *  Should you have any technical questions please contact the hotline of
 *  Rohde & Schwarz Vertriebs-GmbH Rohde & Schwarz Support Center
 *
 *  e-mail: CustomerSupport@rohde-schwarz.com
 *

 *****************************************************************************/

#include "rscmwinm.h"
#include "rscmwinm_utility.h"
#include <stdlib.h>

#if (defined(WIN32) || defined(_WIN32) || defined(__WIN32__) || defined(__NT__))
    #define ANSI
#endif
#ifndef ANSI                /* UNIX compatible */
    #include <sys/timeb.h>
    #include <sys/types.h>
    #include <unistd.h>
    #define Sleep sleep
#else                       /* ANSI compatible */
    #include <windows.h>
#endif

#pragma warning (disable:4100) // unreferenced formal parameter

/*****************************************************************************
 * Function: rscmwinm_OperatingBand_ReadCallback
 * Purpose:  This function overrides standard calback funtion. Reads string
 *           returned and returns only the band number
 *****************************************************************************/
ViStatus rscmwinm_OperatingBand_ReadCallback(ViSession          instrSession,
                                             ViConstString      repCapName,
                                             RsCoreAttributePtr attr)
{
    ViStatus error = VI_SUCCESS;
    ViInt32  value = 0;
    ViChar   *cmd = NULL;
    ViChar   response[RS_MAX_MESSAGE_BUF_SIZE];

    switch (attr -> dataType)
    {
        case RS_VAL_INT32:
            checkErr(RsCore_BuildAttrCommandString(instrSession, attr, repCapName, &cmd));
            checkErr(RsCore_QueryAttributeCommand(instrSession, attr, cmd, response));
            sscanf (response, "OB%ld", &value);
            RsCore_SetAttributeP2Value(instrSession, attr, (void*) &value);
            break;
        default:
            checkErr(RsCore_GenerateInvalidDataTypeError(instrSession, attr->dataType, "rscmwinm_OperatingBand_ReadCallback only accepts type RS_VAL_INT32"));
    }

Error:
    if (cmd)
        free (cmd);

    return error;
}

/*****************************************************************************
 * Function: rscmwinm_OperatingBand_WriteCallback
 * Purpose:  This function overrides standard calback funtion. Writes string
 *           with band number.
 *****************************************************************************/
ViStatus rscmwinm_OperatingBand_WriteCallback(ViSession          instrSession,
                                              ViConstString      repCapName,
                                              RsCoreAttributePtr attr,
                                              void               *value)
{
    return RsCore_SpecialCallback_SurroundParamWrite(instrSession, repCapName, attr, "OB", value, "");
}
