/*****************************************************************************
 *  Rohde&Schwarz CMW500 Wideband Radio Communication Tester instrument driver
 *  R&S CMW NB-IoT Signaling Driver
 *  VXIpnp Instrument Driver
 *****************************************************************************/

#ifndef __RSCMWINS_HEADER
#define __RSCMWINS_HEADER

#include "rscore.h"
#include "rscmwins_attributes.h"
#include "rscmwins_utility.h"

#include <string.h>
#include <stdlib.h>
#include <stdio.h>

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

/****************************************************************************
 *----------------- Instrument Driver Revision Information -----------------*
 ****************************************************************************/

/* Class Driver Identification */

#define RSCMWINS_CLASS_DRIVER_DESCRIPTION           ""
#define RSCMWINS_CLASS_DRIVER_PREFIX                ""
#define RSCMWINS_CLASS_DRIVER_VENDOR                ""
#define RSCMWINS_CLASS_DRIVER_REVISION              ""
#define RSCMWINS_CLASS_SPEC_MAJOR_VERSION           1L    /* Class specification major version */
#define RSCMWINS_CLASS_SPEC_MINOR_VERSION           0L    /* Class specification minor version */

/* Driver Identification */

#define RSCMWINS_SPECIFIC_DRIVER_DESCRIPTION        ""
#define RSCMWINS_SPECIFIC_DRIVER_PREFIX             "RSCMWINS"
#define RSCMWINS_SPECIFIC_DRIVER_LOCATOR            ""
#define RSCMWINS_SPECIFIC_DRIVER_VENDOR             ""
#define RSCMWINS_MAJOR_VERSION                      3L    /* Instrument driver major version          */
#define RSCMWINS_MINOR_VERSION                      8L    /* Instrument driver minor version          */
#define RSCMWINS_MINOR_MINOR_VERSION                200L   /* Instrument driver minor minor version    */

/* Driver Capabilities */

#define RSCMWINS_SUPPORTED_INSTRUMENT_MODELS        ""    /* Instrument driver supported model(s)     */
#define RSCMWINS_GROUP_CAPABILITIES                 ""
#define RSCMWINS_FUNCTION_CAPABILITIES              ""

/****************************************************************************
 *------------------------------ Useful Macros -----------------------------*
 ****************************************************************************/

/*****************************************************************************
 *- Useful Macros & Constants -----------------------------------------------*
 *****************************************************************************/

#define RSCMWINS_SIMULATION_ID_QUERY      "Rohde&Schwarz,CMW,123456/789,1.23"  /* Default definition of ID Query Response for simulation */
#define RSCMWINS_VALID_ID_RESPONSE_STRING "Rohde&Schwarz"      /* Valid response for identification query */
#define RSCMWINS_SIMULATION_OPT_QUERY     ""      /* Simulated response for *OPT? command */

#define RSCMWINS_OPC_TIMEOUT              5000L   /* Maximum time to wait for OPC in milliseconds */

/****************************************************************************
 *---------------------------- Attribute Defines ---------------------------*
 ****************************************************************************/

    /*- Inherent Instrument Specific Attributes ----------------------------*/

        /* User Options */

#define RSCMWINS_ATTR_RANGE_CHECK                                           RS_ATTR_RANGE_CHECK                                     /* ViBoolean */
#define RSCMWINS_ATTR_QUERY_INSTRUMENT_STATUS                               RS_ATTR_QUERY_INSTRUMENT_STATUS                         /* ViBoolean */
#define RSCMWINS_ATTR_CACHE                                                 RS_ATTR_CACHE                                           /* ViBoolean */
#define RSCMWINS_ATTR_SIMULATE                                              RS_ATTR_SIMULATE                                        /* ViBoolean */
#define RSCMWINS_ATTR_RECORD_COERCIONS                                      RS_ATTR_RECORD_COERCIONS                                /* ViBoolean */
#define RSCMWINS_ATTR_INTERCHANGE_CHECK                                     RS_ATTR_INTERCHANGE_CHECK                               /* ViBoolean */
#define RSCMWINS_ATTR_SPY                                                   RS_ATTR_SPY                                             /* ViBoolean */
#define RSCMWINS_ATTR_USE_SPECIFIC_SIMULATION                               RS_ATTR_USE_SPECIFIC_SIMULATION                         /* ViBoolean */

        /* Class Driver Identification */

#define RSCMWINS_ATTR_CLASS_DRIVER_DESCRIPTION                              RS_ATTR_CLASS_DRIVER_DESCRIPTION                        /* ViString, read-only */
#define RSCMWINS_ATTR_CLASS_DRIVER_PREFIX                                   RS_ATTR_CLASS_DRIVER_PREFIX                             /* ViString, read-only */
#define RSCMWINS_ATTR_CLASS_DRIVER_VENDOR                                   RS_ATTR_CLASS_DRIVER_VENDOR                             /* ViString, read-only */
#define RSCMWINS_ATTR_CLASS_DRIVER_REVISION                                 RS_ATTR_CLASS_DRIVER_REVISION                           /* ViString, read-only */
#define RSCMWINS_ATTR_CLASS_DRIVER_CLASS_SPEC_MAJOR_VERSION                 RS_ATTR_CLASS_DRIVER_CLASS_SPEC_MAJOR_VERSION           /* ViInt32,  read-only */
#define RSCMWINS_ATTR_CLASS_DRIVER_CLASS_SPEC_MINOR_VERSION                 RS_ATTR_CLASS_DRIVER_CLASS_SPEC_MINOR_VERSION           /* ViInt32,  read-only */

        /* Driver Identification */

#define RSCMWINS_ATTR_SPECIFIC_DRIVER_DESCRIPTION                           RS_ATTR_SPECIFIC_DRIVER_DESCRIPTION                     /* ViString, read-only */
#define RSCMWINS_ATTR_SPECIFIC_DRIVER_PREFIX                                RS_ATTR_SPECIFIC_DRIVER_PREFIX                          /* ViString, read-only */
#define RSCMWINS_ATTR_SPECIFIC_DRIVER_LOCATOR                               RS_ATTR_SPECIFIC_DRIVER_LOCATOR                         /* ViString, read-only */
#define RSCMWINS_ATTR_SPECIFIC_DRIVER_VENDOR                                RS_ATTR_SPECIFIC_DRIVER_VENDOR                          /* ViString, read-only */
#define RSCMWINS_ATTR_SPECIFIC_DRIVER_REVISION                              RS_ATTR_SPECIFIC_DRIVER_REVISION                        /* ViString, read-only */
#define RSCMWINS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION              RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION        /* ViInt32,  read-only */
#define RSCMWINS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION              RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION        /* ViInt32,  read-only */

        /* Driver Capabilities */

#define RSCMWINS_ATTR_SUPPORTED_INSTRUMENT_MODELS                           RS_ATTR_SUPPORTED_INSTRUMENT_MODELS                     /* ViString, read-only */
#define RSCMWINS_ATTR_GROUP_CAPABILITIES                                    RS_ATTR_GROUP_CAPABILITIES                              /* ViString, read-only */
#define RSCMWINS_ATTR_FUNCTION_CAPABILITIES                                 RS_ATTR_FUNCTION_CAPABILITIES                           /* ViString, read-only */
#define RSCMWINS_ATTR_CHANNEL_COUNT                                         RS_ATTR_CHANNEL_COUNT                                   /* ViInt32,  read-only */

        /* Driver Setup */

#define RSCMWINS_ATTR_DRIVER_SETUP                                          RS_ATTR_DRIVER_SETUP                                    /* ViString            */

        /* Instrument Identification */

#define RSCMWINS_ATTR_INSTRUMENT_MANUFACTURER                               RS_ATTR_INSTRUMENT_MANUFACTURER                         /* ViString, read-only */
#define RSCMWINS_ATTR_INSTRUMENT_MODEL                                      RS_ATTR_INSTRUMENT_MODEL                                /* ViString, read-only */
#define RSCMWINS_ATTR_INSTRUMENT_FIRMWARE_REVISION                          RS_ATTR_INSTRUMENT_FIRMWARE_REVISION                    /* ViString, read-only */

        /* Advanced Session Information */

#define RSCMWINS_ATTR_IO_RESOURCE_DESCRIPTOR                                RS_ATTR_IO_RESOURCE_DESCRIPTOR                          /* ViString, read-only */
#define RSCMWINS_ATTR_LOGICAL_NAME                                          RS_ATTR_LOGICAL_NAME                                    /* ViString, read-only */

    /*- Instrument-Specific Attributes -------------------------------------*/

/* BEGIN GENERATE */
#define RSCMWINS_ATTR_CONFIGURE_GENERATOR_STATE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 214
#define RSCMWINS_ATTR_QUERY_RRC_STATE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 216
#define RSCMWINS_ATTR_RRC_RELEASE_CAUSE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 481
#define RSCMWINS_ATTR_CONFIGURE_PS_ACTION                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 217
#define RSCMWINS_ATTR_QUERY_PS_STATE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 218
#define RSCMWINS_ATTR_SCENARIO_CATALOG                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 219
#define RSCMWINS_ATTR_SCENARIO_ACTIVE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 220
#define RSCMWINS_ATTR_CLEAN_EVENT_LOG                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 224
#define RSCMWINS_ATTR_QUERY_UE_INFO_IMEI                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 226
#define RSCMWINS_ATTR_QUERY_UE_INFO_IMSI                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 227
#define RSCMWINS_ATTR_QUERY_UE_INFO_DEFAULT_BEARERS_CATALOG                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 228
#define RSCMWINS_ATTR_QUERY_UE_INFO_ASSIGNED_IP_ADDRESSES                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 229
#define RSCMWINS_ATTR_QUERY_UE_CAPABILITIES_INACTIVITY_MONITOR              RS_SPECIFIC_PUBLIC_ATTR_BASE + 230
#define RSCMWINS_ATTR_QUERY_UE_CAPABILITIES_RELEASE_ASSISTANCE_INDICATION   RS_SPECIFIC_PUBLIC_ATTR_BASE + 231
#define RSCMWINS_ATTR_QUERY_UE_CAPABILITIES_MULTI_TONE                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 232
#define RSCMWINS_ATTR_QUERY_UE_CAPABILITIES_MULTI_CARRIER                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 233
#define RSCMWINS_ATTR_QUERY_UE_CAPABILITIES_USER_PLANE_C_IOT_OPTIMIZATION   RS_SPECIFIC_PUBLIC_ATTR_BASE + 234
#define RSCMWINS_ATTR_QUERY_UE_CAPABILITIES_TRANSFER_CATEGORY               RS_SPECIFIC_PUBLIC_ATTR_BASE + 235
#define RSCMWINS_ATTR_QUERY_UE_CAPABILITIES_MULTIPLE_DRB                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 236
#define RSCMWINS_ATTR_QUERY_UE_CAPABILITIES_MULTI_CARRIER_PAGING            RS_SPECIFIC_PUBLIC_ATTR_BASE + 237
#define RSCMWINS_ATTR_QUERY_UE_CAPABILITIES_MAX_ROHC_CONTEXT_SESSIONS       RS_SPECIFIC_PUBLIC_ATTR_BASE + 238
#define RSCMWINS_ATTR_QUERY_UE_CAPABILITIES_ROHC_PROFILES                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 239
#define RSCMWINS_ATTR_QUERY_UE_CAPABILITIES_REFERENCE_ROHC_PROFILE_NAMES    RS_SPECIFIC_PUBLIC_ATTR_BASE + 240
#define RSCMWINS_ATTR_QUERY_UE_CAPABILITIES_INTERFERENCE_RANDOMIZATION      RS_SPECIFIC_PUBLIC_ATTR_BASE + 242
#define RSCMWINS_ATTR_QUERY_UE_CAPABILITIES_UE_SUPPORTS_MULTI_CARRIER       RS_SPECIFIC_PUBLIC_ATTR_BASE + 243
#define RSCMWINS_ATTR_QUERY_UE_CAPABILITIES_MULTI_CARRIER_NPRACH            RS_SPECIFIC_PUBLIC_ATTR_BASE + 244
#define RSCMWINS_ATTR_QUERY_UE_CAPABILITIES_NPUSCH_MULTI_TONE               RS_SPECIFIC_PUBLIC_ATTR_BASE + 245
#define RSCMWINS_ATTR_QUERY_UE_CAPABILITIES_TWO_HARQ_PROCESSES              RS_SPECIFIC_PUBLIC_ATTR_BASE + 246
#define RSCMWINS_ATTR_QUERY_UE_CAPABILITIES_RELEASE                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 247
#define RSCMWINS_ATTR_QUERY_UE_CAPABILITIES_MULTIPLE_NS_PMAX                RS_SPECIFIC_PUBLIC_ATTR_BASE + 250
#define RSCMWINS_ATTR_QUERY_UE_CAPABILITIES_POWER_CLASS_14_DBM              RS_SPECIFIC_PUBLIC_ATTR_BASE + 252
#define RSCMWINS_ATTR_QUERY_UE_CAPABILITIES_PAGING_WAKE_UP_SIGNAL           RS_SPECIFIC_PUBLIC_ATTR_BASE + 378
#define RSCMWINS_ATTR_QUERY_UE_CAPABILITIES_PAGING_WUS_MIN_GAP              RS_SPECIFIC_PUBLIC_ATTR_BASE + 379
#define RSCMWINS_ATTR_QUERY_UE_CAPABILITIES_EARLY_DATA_UP                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 482
#define RSCMWINS_ATTR_QUERY_UE_CAPABILITIES_SR_WITH_HARQ                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 483
#define RSCMWINS_ATTR_QUERY_UE_CAPABILITIES_SR_WITHOUT_HARQ                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 484
#define RSCMWINS_ATTR_UE_MEASUREMENT_REPORT_ENABLED                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 380
#define RSCMWINS_ATTR_UE_MEASUREMENT_REPORT_RSRP_INDEX                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 381
#define RSCMWINS_ATTR_UE_MEASUREMENT_REPORT_RSRP_RANGE                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 382
#define RSCMWINS_ATTR_UE_MEASUREMENT_REPORT_RSRQ_INDEX                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 383
#define RSCMWINS_ATTR_UE_MEASUREMENT_REPORT_RSRQ_RANGE                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 384
#define RSCMWINS_ATTR_CONFIGURE_RF_OUTPUT_ATTENUATION                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 253
#define RSCMWINS_ATTR_CONFIGURE_RF_INPUT_ATTENUATION                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 254
#define RSCMWINS_ATTR_CONFIGURE_RF_EXTERNAL_TIME_DELAY_INPUT                RS_SPECIFIC_PUBLIC_ATTR_BASE + 256
#define RSCMWINS_ATTR_CONFIGURE_RF_EXTERNAL_TIME_DELAY_OUTPUT               RS_SPECIFIC_PUBLIC_ATTR_BASE + 257
#define RSCMWINS_ATTR_CONFIGURE_RF_SIGNAL_OPERATING_BAND                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 258
#define RSCMWINS_ATTR_CONFIGURE_RF_CHANNEL_DL                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 259
#define RSCMWINS_ATTR_CONFIGURE_RF_CHANNEL_UL                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 260
#define RSCMWINS_ATTR_CONFIGURE_RF_FREQUENCY_OFFSET_DL                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 261
#define RSCMWINS_ATTR_CONFIGURE_RF_FREQUENCY_OFFSET_UL                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 262
#define RSCMWINS_ATTR_CONFIGURE_RF_ENP_MODE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 263
#define RSCMWINS_ATTR_CONFIGURE_RF_ENP_POWER                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 264
#define RSCMWINS_ATTR_CONFIGURE_RF_ENP_USER_MARGIN                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 265
#define RSCMWINS_ATTR_CONFIGURE_RF_MIXER_LEVEL_OFFSET                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 266
#define RSCMWINS_ATTR_QUERY_RF_USER_DEFINED_CHANNEL_UL_MAXIMUM              RS_SPECIFIC_PUBLIC_ATTR_BASE + 267
#define RSCMWINS_ATTR_QUERY_RF_USER_DEFINED_FREQUENCY_DL_MAXIMUM            RS_SPECIFIC_PUBLIC_ATTR_BASE + 268
#define RSCMWINS_ATTR_QUERY_RF_USER_DEFINED_FREQUENCY_UL_MAXIMUM            RS_SPECIFIC_PUBLIC_ATTR_BASE + 269
#define RSCMWINS_ATTR_QUERY_RF_USER_DEFINED_FREQUENCY_UL_MINIMUM            RS_SPECIFIC_PUBLIC_ATTR_BASE + 270
#define RSCMWINS_ATTR_CONFIGURE_DL_POWER_NRS_EPRE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 272
#define RSCMWINS_ATTR_CONFIGURE_DL_POWER_OCNG                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 273
#define RSCMWINS_ATTR_CONFIGURE_DL_POWER_AWGN                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 274
#define RSCMWINS_ATTR_CONFIGURE_UL_POWER_CONTROL_NOMINAL_POWER              RS_SPECIFIC_PUBLIC_ATTR_BASE + 275
#define RSCMWINS_ATTR_QUERY_UL_POWER_CONTROL_NPRACH_PREAMBLE_POWER          RS_SPECIFIC_PUBLIC_ATTR_BASE + 276
#define RSCMWINS_ATTR_QUERY_UL_POWER_CONTROL_NPUSCH_FORMAT_POWER            RS_SPECIFIC_PUBLIC_ATTR_BASE + 277
#define RSCMWINS_ATTR_CONFIGURE_UL_POWER_CONTROL_MAXIMUM_UE_POWER           RS_SPECIFIC_PUBLIC_ATTR_BASE + 278
#define RSCMWINS_ATTR_CONFIGURE_UL_POWER_ADVANCED_ENABLED                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 279
#define RSCMWINS_ATTR_CONFIGURE_UL_POWER_ADVANCED_NRS_POWER                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 280
#define RSCMWINS_ATTR_QUERY_UL_POWER_ADVANCED_PATHLOSS                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 281
#define RSCMWINS_ATTR_CONFIGURE_UL_POWER_ADVANCED_PIR_TARGET_POWER          RS_SPECIFIC_PUBLIC_ATTR_BASE + 282
#define RSCMWINS_ATTR_CONFIGURE_UL_POWER_ADVANCED_P0_NOMINAL_NPUSCH         RS_SPECIFIC_PUBLIC_ATTR_BASE + 283
#define RSCMWINS_ATTR_CONFIGURE_UL_POWER_ADVANCED_PATHLOSS_COMPENSATION_ALPHA RS_SPECIFIC_PUBLIC_ATTR_BASE + 284
#define RSCMWINS_ATTR_CONFIGURE_PHYSICAL_CELL_DUPLEX_MODE                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 285
#define RSCMWINS_ATTR_CONFIGURE_PHYSICAL_CELL_SUBCARRIER_SPACING            RS_SPECIFIC_PUBLIC_ATTR_BASE + 286
#define RSCMWINS_ATTR_CONFIGURE_PHYSICAL_CELL_ID                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 287
#define RSCMWINS_ATTR_CONFIGURE_PHYSICAL_CELL_OPERATION_MODE                RS_SPECIFIC_PUBLIC_ATTR_BASE + 288
#define RSCMWINS_ATTR_CONFIGURE_PHYSICAL_CELL_ENABLE_FLEXIBLE_UL_DL_SEPARATION RS_SPECIFIC_PUBLIC_ATTR_BASE + 385
#define RSCMWINS_ATTR_CONFIGURE_PHYSICAL_CELL_BANDWIDTH                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 289
#define RSCMWINS_ATTR_CONFIGURE_PHYSICAL_CELL_CONTROL_REGION_SIZE           RS_SPECIFIC_PUBLIC_ATTR_BASE + 290
#define RSCMWINS_ATTR_CONFIGURE_PHYSICAL_CELL_POWER_OFFSET                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 291
#define RSCMWINS_ATTR_CONFIGURE_PHYSICAL_CELL_INBAND_PCI                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 292
#define RSCMWINS_ATTR_CONFIGURE_PHYSICAL_CELL_INBAND_CARRIER_POSITION       RS_SPECIFIC_PUBLIC_ATTR_BASE + 293
#define RSCMWINS_ATTR_CONFIGURE_PHYSICAL_CELL_INBAND_UPLINK_CARRIER_POSITION_ENABLED RS_SPECIFIC_PUBLIC_ATTR_BASE + 386
#define RSCMWINS_ATTR_CONFIGURE_PHYSICAL_CELL_INBAND_UPLINK_CARRIER_POSITION RS_SPECIFIC_PUBLIC_ATTR_BASE + 387
#define RSCMWINS_ATTR_CONFIGURE_PHYSICAL_CELL_GUARD_BAND_POSITION           RS_SPECIFIC_PUBLIC_ATTR_BASE + 294
#define RSCMWINS_ATTR_CONFIGURE_PHYSICAL_CELL_GUARD_BAND_UPLINK_POSITION_ENABLED RS_SPECIFIC_PUBLIC_ATTR_BASE + 388
#define RSCMWINS_ATTR_CONFIGURE_PHYSICAL_CELL_GUARD_BAND_UPLINK_POSITION    RS_SPECIFIC_PUBLIC_ATTR_BASE + 389
#define RSCMWINS_ATTR_QUERY_PHYSICAL_CELL_LTE_FREQUENCY_DL                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 295
#define RSCMWINS_ATTR_QUERY_PHYSICAL_CELL_LTE_FREQUENCY_UL                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 296
#define RSCMWINS_ATTR_QUERY_PHYSICAL_CELL_CHANNEL_RASTER_OFFSET_DL          RS_SPECIFIC_PUBLIC_ATTR_BASE + 297
#define RSCMWINS_ATTR_QUERY_PHYSICAL_CELL_CHANNEL_RASTER_OFFSET_UL          RS_SPECIFIC_PUBLIC_ATTR_BASE + 298
#define RSCMWINS_ATTR_CONFIGURE_PHYSICAL_CELL_NO_RESPONSE_TO_PREAMBLES      RS_SPECIFIC_PUBLIC_ATTR_BASE + 299
#define RSCMWINS_ATTR_CONFIGURE_PHYSICAL_CELL_POWER_RAMPING                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 300
#define RSCMWINS_ATTR_CONFIGURE_PHYSICAL_CELL_PREAMBLE_FORMAT               RS_SPECIFIC_PUBLIC_ATTR_BASE + 301
#define RSCMWINS_ATTR_CONFIGURE_PHYSICAL_CELL_MAX_TRANSMISSIONS             RS_SPECIFIC_PUBLIC_ATTR_BASE + 302
#define RSCMWINS_ATTR_CONFIGURE_PHYSICAL_CELL_CE_NUMBER_OF_THRESHOLD        RS_SPECIFIC_PUBLIC_ATTR_BASE + 390
#define RSCMWINS_ATTR_CONFIGURE_PHYSICAL_CELL_CE_REPETITIONS_PER_PREAMBLE_0 RS_SPECIFIC_PUBLIC_ATTR_BASE + 391
#define RSCMWINS_ATTR_CONFIGURE_PHYSICAL_CELL_CE_REPETITIONS_PER_PREAMBLE_1 RS_SPECIFIC_PUBLIC_ATTR_BASE + 392
#define RSCMWINS_ATTR_CONFIGURE_PHYSICAL_CELL_CE_REPETITIONS_PER_PREAMBLE_2 RS_SPECIFIC_PUBLIC_ATTR_BASE + 393
#define RSCMWINS_ATTR_CONFIGURE_PHYSICAL_CELL_CE_NPDCCH_MAX_REPETITIONS_0   RS_SPECIFIC_PUBLIC_ATTR_BASE + 394
#define RSCMWINS_ATTR_CONFIGURE_PHYSICAL_CELL_CE_NPDCCH_MAX_REPETITIONS_1   RS_SPECIFIC_PUBLIC_ATTR_BASE + 395
#define RSCMWINS_ATTR_CONFIGURE_PHYSICAL_CELL_CE_NPDCCH_MAX_REPETITIONS_2   RS_SPECIFIC_PUBLIC_ATTR_BASE + 396
#define RSCMWINS_ATTR_CONFIGURE_PHYSICAL_CELL_CE_RSRP_THRESHOLD_1           RS_SPECIFIC_PUBLIC_ATTR_BASE + 397
#define RSCMWINS_ATTR_CONFIGURE_PHYSICAL_CELL_CE_RSRP_THRESHOLD_2           RS_SPECIFIC_PUBLIC_ATTR_BASE + 398
#define RSCMWINS_ATTR_QUERY_PHYSICAL_CELL_CE_LEVEL_REPORT                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 399
#define RSCMWINS_ATTR_CONFIGURE_PHYSICAL_CELL_WUS_ENABLED                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 400
#define RSCMWINS_ATTR_CONFIGURE_PHYSICAL_CELL_WUS_DISABLE_PAGING            RS_SPECIFIC_PUBLIC_ATTR_BASE + 401
#define RSCMWINS_ATTR_CONFIGURE_PHYSICAL_CELL_WUS_MAX_DURATION_FACTOR       RS_SPECIFIC_PUBLIC_ATTR_BASE + 402
#define RSCMWINS_ATTR_CONFIGURE_PHYSICAL_CELL_WUS_NUM_POS                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 403
#define RSCMWINS_ATTR_CONFIGURE_PHYSICAL_CELL_WUS_FIRST_PO_POSITION         RS_SPECIFIC_PUBLIC_ATTR_BASE + 404
#define RSCMWINS_ATTR_CONFIGURE_PHYSICAL_CELL_WUS_NO_OF_DRX_CYCLES_RELAXED  RS_SPECIFIC_PUBLIC_ATTR_BASE + 405
#define RSCMWINS_ATTR_CONFIGURE_PHYSICAL_CELL_WUS_TIME_OFFSET_DRX           RS_SPECIFIC_PUBLIC_ATTR_BASE + 406
#define RSCMWINS_ATTR_CONFIGURE_PHYSICAL_CELL_WUS_TIME_OFFSET_EDRX_SHORT    RS_SPECIFIC_PUBLIC_ATTR_BASE + 407
#define RSCMWINS_ATTR_CONFIGURE_PHYSICAL_CELL_WUS_TIME_OFFSET_EDRX_LONG_ENABLED RS_SPECIFIC_PUBLIC_ATTR_BASE + 408
#define RSCMWINS_ATTR_CONFIGURE_PHYSICAL_CELL_WUS_TIME_OFFSET_EDRX_LONG     RS_SPECIFIC_PUBLIC_ATTR_BASE + 409
#define RSCMWINS_ATTR_CONFIGURE_NETWORK_IDENTITY_MCC                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 303
#define RSCMWINS_ATTR_CONFIGURE_NETWORK_IDENTITY_MNC_DIGITS                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 304
#define RSCMWINS_ATTR_CONFIGURE_NETWORK_IDENTITY_MNC                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 305
#define RSCMWINS_ATTR_CONFIGURE_NETWORK_IDENTITY_TAC                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 306
#define RSCMWINS_ATTR_CONFIGURE_NETWORK_IDENTITY_CID_EUTRAN                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 307
#define RSCMWINS_ATTR_CONFIGURE_NETWORK_IDENTITY_UE_IMSI                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 308
#define RSCMWINS_ATTR_CONFIGURE_NETWORK_SECURITY_AUTHENTICATION             RS_SPECIFIC_PUBLIC_ATTR_BASE + 309
#define RSCMWINS_ATTR_CONFIGURE_NETWORK_SECURITY_ENABLED                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 310
#define RSCMWINS_ATTR_CONFIGURE_NETWORK_SECURITY_ALGORITHM                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 311
#define RSCMWINS_ATTR_CONFIGURE_NETWORK_SECURITY_SECRET_KEY                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 312
#define RSCMWINS_ATTR_CONFIGURE_NETWORK_SECURITY_MILENAGE                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 313
#define RSCMWINS_ATTR_CONFIGURE_NETWORK_SECURITY_OPC                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 314
#define RSCMWINS_ATTR_CONFIGURE_NETWORK_TIMER_OUT_OF_SYNC                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 315
#define RSCMWINS_ATTR_CONFIGURE_NETWORK_TIMER_T3324_ENABLED                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 316
#define RSCMWINS_ATTR_CONFIGURE_NETWORK_TIMER_T3324_VALUE                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 317
#define RSCMWINS_ATTR_CONFIGURE_NETWORK_TIMER_T3412_ENABLED                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 318
#define RSCMWINS_ATTR_CONFIGURE_NETWORK_TIMER_T3412_VALUE                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 319
#define RSCMWINS_ATTR_CONFIGURE_NETWORK_TIMER_ADDITIONAL_T3412              RS_SPECIFIC_PUBLIC_ATTR_BASE + 320
#define RSCMWINS_ATTR_CONFIGURE_NETWORK_TIME_DAYLIGHT_SAVING_TIME_ENABLED   RS_SPECIFIC_PUBLIC_ATTR_BASE + 321
#define RSCMWINS_ATTR_CONFIGURE_NETWORK_TIME_DAYLIGHT_SAVING_TIME_VALUE     RS_SPECIFIC_PUBLIC_ATTR_BASE + 322
#define RSCMWINS_ATTR_CONFIGURE_NETWORK_TIME_LOCAL_TIME_ZONE_OFFSET         RS_SPECIFIC_PUBLIC_ATTR_BASE + 323
#define RSCMWINS_ATTR_CONFIGURE_NETWORK_TIME_SEND_TIME                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 324
#define RSCMWINS_ATTR_CONFIGURE_NETWORK_TIME_SEND_NOW                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 325
#define RSCMWINS_ATTR_CONFIGURE_NETWORK_TIME_SOURCE                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 328
#define RSCMWINS_ATTR_CONFIGURE_NETWORK_SYNC_ZONE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 329
#define RSCMWINS_ATTR_CONFIGURE_NETWORK_SYNC_OFFSET                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 330
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_GENERAL_CONNECTION_TYPE          RS_SPECIFIC_PUBLIC_ATTR_BASE + 331
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_GENERAL_TEST_MODE_ENABLED        RS_SPECIFIC_PUBLIC_ATTR_BASE + 332
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_GENERAL_TEST_MODE_IP_VERSION     RS_SPECIFIC_PUBLIC_ATTR_BASE + 333
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_GENERAL_C_IOT                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 334
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_GENERAL_DATA_APPLICATION_MODE_IP_VERSION RS_SPECIFIC_PUBLIC_ATTR_BASE + 335
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_GENERAL_DESTINATION_SERVER_IP_ADDRESS RS_SPECIFIC_PUBLIC_ATTR_BASE + 410
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_GENERAL_DESTINATION_SERVER_PORT  RS_SPECIFIC_PUBLIC_ATTR_BASE + 411
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_GENERAL_RRC_KEEP                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 336
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_GENERAL_RRC_TIMER                RS_SPECIFIC_PUBLIC_ATTR_BASE + 337
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_GENERAL_SCHEDULING_TYPE          RS_SPECIFIC_PUBLIC_ATTR_BASE + 338
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_GENERAL_DEFAULT_PAGING_CYCLE     RS_SPECIFIC_PUBLIC_ATTR_BASE + 339
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_GENERAL_PCCH_CONFIG_NB           RS_SPECIFIC_PUBLIC_ATTR_BASE + 340
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_GENERAL_MODIFICATION_PERIOD_COEFFICIENT RS_SPECIFIC_PUBLIC_ATTR_BASE + 341
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_GENERAL_PSM_ALLOWED              RS_SPECIFIC_PUBLIC_ATTR_BASE + 342
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_GENERAL_PAGING_IDLE_MODE         RS_SPECIFIC_PUBLIC_ATTR_BASE + 343
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_GENERAL_PAGING_TIME_WINDOW       RS_SPECIFIC_PUBLIC_ATTR_BASE + 344
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_GENERAL_CYCLE_LENGTH             RS_SPECIFIC_PUBLIC_ATTR_BASE + 345
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_GENERAL_RRC_ALLOW_PAGING_AFTER_SI_TRANSMISSION RS_SPECIFIC_PUBLIC_ATTR_BASE + 412
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_GENERAL_INTERFERENCE_RANDOMIZATION RS_SPECIFIC_PUBLIC_ATTR_BASE + 413
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_GENERAL_PAGING_COLLISION_REPORT  RS_SPECIFIC_PUBLIC_ATTR_BASE + 414
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_USER_PATTERN                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 351
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_HARQ_ENABLED                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 357
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_HARQ_MAX_NUMBER_OF_TRANSMISSIONS RS_SPECIFIC_PUBLIC_ATTR_BASE + 358
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_HARQ_PROCESSES                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 359
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_NAC_13_ENABLED                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 415
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_NAC_13_DL_CHANNEL_FREQUENCY      RS_SPECIFIC_PUBLIC_ATTR_BASE + 416
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_NAC_13_UL_CHANNEL_FREQUENCY      RS_SPECIFIC_PUBLIC_ATTR_BASE + 417
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_NAC_13_DL_BITMAP                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 418
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_NAC_13_DL_BITMAP_EXPLICIT        RS_SPECIFIC_PUBLIC_ATTR_BASE + 419
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_NAC_13_DL_GAP                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 420
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_NAC_13_GAP_THRESHOLD             RS_SPECIFIC_PUBLIC_ATTR_BASE + 421
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_NAC_13_GAP_PERIODICITY           RS_SPECIFIC_PUBLIC_ATTR_BASE + 422
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_NAC_13_GAP_DURATION_COEFFICIENT  RS_SPECIFIC_PUBLIC_ATTR_BASE + 423
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_NAC_13_NRS_POWER_OFFSET          RS_SPECIFIC_PUBLIC_ATTR_BASE + 424
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_NAC_14_PAGING_ENABLED            RS_SPECIFIC_PUBLIC_ATTR_BASE + 425
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_NAC_14_PAGING_WEIGHT_ANCHOR      RS_SPECIFIC_PUBLIC_ATTR_BASE + 426
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_NAC_14_PAGING_WEIGHT_ANCHOR_ENABLED RS_SPECIFIC_PUBLIC_ATTR_BASE + 485
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_NAC_14_PAGING_CARRIER_1_ENABLED  RS_SPECIFIC_PUBLIC_ATTR_BASE + 427
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_NAC_14_PAGING_CARRIER_1_DL_CHANNEL_FREQUENCY RS_SPECIFIC_PUBLIC_ATTR_BASE + 428
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_NAC_14_PAGING_CARRIER_1_DL_CHANNEL_OFFSET RS_SPECIFIC_PUBLIC_ATTR_BASE + 429
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_NAC_14_PAGING_CARRIER_1_DL_BITMAP RS_SPECIFIC_PUBLIC_ATTR_BASE + 430
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_NAC_14_PAGING_CARRIER_1_DL_BITMAP_EXPLICIT RS_SPECIFIC_PUBLIC_ATTR_BASE + 431
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_NAC_14_PAGING_CARRIER_1_DL_GAP   RS_SPECIFIC_PUBLIC_ATTR_BASE + 432
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_NAC_14_PAGING_CARRIER_1_GAP_THRESHOLD RS_SPECIFIC_PUBLIC_ATTR_BASE + 433
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_NAC_14_PAGING_CARRIER_1_GAP_PERIODICITY RS_SPECIFIC_PUBLIC_ATTR_BASE + 434
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_NAC_14_PAGING_CARRIER_1_GAP_DURATION_COEFFICIENT RS_SPECIFIC_PUBLIC_ATTR_BASE + 435
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_NAC_14_PAGING_CARRIER_1_NRS_POWER_OFFSET RS_SPECIFIC_PUBLIC_ATTR_BASE + 436
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_NAC_14_PAGING_CARRIER_1_PCCH_ENABLED RS_SPECIFIC_PUBLIC_ATTR_BASE + 437
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_NAC_14_PAGING_CARRIER_1_PCCH_NUM_OF_REPETITIONS RS_SPECIFIC_PUBLIC_ATTR_BASE + 438
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_NAC_14_PAGING_CARRIER_1_PCCH_PAGING_WEIGHT RS_SPECIFIC_PUBLIC_ATTR_BASE + 439
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_NAC_14_PAGING_CARRIER_1_PCCH_PAGING_WEIGHT_ENABLED RS_SPECIFIC_PUBLIC_ATTR_BASE + 486
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_NAC_14_PAGING_CARRIER_1_WUS_ENABLED RS_SPECIFIC_PUBLIC_ATTR_BASE + 440
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_NAC_14_PAGING_CARRIER_1_MAX_DURATION_FACTOR RS_SPECIFIC_PUBLIC_ATTR_BASE + 441
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_NAC_14_PAGING_CARRIER_2_ENABLED  RS_SPECIFIC_PUBLIC_ATTR_BASE + 442
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_NAC_14_PAGING_CARRIER_2_DL_CHANNEL_FREQUENCY RS_SPECIFIC_PUBLIC_ATTR_BASE + 443
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_NAC_14_PAGING_CARRIER_2_DL_CHANNEL_OFFSET RS_SPECIFIC_PUBLIC_ATTR_BASE + 444
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_NAC_14_PAGING_CARRIER_2_DL_BITMAP RS_SPECIFIC_PUBLIC_ATTR_BASE + 445
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_NAC_14_PAGING_CARRIER_2_DL_BITMAP_EXPLICIT RS_SPECIFIC_PUBLIC_ATTR_BASE + 446
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_NAC_14_PAGING_CARRIER_2_DL_GAP   RS_SPECIFIC_PUBLIC_ATTR_BASE + 447
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_NAC_14_PAGING_CARRIER_2_GAP_THRESHOLD RS_SPECIFIC_PUBLIC_ATTR_BASE + 448
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_NAC_14_PAGING_CARRIER_2_GAP_PERIODICITY RS_SPECIFIC_PUBLIC_ATTR_BASE + 449
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_NAC_14_PAGING_CARRIER_2_GAP_DURATION_COEFFICIENT RS_SPECIFIC_PUBLIC_ATTR_BASE + 450
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_NAC_14_PAGING_CARRIER_2_NRS_POWER_OFFSET RS_SPECIFIC_PUBLIC_ATTR_BASE + 451
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_NAC_14_PAGING_CARRIER_2_PCCH_ENABLED RS_SPECIFIC_PUBLIC_ATTR_BASE + 452
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_NAC_14_PAGING_CARRIER_2_PCCH_NUM_OF_REPETITIONS RS_SPECIFIC_PUBLIC_ATTR_BASE + 453
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_NAC_14_PAGING_CARRIER_2_PCCH_PAGING_WEIGHT RS_SPECIFIC_PUBLIC_ATTR_BASE + 454
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_NAC_14_PAGING_CARRIER_2_PCCH_PAGING_WEIGHT_ENABLED RS_SPECIFIC_PUBLIC_ATTR_BASE + 487
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_NAC_14_PAGING_CARRIER_2_WUS_ENABLED RS_SPECIFIC_PUBLIC_ATTR_BASE + 455
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_NAC_14_PAGING_CARRIER_2_MAX_DURATION_FACTOR RS_SPECIFIC_PUBLIC_ATTR_BASE + 456
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_NAC_14_RACH_ENABLED              RS_SPECIFIC_PUBLIC_ATTR_BASE + 457
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_NAC_14_RACH_NPRACH_PROBABILITY_ANCHOR_ENABLED RS_SPECIFIC_PUBLIC_ATTR_BASE + 458
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_NAC_14_RACH_NPRACH_PROBABILITY_ANCHOR RS_SPECIFIC_PUBLIC_ATTR_BASE + 459
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_NAC_14_CARRIER_1_RACH_ENABLED    RS_SPECIFIC_PUBLIC_ATTR_BASE + 460
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_NAC_14_RACH_CARRIER_1_UL_CHANNEL_FREQUENCY RS_SPECIFIC_PUBLIC_ATTR_BASE + 461
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_NAC_14_RACH_CARRIER_1_UL_CHANNEL_OFFSET RS_SPECIFIC_PUBLIC_ATTR_BASE + 462
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_NAC_14_CARRIER_2_RACH_ENABLED    RS_SPECIFIC_PUBLIC_ATTR_BASE + 463
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_NAC_14_RACH_CARRIER_2_UL_CHANNEL_FREQUENCY RS_SPECIFIC_PUBLIC_ATTR_BASE + 464
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_NAC_14_RACH_CARRIER_2_UL_CHANNEL_OFFSET RS_SPECIFIC_PUBLIC_ATTR_BASE + 465
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_NPDCCH_MAX_NO_REPETITIONS_RMAX   RS_SPECIFIC_PUBLIC_ATTR_BASE + 466
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_NPDCCH_NO_REPETITIONS            RS_SPECIFIC_PUBLIC_ATTR_BASE + 467
#define RSCMWINS_ATTR_QUERY_CONNECTION_NPDCCH_NO_REPETITIONS                RS_SPECIFIC_PUBLIC_ATTR_BASE + 468
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_NPDCCH_START_SF                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 469
#define RSCMWINS_ATTR_QUERY_CONNECTION_NPDCCH_PERIOD                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 470
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_NPDCCH_OFFSET                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 471
#define RSCMWINS_ATTR_QUERY_CONNECTION_NPDCCH_OFFSET                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 472
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_NPDCCH_CSS_MAX_NO_REPETITIONS_RMAX RS_SPECIFIC_PUBLIC_ATTR_BASE + 473
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_CONNECTED_DRX_ENABLED            RS_SPECIFIC_PUBLIC_ATTR_BASE + 474
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_CONNECTED_DRX_ON_DURATION_TIMER  RS_SPECIFIC_PUBLIC_ATTR_BASE + 475
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_CONNECTED_DRX_INACTIVITY_TIMER   RS_SPECIFIC_PUBLIC_ATTR_BASE + 476
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_CONNECTED_DRX_RETRANSMISSION_TIMER RS_SPECIFIC_PUBLIC_ATTR_BASE + 477
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_CONNECTED_DRX_CYCLE              RS_SPECIFIC_PUBLIC_ATTR_BASE + 478
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_CONNECTED_DRX_START_OFFSET       RS_SPECIFIC_PUBLIC_ATTR_BASE + 479
#define RSCMWINS_ATTR_CONFIGURE_CONNECTION_CONNECTED_DRX_UL_RETRANS_TIMER   RS_SPECIFIC_PUBLIC_ATTR_BASE + 480
#define RSCMWINS_ATTR_SCHEDULING_REQUEST_WITH_HARQ                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 488
#define RSCMWINS_ATTR_SCHEDULING_REQUEST_WITHOUT_HARQ                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 489
#define RSCMWINS_ATTR_SCHEDULING_REQUEST_WITHOUT_HARQ_ALPHA                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 490
#define RSCMWINS_ATTR_SCHEDULING_REQUEST_WITHOUT_HARQ_CARRIER_INDEX         RS_SPECIFIC_PUBLIC_ATTR_BASE + 491
#define RSCMWINS_ATTR_SCHEDULING_REQUEST_WITHOUT_HARQ_RESOURCE_INDEX        RS_SPECIFIC_PUBLIC_ATTR_BASE + 492
#define RSCMWINS_ATTR_SCHEDULING_REQUEST_WITHOUT_HARQ_SR                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 493
#define RSCMWINS_ATTR_SCHEDULING_REQUEST_WITHOUT_HARQ_SUBCARRIER_INDEX_FORMAT RS_SPECIFIC_PUBLIC_ATTR_BASE + 494
#define RSCMWINS_ATTR_SCHEDULING_REQUEST_WITHOUT_HARQ_SUBCARRIER_INDEX_FORMAT_VALUE RS_SPECIFIC_PUBLIC_ATTR_BASE + 495
#define RSCMWINS_ATTR_SCHEDULING_REQUEST_NO_RESPONSE_TO_SR_ENABLED          RS_SPECIFIC_PUBLIC_ATTR_BASE + 496
#define RSCMWINS_ATTR_INITIATE_BLER_MEASUREMENT                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 360
#define RSCMWINS_ATTR_STOP_BLER_MEASUREMENT                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 361
#define RSCMWINS_ATTR_ABORT_BLER_MEASUREMENT                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 362
#define RSCMWINS_ATTR_QUERY_BLER_STATE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 363
#define RSCMWINS_ATTR_CONFIGURE_BLER_TIMEOUT                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 365
#define RSCMWINS_ATTR_CONFIGURE_BLER_REPETITION                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 366
#define RSCMWINS_ATTR_CONFIGURE_BLER_SAMPLES                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 367
#define RSCMWINS_ATTR_CONFIGURE_BLER_ALGORITHM                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 368
#define RSCMWINS_ATTR_EDT_ENABLED                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 497
#define RSCMWINS_ATTR_EDT_RESOURCE_NUMBERS                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 498
#define RSCMWINS_ATTR_EDT_USER_PLAN_ENABLED                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 499
#define RSCMWINS_ATTR_EDT_SMALL_TBS_ENABLED                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 500
#define RSCMWINS_ATTR_EDT_SMALL_TBS_SUBSET_ENABLED                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 501
#define RSCMWINS_ATTR_SYSTEM_VERSION                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 372
#define RSCMWINS_ATTR_SYSTEM_ERROR                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 373
#define RSCMWINS_ATTR_SYSTEM_ALL_ERRORS                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 374
#define RSCMWINS_ATTR_SYSTEM_PRESET                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 375
#define RSCMWINS_ATTR_PROCESS_ALL_PREVIOUS_COMMANDS                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 376
#define RSCMWINS_ATTR_ID_QUERY_RESPONSE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 377

// rscmwins_rngENPMode
#define RSCMWINS_VAL_ENP_MODE_MANUAL                                        0
#define RSCMWINS_VAL_ENP_MODE_ULPC                                          1

// rscmwins_rngRRCState
#define RSCMWINS_VAL_RRC_STATE_IDLE                                         0
#define RSCMWINS_VAL_RRC_STATE_CONN                                         1

// rscmwins_rngConfigurePSAction
#define RSCMWINS_VAL_CONFIGURE_PS_ACTION_CONN                               0
#define RSCMWINS_VAL_CONFIGURE_PS_ACTION_DISC                               1
#define RSCMWINS_VAL_CONFIGURE_PS_ACTION_SMS                                2
#define RSCMWINS_VAL_CONFIGURE_PS_ACTION_DETACH                             3
#define RSCMWINS_VAL_CONFIGURE_PS_ACTION_RESUME                             4
#define RSCMWINS_VAL_CONFIGURE_PS_ACTION_SUSPEND                            5

// rscmwins_rngOperatingBand
#define RSCMWINS_VAL_OB_UDEF                                                0
#define RSCMWINS_VAL_OB_1                                                   1
#define RSCMWINS_VAL_OB_2                                                   2
#define RSCMWINS_VAL_OB_3                                                   3
#define RSCMWINS_VAL_OB_4                                                   4
#define RSCMWINS_VAL_OB_5                                                   5
#define RSCMWINS_VAL_OB_7                                                   6
#define RSCMWINS_VAL_OB_8                                                   7
#define RSCMWINS_VAL_OB_9                                                   8
#define RSCMWINS_VAL_OB_10                                                  9
#define RSCMWINS_VAL_OB_11                                                  10
#define RSCMWINS_VAL_OB_12                                                  11
#define RSCMWINS_VAL_OB_13                                                  12
#define RSCMWINS_VAL_OB_14                                                  13
#define RSCMWINS_VAL_OB_17                                                  14
#define RSCMWINS_VAL_OB_18                                                  15
#define RSCMWINS_VAL_OB_19                                                  16
#define RSCMWINS_VAL_OB_20                                                  17
#define RSCMWINS_VAL_OB_21                                                  18
#define RSCMWINS_VAL_OB_22                                                  19
#define RSCMWINS_VAL_OB_24                                                  20
#define RSCMWINS_VAL_OB_25                                                  21
#define RSCMWINS_VAL_OB_26                                                  22
#define RSCMWINS_VAL_OB_27                                                  23
#define RSCMWINS_VAL_OB_28                                                  24
#define RSCMWINS_VAL_OB_30                                                  25
#define RSCMWINS_VAL_OB_31                                                  26
#define RSCMWINS_VAL_OB_65                                                  27
#define RSCMWINS_VAL_OB_66                                                  28
#define RSCMWINS_VAL_OB_68                                                  29
#define RSCMWINS_VAL_OB_70                                                  30
#define RSCMWINS_VAL_OB_71                                                  31
#define RSCMWINS_VAL_OB_72                                                  32
#define RSCMWINS_VAL_OB_73                                                  33
#define RSCMWINS_VAL_OB_74                                                  34
#define RSCMWINS_VAL_OB_85                                                  35

// rscmwins_rngPathlossCompAlpha
#define RSCMWINS_VAL_PCA_ZERO                                               0
#define RSCMWINS_VAL_PCA_DOT4                                               1
#define RSCMWINS_VAL_PCA_DOT5                                               2
#define RSCMWINS_VAL_PCA_DOT6                                               3
#define RSCMWINS_VAL_PCA_DOT7                                               4
#define RSCMWINS_VAL_PCA_DOT8                                               5
#define RSCMWINS_VAL_PCA_DOT9                                               6
#define RSCMWINS_VAL_PCA_ONE                                                7

// rscmwins_rngPhysicalCellDuplexMode
#define RSCMWINS_VAL_PHYSICAL_CELL_DUPLEX_MODE_FDD                          0

// rscmwins_rngPhysCellSubcSpacing
#define RSCMWINS_VAL_PHYS_CELL_SUBCARRIER_SPACING_S3K75                     0
#define RSCMWINS_VAL_PHYS_CELL_SUBCARRIER_SPACING_S15K                      1

// rscmwins_rngPhysicalCellOperationMode
#define RSCMWINS_PHYS_CELL_OPER_MODE_SALM                                   0
#define RSCMWINS_PHYS_CELL_OPER_MODE_GBOP                                   1
#define RSCMWINS_PHYS_CELL_OPER_MODE_IBOP                                   2

// rscmwins_rngPhysicalCellBandwidth
#define RSCMWINS_VAL_PHYS_CELL_BW_B030                                      0
#define RSCMWINS_VAL_PHYS_CELL_BW_B050                                      1
#define RSCMWINS_VAL_PHYS_CELL_BW_B100                                      2
#define RSCMWINS_VAL_PHYS_CELL_BW_B150                                      3
#define RSCMWINS_VAL_PHYS_CELL_BW_B200                                      4

// rscmwins_rngPhysCellControlRegionSize
#define RSCMWINS_VAL_PHYS_CELL_CTRL_REGION_SIZE_CRS1                        0
#define RSCMWINS_VAL_PHYS_CELL_CTRL_REGION_SIZE_CRS2                        1
#define RSCMWINS_VAL_PHYS_CELL_CTRL_REGION_SIZE_CRS3                        2

// rscmwins_rngPhysicalCellPowerOffset
#define RSCMWINS_VAL_PHYS_CELL_POW_OFFSET_ZERO                              0

// rscmwins_rngPhysCellInbandPCI
#define RSCMWINS_VAL_PHYS_CELL_INBAND_PCI_SAME                              0
#define RSCMWINS_VAL_PHYS_CELL_INBAND_PCI_DIFF                              1

// rscmwins_rngPhyslCellGuardBandPosition
#define RSCMWINS_VAL_PHYS_CELL_GB_POSITION_UP                               0
#define RSCMWINS_VAL_PHYS_CELL_GB_POSITION_LOW                              1

// rscmwins_rngPhysCellPowerRamping
#define RSCMWINS_VAL_PHYS_CELL_POWER_RAMP_S0                                0
#define RSCMWINS_VAL_PHYS_CELL_POWER_RAMP_S2                                1
#define RSCMWINS_VAL_PHYS_CELL_POWER_RAMP_S4                                2
#define RSCMWINS_VAL_PHYS_CELL_POWER_RAMP_S6                                3

// rscmwins_rngPhysCellMaxTransmissions
#define RSCMWINS_VAL_PHYS_CELL_MAX_TRANS_T6                                 0
#define RSCMWINS_VAL_PHYS_CELL_MAX_TRANS_T10                                1
#define RSCMWINS_VAL_PHYS_CELL_MAX_TRANS_T50                                2

// rscmwins_rngMNCDigits
#define RSCMWINS_VAL_MNC_DIGITS_TWO                                         0
#define RSCMWINS_VAL_MNC_DIGITS_THREE                                       1

// rscmwins_rngNetworkSecurityAlgorithm
#define RSCMWINS_VAL_NETWORK_SECURITY_ALGORITHM_NULL                        0
#define RSCMWINS_VAL_NETWORK_SECURITY_ALGORITHM_S3G                         1
#define RSCMWINS_VAL_NETWORK_SECURITY_ALGORITHM_AES                         2

// rscmwins_rngDaylightSavingTime
#define RSCMWINS_VAL_DST_P1H                                                0
#define RSCMWINS_VAL_DST_P2H                                                1

// rscmwins_rngNetworkTimeSource
#define RSCMWINS_VAL_NETWORK_TIME_SOURCE_CMWTIME                            0
#define RSCMWINS_VAL_NETWORK_TIME_SOURCE_DATE                               1

// rscmwins_rngNetworkSyncZone
#define RSCMWINS_NETWORK_SYNC_ZONE_NONE                                     0
#define RSCMWINS_NETWORK_SYNC_ZONE_Z1                                       1

// rscmwins_rngConnectionType
#define RSCMWINS_VAL_CONN_TYPE_TEST                                         0
#define RSCMWINS_VAL_CONN_TYPE_DAPP                                         1

// rscmwins_rngIPVersion
#define RSCMWINS_VAL_IP_VERSION_IPV4                                        0
#define RSCMWINS_VAL_IP_VERSION_IPV6                                        1

// rscmwins_rngCIoT
#define RSCMWINS_VAL_CIOT_CPL                                               0
#define RSCMWINS_VAL_CIOT_UPL                                               1

// rscmwins_rngDataApplicationIPVersion
#define RSCMWINS_VAL_DATA_APP_IP_VERSION_IPV4                               0
#define RSCMWINS_VAL_DATA_APP_IP_VERSION_IPV6                               1
#define RSCMWINS_VAL_DATA_APP_IP_VERSION_IPV46                              2

// rscmwins_rngSchedulingType
#define RSCMWINS_VAL_SCHEDULING_TYPE_ULRMC                                  0
#define RSCMWINS_VAL_SCHEDULING_TYPE_DLRMC                                  1
#define RSCMWINS_VAL_SCHEDULING_TYPE_UDEF                                   2

// rscmwins_rngDefaultPagingCycle
#define RSCMWINS_VAL_DEFAULT_PAGING_CYCLE_P128                              0
#define RSCMWINS_VAL_DEFAULT_PAGING_CYCLE_P256                              1
#define RSCMWINS_VAL_DEFAULT_PAGING_CYCLE_P512                              2
#define RSCMWINS_VAL_DEFAULT_PAGING_CYCLE_P1K                               3

// rscmwins_rngPCCHConfignB
#define RSCMWINS_VAL_PCCH_CONFIG_NB_N4T                                     0
#define RSCMWINS_VAL_PCCH_CONFIG_NB_N2T                                     1
#define RSCMWINS_VAL_PCCH_CONFIG_NB_NT                                      2
#define RSCMWINS_VAL_PCCH_CONFIG_NB_NT2                                     3
#define RSCMWINS_VAL_PCCH_CONFIG_NB_NT4                                     4
#define RSCMWINS_VAL_PCCH_CONFIG_NB_NT8                                     5
#define RSCMWINS_VAL_PCCH_CONFIG_NB_NT16                                    6
#define RSCMWINS_VAL_PCCH_CONFIG_NB_NT32                                    7
#define RSCMWINS_VAL_PCCH_CONFIG_NB_NT64                                    8
#define RSCMWINS_VAL_PCCH_CONFIG_NB_NT128                                   9
#define RSCMWINS_VAL_PCCH_CONFIG_NB_NT256                                   10
#define RSCMWINS_VAL_PCCH_CONFIG_NB_NT512                                   11
#define RSCMWINS_VAL_PCCH_CONFIG_NB_NT1K                                    12

// rscmwins_rngModificationPeriodCoefficient
#define RSCMWINS_VAL_MOD_PERIOD_COEFF_C16                                   0
#define RSCMWINS_VAL_MOD_PERIOD_COEFF_C32                                   1
#define RSCMWINS_VAL_MOD_PERIOD_COEFF_C64                                   2
#define RSCMWINS_VAL_MOD_PERIOD_COEFF_C128                                  3

// rscmwins_rngPagingTimeWindow
#define RSCMWINS_VAL_PAGING_TIME_WINDOW_W2K56                               0
#define RSCMWINS_VAL_PAGING_TIME_WINDOW_W5K12                               1
#define RSCMWINS_VAL_PAGING_TIME_WINDOW_W7K68                               2
#define RSCMWINS_VAL_PAGING_TIME_WINDOW_W10K                                3
#define RSCMWINS_VAL_PAGING_TIME_WINDOW_W12K                                4
#define RSCMWINS_VAL_PAGING_TIME_WINDOW_W15K                                5
#define RSCMWINS_VAL_PAGING_TIME_WINDOW_W17K                                6
#define RSCMWINS_VAL_PAGING_TIME_WINDOW_W20K                                7
#define RSCMWINS_VAL_PAGING_TIME_WINDOW_W23K                                8
#define RSCMWINS_VAL_PAGING_TIME_WINDOW_W25K                                9
#define RSCMWINS_VAL_PAGING_TIME_WINDOW_W28K                                10
#define RSCMWINS_VAL_PAGING_TIME_WINDOW_W30K                                11
#define RSCMWINS_VAL_PAGING_TIME_WINDOW_W33K                                12
#define RSCMWINS_VAL_PAGING_TIME_WINDOW_W35K                                13
#define RSCMWINS_VAL_PAGING_TIME_WINDOW_W38K                                14
#define RSCMWINS_VAL_PAGING_TIME_WINDOW_W40K                                15

// rscmwins_rngCycleLength
#define RSCMWINS_VAL_CYCLE_LENGTH_L2K                                       0
#define RSCMWINS_VAL_CYCLE_LENGTH_L4K                                       1
#define RSCMWINS_VAL_CYCLE_LENGTH_L8K                                       2
#define RSCMWINS_VAL_CYCLE_LENGTH_L16K                                      3
#define RSCMWINS_VAL_CYCLE_LENGTH_L32K                                      4
#define RSCMWINS_VAL_CYCLE_LENGTH_L65K                                      5
#define RSCMWINS_VAL_CYCLE_LENGTH_L0M1                                      6
#define RSCMWINS_VAL_CYCLE_LENGTH_L0M2                                      7
#define RSCMWINS_VAL_CYCLE_LENGTH_L0M5                                      8
#define RSCMWINS_VAL_CYCLE_LENGTH_L1M                                       9

// rscmwins_rngDNDSubcarriers
#define RSCMWINS_VAL_SUBC_SC1                                               0
#define RSCMWINS_VAL_SUBC_SC3                                               1
#define RSCMWINS_VAL_SUBC_SC6                                               2
#define RSCMWINS_VAL_SUBC_SC12                                              3

// rscmwins_rngDNDMCSIndex
#define RSCMWINS_VAL_MCS_INDEX_MI0                                          0
#define RSCMWINS_VAL_MCS_INDEX_MI1                                          1
#define RSCMWINS_VAL_MCS_INDEX_MI2                                          2
#define RSCMWINS_VAL_MCS_INDEX_MI3                                          3
#define RSCMWINS_VAL_MCS_INDEX_MI4                                          4
#define RSCMWINS_VAL_MCS_INDEX_MI5                                          5
#define RSCMWINS_VAL_MCS_INDEX_MI6                                          6
#define RSCMWINS_VAL_MCS_INDEX_MI7                                          7
#define RSCMWINS_VAL_MCS_INDEX_MI8                                          8
#define RSCMWINS_VAL_MCS_INDEX_MI9                                          9
#define RSCMWINS_VAL_MCS_INDEX_MI10                                         10
#define RSCMWINS_VAL_MCS_INDEX_MI11                                         11
#define RSCMWINS_VAL_MCS_INDEX_MI12                                         12
#define RSCMWINS_VAL_MCS_INDEX_MI13                                         13

// rscmwins_rngDNDResourceUnits
#define RSCMWINS_VAL_RESOURCE_UNITS_NRU01                                   0
#define RSCMWINS_VAL_RESOURCE_UNITS_NRU02                                   1
#define RSCMWINS_VAL_RESOURCE_UNITS_NRU03                                   2
#define RSCMWINS_VAL_RESOURCE_UNITS_NRU04                                   3
#define RSCMWINS_VAL_RESOURCE_UNITS_NRU05                                   4
#define RSCMWINS_VAL_RESOURCE_UNITS_NRU06                                   5
#define RSCMWINS_VAL_RESOURCE_UNITS_NRU08                                   6
#define RSCMWINS_VAL_RESOURCE_UNITS_NRU10                                   7

// rscmwins_rngDNDRepetitions
#define RSCMWINS_VAL_REPETITIONS_NR1                                        0
#define RSCMWINS_VAL_REPETITIONS_NR2                                        1
#define RSCMWINS_VAL_REPETITIONS_NR4                                        2
#define RSCMWINS_VAL_REPETITIONS_NR8                                        3
#define RSCMWINS_VAL_REPETITIONS_NR16                                       4
#define RSCMWINS_VAL_REPETITIONS_NR32                                       5
#define RSCMWINS_VAL_REPETITIONS_NR64                                       6
#define RSCMWINS_VAL_REPETITIONS_NR128                                      7

// rscmwins_rngDNDModulation
#define RSCMWINS_VAL_MODULATION_QPSK                                        0
#define RSCMWINS_VAL_MODULATION_BPSK                                        1

// rscmwins_rngDNDSubframes
#define RSCMWINS_VAL_SUBFRAMES_NSF01                                        0
#define RSCMWINS_VAL_SUBFRAMES_NSF02                                        1
#define RSCMWINS_VAL_SUBFRAMES_NSF03                                        2
#define RSCMWINS_VAL_SUBFRAMES_NSF04                                        3
#define RSCMWINS_VAL_SUBFRAMES_NSF05                                        4
#define RSCMWINS_VAL_SUBFRAMES_NSF06                                        5
#define RSCMWINS_VAL_SUBFRAMES_NSF08                                        6
#define RSCMWINS_VAL_SUBFRAMES_NSF10                                        7

// rscmwins_rngUserPattern
#define RSCMWINS_VAL_USER_PATTERN_DL                                        0
#define RSCMWINS_VAL_USER_PATTERN_UL                                        1
#define RSCMWINS_VAL_USER_PATTERN_DLUL                                      2
#define RSCMWINS_VAL_USER_PATTERN_NOS                                       3

// rscmwins_rngBLERState
#define RSCMWINS_VAL_BLER_STATE_OFF                                         0
#define RSCMWINS_VAL_BLER_STATE_RUN                                         1
#define RSCMWINS_VAL_BLER_STATE_RDY                                         2

// rscmwins_rngDNDSyncState
#define RSCMWINS_VAL_SYNC_STATE_PEND                                        0
#define RSCMWINS_VAL_SYNC_STATE_ADJ                                         1
#define RSCMWINS_VAL_SYNC_STATE_INV                                         2

// rscmwins_rngDNDResourceState
#define RSCMWINS_VAL_RESOURCE_STATE_QUE                                     0
#define RSCMWINS_VAL_RESOURCE_STATE_ACT                                     1
#define RSCMWINS_VAL_RESOURCE_STATE_INV                                     2

// rscmwins_rngBLERRepetition
#define RSCMWINS_VAL_BLER_REPETITION_SINGLE                                 0
#define RSCMWINS_VAL_BLER_REPETITION_CONT                                   1

// rscmwins_rngBLERAlgorithm
#define RSCMWINS_VAL_BLER_ALGORITHM_ERC1                                    1
#define RSCMWINS_VAL_BLER_ALGORITHM_ERC2                                    2
#define RSCMWINS_VAL_BLER_ALGORITHM_ERC3                                    3
#define RSCMWINS_VAL_BLER_ALGORITHM_ERC4                                    4

// rscmwins_rngDNDEventLogCategory
#define RSCMWINS_VAL_EVENT_LOG_CATEGORY_INFO                                0
#define RSCMWINS_VAL_EVENT_LOG_CATEGORY_WARNING                             1
#define RSCMWINS_VAL_EVENT_LOG_CATEGORY_ERROR                               2
#define RSCMWINS_VAL_EVENT_LOG_CATEGORY_CONTINUE                            3

// rscmwins_rngNoYes
#define RSCMWINS_VAL_NO_YES_NO                                              0
#define RSCMWINS_VAL_NO_YES_YES                                             1

// rscmwins_rngTransferCategory
#define RSCMWINS_VAL_TRANSFER_CATEGORY_NB1                                  0
#define RSCMWINS_VAL_TRANSFER_CATEGORY_NB2                                  1

// rscmwins_rngROHCContextSessions
#define RSCMWINS_VAL_ROHC_CONTEXT_SESSIONS_CS2                              0
#define RSCMWINS_VAL_ROHC_CONTEXT_SESSIONS_CS4                              1
#define RSCMWINS_VAL_ROHC_CONTEXT_SESSIONS_CS8                              2
#define RSCMWINS_VAL_ROHC_CONTEXT_SESSIONS_CS12                             3

// rscmwins_rngPSState
#define RSCMWINS_VAL_PS_STATE_OFF                                           0
#define RSCMWINS_VAL_PS_STATE_ON                                            1
#define RSCMWINS_VAL_PS_STATE_ATT                                           2
#define RSCMWINS_VAL_PS_STATE_CEST                                          3
#define RSCMWINS_VAL_PS_STATE_DISC                                          4
#define RSCMWINS_VAL_PS_STATE_CONN                                          5
#define RSCMWINS_VAL_PS_STATE_SIGN                                          6

// rscmwins_rngUECapabilitiesRelease
#define RSCMWINS_VAL_UE_CAP_RELEASE_R13                                     0

// rscmwins_rngScenario
#define RSCMWINS_VAL_SCENARIO_NAV                                           0
#define RSCMWINS_VAL_SCENARIO_SCEL                                          1

// rscmwins_rngUserSchedulingPattern
#define RSCMWINS_VAL_SCHEDULING_PATTERN_DL                                  0
#define RSCMWINS_VAL_SCHEDULING_PATTERN_UL                                  1
#define RSCMWINS_VAL_SCHEDULING_PATTERN_DLUL                                2
#define RSCMWINS_VAL_SCHEDULING_PATTERN_NOS                                 3

// rscmwins_rngPhysicalCellCENPDCCHMaxRepetitions
#define RSCMWINS_VAL_NPDCCH_MAX_REPETITIONS_R1                              0
#define RSCMWINS_VAL_NPDCCH_MAX_REPETITIONS_R2                              1
#define RSCMWINS_VAL_NPDCCH_MAX_REPETITIONS_R4                              2
#define RSCMWINS_VAL_NPDCCH_MAX_REPETITIONS_R8                              3
#define RSCMWINS_VAL_NPDCCH_MAX_REPETITIONS_R16                             4
#define RSCMWINS_VAL_NPDCCH_MAX_REPETITIONS_R32                             5
#define RSCMWINS_VAL_NPDCCH_MAX_REPETITIONS_R64                             6
#define RSCMWINS_VAL_NPDCCH_MAX_REPETITIONS_R128                            7
#define RSCMWINS_VAL_NPDCCH_MAX_REPETITIONS_R256                            8
#define RSCMWINS_VAL_NPDCCH_MAX_REPETITIONS_R512                            9
#define RSCMWINS_VAL_NPDCCH_MAX_REPETITIONS_R1024                           10
#define RSCMWINS_VAL_NPDCCH_MAX_REPETITIONS_R2048                           11

// rscmwins_rngPhysicalCellWUSMaxDurationFactor
#define RSCMWINS_VAL_WUS_DURATION_FACTOR_R2                                 0
#define RSCMWINS_VAL_WUS_DURATION_FACTOR_R4                                 1
#define RSCMWINS_VAL_WUS_DURATION_FACTOR_R8                                 2
#define RSCMWINS_VAL_WUS_DURATION_FACTOR_R16                                3
#define RSCMWINS_VAL_WUS_DURATION_FACTOR_R32                                4
#define RSCMWINS_VAL_WUS_DURATION_FACTOR_R64                                5
#define RSCMWINS_VAL_WUS_DURATION_FACTOR_R128                               6

// rscmwins_rngPhysicalCellWUSNumPOs
#define RSCMWINS_VAL_WUS_NUM_PO_ONE                                         0
#define RSCMWINS_VAL_WUS_NUM_PO_TWO                                         1
#define RSCMWINS_VAL_WUS_NUM_PO_FOUR                                        2

// rscmwins_rngDRXTimer
#define RSCMWINS_VAL_DRX_TIMER_PSF0                                         0
#define RSCMWINS_VAL_DRX_TIMER_PSF1                                         1
#define RSCMWINS_VAL_DRX_TIMER_PSF2                                         2
#define RSCMWINS_VAL_DRX_TIMER_PSF3                                         3
#define RSCMWINS_VAL_DRX_TIMER_PSF4                                         4
#define RSCMWINS_VAL_DRX_TIMER_PSF6                                         5
#define RSCMWINS_VAL_DRX_TIMER_PSF8                                         6
#define RSCMWINS_VAL_DRX_TIMER_PSF16                                        7
#define RSCMWINS_VAL_DRX_TIMER_PSF24                                        8
#define RSCMWINS_VAL_DRX_TIMER_PSF32                                        9
#define RSCMWINS_VAL_DRX_TIMER_PSF33                                        10
#define RSCMWINS_VAL_DRX_TIMER_PSF40                                        11
#define RSCMWINS_VAL_DRX_TIMER_PSF64                                        12
#define RSCMWINS_VAL_DRX_TIMER_PSF80                                        13
#define RSCMWINS_VAL_DRX_TIMER_PSF96                                        14
#define RSCMWINS_VAL_DRX_TIMER_PSF112                                       15
#define RSCMWINS_VAL_DRX_TIMER_PSF128                                       16
#define RSCMWINS_VAL_DRX_TIMER_PSF160                                       17
#define RSCMWINS_VAL_DRX_TIMER_PSF320                                       18

// rscmwins_rngDRXCycle
#define RSCMWINS_DRX_CYCLE_SF256                                            0
#define RSCMWINS_DRX_CYCLE_SF512                                            1
#define RSCMWINS_DRX_CYCLE_SF1024                                           2
#define RSCMWINS_DRX_CYCLE_SF1280                                           3
#define RSCMWINS_DRX_CYCLE_SF1536                                           4
#define RSCMWINS_DRX_CYCLE_SF2048                                           5
#define RSCMWINS_DRX_CYCLE_SF2560                                           6
#define RSCMWINS_DRX_CYCLE_SF3072                                           7
#define RSCMWINS_DRX_CYCLE_SF4096                                           8
#define RSCMWINS_DRX_CYCLE_SF4608                                           9
#define RSCMWINS_DRX_CYCLE_SF5120                                           10
#define RSCMWINS_DRX_CYCLE_SF6144                                           11
#define RSCMWINS_DRX_CYCLE_SF7680                                           12
#define RSCMWINS_DRX_CYCLE_SF8192                                           13
#define RSCMWINS_DRX_CYCLE_SF9216                                           14
#define RSCMWINS_DRX_CYCLE_SF10240                                          15

// rscmwins_rngNACBitmap
#define RSCMWINS_VAL_NAC_BITMAP_NOB                                         0
#define RSCMWINS_VAL_NAC_BITMAP_ANB                                         1
#define RSCMWINS_VAL_NAC_BITMAP_EXB                                         2

// rscmwins_rngNACGap
#define RSCMWINS_VAL_NAC_GAP_NOG                                            0
#define RSCMWINS_VAL_NAC_GAP_ANG                                            1
#define RSCMWINS_VAL_NAC_GAP_EXG                                            2

// rscmwins_rngNACGapThreshold
#define RSCMWINS_VAL_NAC_GAP_THRESHOLD_N32                                  0
#define RSCMWINS_VAL_NAC_GAP_THRESHOLD_N64                                  1
#define RSCMWINS_VAL_NAC_GAP_THRESHOLD_N128                                 2
#define RSCMWINS_VAL_NAC_GAP_THRESHOLD_N256                                 3

// rscmwins_rngNACGapPeriodicity
#define RSCMWINS_VAL_NAC_GAP_PERIODICITY_SF64                               0
#define RSCMWINS_VAL_NAC_GAP_PERIODICITY_SF128                              1
#define RSCMWINS_VAL_NAC_GAP_PERIODICITY_SF256                              2
#define RSCMWINS_VAL_NAC_GAP_PERIODICITY_SF512                              3

// rscmwins_rngNACNRSPowerOffset
#define RSCMWINS_VAL_NAC_NRS_POWER_OFFSET_N12                               0
#define RSCMWINS_VAL_NAC_NRS_POWER_OFFSET_N10                               1
#define RSCMWINS_VAL_NAC_NRS_POWER_OFFSET_N8                                2
#define RSCMWINS_VAL_NAC_NRS_POWER_OFFSET_N6                                3
#define RSCMWINS_VAL_NAC_NRS_POWER_OFFSET_N4                                4
#define RSCMWINS_VAL_NAC_NRS_POWER_OFFSET_N2                                5
#define RSCMWINS_VAL_NAC_NRS_POWER_OFFSET_ZERO                              6
#define RSCMWINS_VAL_NAC_NRS_POWER_OFFSET_P3                                7

// rscmwins_rngNACPagingWeightAnchor
#define RSCMWINS_VAL_NAC_PAGING_WEIGHT_ANCHOR_W0                            0
#define RSCMWINS_VAL_NAC_PAGING_WEIGHT_ANCHOR_W1                            1
#define RSCMWINS_VAL_NAC_PAGING_WEIGHT_ANCHOR_W2                            2
#define RSCMWINS_VAL_NAC_PAGING_WEIGHT_ANCHOR_W3                            3
#define RSCMWINS_VAL_NAC_PAGING_WEIGHT_ANCHOR_W4                            4
#define RSCMWINS_VAL_NAC_PAGING_WEIGHT_ANCHOR_W5                            5
#define RSCMWINS_VAL_NAC_PAGING_WEIGHT_ANCHOR_W6                            6
#define RSCMWINS_VAL_NAC_PAGING_WEIGHT_ANCHOR_W7                            7
#define RSCMWINS_VAL_NAC_PAGING_WEIGHT_ANCHOR_W8                            8
#define RSCMWINS_VAL_NAC_PAGING_WEIGHT_ANCHOR_W9                            9
#define RSCMWINS_VAL_NAC_PAGING_WEIGHT_ANCHOR_W10                           10
#define RSCMWINS_VAL_NAC_PAGING_WEIGHT_ANCHOR_W11                           11
#define RSCMWINS_VAL_NAC_PAGING_WEIGHT_ANCHOR_W12                           12
#define RSCMWINS_VAL_NAC_PAGING_WEIGHT_ANCHOR_W13                           13
#define RSCMWINS_VAL_NAC_PAGING_WEIGHT_ANCHOR_W14                           14
#define RSCMWINS_VAL_NAC_PAGING_WEIGHT_ANCHOR_W15                           15
#define RSCMWINS_VAL_NAC_PAGING_WEIGHT_ANCHOR_W16                           16

// rscmwins_rngNACChannelOffset
#define RSCMWINS_VAL_NAC_CANNEL_OFFSET_VN10                                 0
#define RSCMWINS_VAL_NAC_CANNEL_OFFSET_VN9                                  1
#define RSCMWINS_VAL_NAC_CANNEL_OFFSET_VN8                                  2
#define RSCMWINS_VAL_NAC_CANNEL_OFFSET_VN7                                  3
#define RSCMWINS_VAL_NAC_CANNEL_OFFSET_VN6                                  4
#define RSCMWINS_VAL_NAC_CANNEL_OFFSET_VN5                                  5
#define RSCMWINS_VAL_NAC_CANNEL_OFFSET_VN4                                  6
#define RSCMWINS_VAL_NAC_CANNEL_OFFSET_VN3                                  7
#define RSCMWINS_VAL_NAC_CANNEL_OFFSET_VN2                                  8
#define RSCMWINS_VAL_NAC_CANNEL_OFFSET_VN1                                  9
#define RSCMWINS_VAL_NAC_CANNEL_OFFSET_VNHF                                 10
#define RSCMWINS_VAL_NAC_CANNEL_OFFSET_V0                                   11
#define RSCMWINS_VAL_NAC_CANNEL_OFFSET_V1                                   12
#define RSCMWINS_VAL_NAC_CANNEL_OFFSET_V2                                   13
#define RSCMWINS_VAL_NAC_CANNEL_OFFSET_V3                                   14
#define RSCMWINS_VAL_NAC_CANNEL_OFFSET_V4                                   19
#define RSCMWINS_VAL_NAC_CANNEL_OFFSET_V5                                   20
#define RSCMWINS_VAL_NAC_CANNEL_OFFSET_V6                                   21
#define RSCMWINS_VAL_NAC_CANNEL_OFFSET_V7                                   22
#define RSCMWINS_VAL_NAC_CANNEL_OFFSET_V8                                   23
#define RSCMWINS_VAL_NAC_CANNEL_OFFSET_V9                                   24

// rscmwins_rngNACRepetitions
#define RSCMWINS_VAL_NAC_REPETITIONS_OFF                                    0
#define RSCMWINS_VAL_NAC_REPETITIONS_ON                                     1
#define RSCMWINS_VAL_NAC_REPETITIONS_R1                                     2
#define RSCMWINS_VAL_NAC_REPETITIONS_R2                                     3
#define RSCMWINS_VAL_NAC_REPETITIONS_R4                                     4
#define RSCMWINS_VAL_NAC_REPETITIONS_R8                                     5
#define RSCMWINS_VAL_NAC_REPETITIONS_R16                                    6
#define RSCMWINS_VAL_NAC_REPETITIONS_R32                                    7
#define RSCMWINS_VAL_NAC_REPETITIONS_R64                                    8
#define RSCMWINS_VAL_NAC_REPETITIONS_R128                                   9
#define RSCMWINS_VAL_NAC_REPETITIONS_R256                                   10
#define RSCMWINS_VAL_NAC_REPETITIONS_R512                                   11
#define RSCMWINS_VAL_NAC_REPETITIONS_R1024                                  12
#define RSCMWINS_VAL_NAC_REPETITIONS_R2048                                  13
#define RSCMWINS_VAL_NAC_REPETITIONS_SP1                                    14
#define RSCMWINS_VAL_NAC_REPETITIONS_SP2                                    15
#define RSCMWINS_VAL_NAC_REPETITIONS_SP3                                    16
#define RSCMWINS_VAL_NAC_REPETITIONS_SP4                                    17

// rscmwins_rngNACPagingWeight
#define RSCMWINS_VAL_NAC_PAGING_WEIGHT_W0                                   0
#define RSCMWINS_VAL_NAC_PAGING_WEIGHT_W1                                   1
#define RSCMWINS_VAL_NAC_PAGING_WEIGHT_W2                                   2
#define RSCMWINS_VAL_NAC_PAGING_WEIGHT_W3                                   3
#define RSCMWINS_VAL_NAC_PAGING_WEIGHT_W4                                   4
#define RSCMWINS_VAL_NAC_PAGING_WEIGHT_W5                                   5
#define RSCMWINS_VAL_NAC_PAGING_WEIGHT_W6                                   6
#define RSCMWINS_VAL_NAC_PAGING_WEIGHT_W7                                   7
#define RSCMWINS_VAL_NAC_PAGING_WEIGHT_W8                                   8
#define RSCMWINS_VAL_NAC_PAGING_WEIGHT_W9                                   9
#define RSCMWINS_VAL_NAC_PAGING_WEIGHT_W10                                  10
#define RSCMWINS_VAL_NAC_PAGING_WEIGHT_W11                                  11
#define RSCMWINS_VAL_NAC_PAGING_WEIGHT_W12                                  12
#define RSCMWINS_VAL_NAC_PAGING_WEIGHT_W13                                  13
#define RSCMWINS_VAL_NAC_PAGING_WEIGHT_W14                                  14
#define RSCMWINS_VAL_NAC_PAGING_WEIGHT_W15                                  15
#define RSCMWINS_VAL_NAC_PAGING_WEIGHT_W16                                  16

// rscmwins_rngNACDurationFactor
#define RSCMWINS_VAL_NAC_DURATION_FACTOR_R2                                 0
#define RSCMWINS_VAL_NAC_DURATION_FACTOR_R4                                 1
#define RSCMWINS_VAL_NAC_DURATION_FACTOR_R8                                 2
#define RSCMWINS_VAL_NAC_DURATION_FACTOR_R16                                3
#define RSCMWINS_VAL_NAC_DURATION_FACTOR_R32                                4
#define RSCMWINS_VAL_NAC_DURATION_FACTOR_R64                                5
#define RSCMWINS_VAL_NAC_DURATION_FACTOR_R128                               6

// rscmwins_rngNPRACHProbabilityAnchor
#define RSCMWINS_VAL_NPRACH_PROBABILITY_ANCHOR_ZERO                         0
#define RSCMWINS_VAL_NPRACH_PROBABILITY_ANCHOR_R2                           2
#define RSCMWINS_VAL_NPRACH_PROBABILITY_ANCHOR_R3                           3
#define RSCMWINS_VAL_NPRACH_PROBABILITY_ANCHOR_R4                           4
#define RSCMWINS_VAL_NPRACH_PROBABILITY_ANCHOR_R5                           5
#define RSCMWINS_VAL_NPRACH_PROBABILITY_ANCHOR_R6                           6
#define RSCMWINS_VAL_NPRACH_PROBABILITY_ANCHOR_R7                           7
#define RSCMWINS_VAL_NPRACH_PROBABILITY_ANCHOR_R8                           8
#define RSCMWINS_VAL_NPRACH_PROBABILITY_ANCHOR_R9                           9
#define RSCMWINS_VAL_NPRACH_PROBABILITY_ANCHOR_R10                          10
#define RSCMWINS_VAL_NPRACH_PROBABILITY_ANCHOR_R11                          11
#define RSCMWINS_VAL_NPRACH_PROBABILITY_ANCHOR_R12                          12
#define RSCMWINS_VAL_NPRACH_PROBABILITY_ANCHOR_R13                          13
#define RSCMWINS_VAL_NPRACH_PROBABILITY_ANCHOR_R14                          14
#define RSCMWINS_VAL_NPRACH_PROBABILITY_ANCHOR_R15                          15
#define RSCMWINS_VAL_NPRACH_PROBABILITY_ANCHOR_R16                          16

// rscmwins_rngNPDCCHNoRepetitions
#define RSCMWINS_VAL_NPDCCH_NO_REPETITIONS_RMAX                             0
#define RSCMWINS_VAL_NPDCCH_NO_REPETITIONS_RMAX2                            1
#define RSCMWINS_VAL_NPDCCH_NO_REPETITIONS_RMAX4                            2
#define RSCMWINS_VAL_NPDCCH_NO_REPETITIONS_RMAX8                            3

// rscmwins_rngNPDCCHCSSMAXRepetitions
#define RSCMWINS_VAL_NPDCCH_CSS_MAX_REPETITIONS_R1                          0
#define RSCMWINS_VAL_NPDCCH_CSS_MAX_REPETITIONS_R2                          1
#define RSCMWINS_VAL_NPDCCH_CSS_MAX_REPETITIONS_R4                          2
#define RSCMWINS_VAL_NPDCCH_CSS_MAX_REPETITIONS_R8                          3
#define RSCMWINS_VAL_NPDCCH_CSS_MAX_REPETITIONS_R16                         4
#define RSCMWINS_VAL_NPDCCH_CSS_MAX_REPETITIONS_R32                         5
#define RSCMWINS_VAL_NPDCCH_CSS_MAX_REPETITIONS_R64                         6
#define RSCMWINS_VAL_NPDCCH_CSS_MAX_REPETITIONS_R128                        7
#define RSCMWINS_VAL_NPDCCH_CSS_MAX_REPETITIONS_R256                        8
#define RSCMWINS_VAL_NPDCCH_CSS_MAX_REPETITIONS_R512                        9
#define RSCMWINS_VAL_NPDCCH_CSS_MAX_REPETITIONS_R1024                       10
#define RSCMWINS_VAL_NPDCCH_CSS_MAX_REPETITIONS_R2048                       11

// rscmwins_rngEDTResourceNumbers
#define RSCMWINS_VAL_EDT_RESOURCE_NUMBERS_B328                              0
#define RSCMWINS_VAL_EDT_RESOURCE_NUMBERS_B408                              1
#define RSCMWINS_VAL_EDT_RESOURCE_NUMBERS_B504                              2
#define RSCMWINS_VAL_EDT_RESOURCE_NUMBERS_B584                              3
#define RSCMWINS_VAL_EDT_RESOURCE_NUMBERS_B680                              4
#define RSCMWINS_VAL_EDT_RESOURCE_NUMBERS_B808                              5
#define RSCMWINS_VAL_EDT_RESOURCE_NUMBERS_B936                              6
#define RSCMWINS_VAL_EDT_RESOURCE_NUMBERS_B1000                             7

// rscmwins_rngRRCReleaseCause
#define RSCMWINS_VAL_RRC_RELEASE_CAUSE_SUSPEND                              0
#define RSCMWINS_VAL_RRC_RELEASE_CAUSE_OTHER                                1

// rscmwins_rngSchedulingRequestWithoutHARQAlpha
#define RSCMWINS_VAL_SCHED_REQ_WITHOUT_HARQ_ALPHA_ZERO                      0
#define RSCMWINS_VAL_SCHED_REQ_WITHOUT_HARQ_ALPHA_DOT4                      1
#define RSCMWINS_VAL_SCHED_REQ_WITHOUT_HARQ_ALPHA_DOT5                      2
#define RSCMWINS_VAL_SCHED_REQ_WITHOUT_HARQ_ALPHA_DOT6                      3
#define RSCMWINS_VAL_SCHED_REQ_WITHOUT_HARQ_ALPHA_DOT7                      4
#define RSCMWINS_VAL_SCHED_REQ_WITHOUT_HARQ_ALPHA_DOT8                      5
#define RSCMWINS_VAL_SCHED_REQ_WITHOUT_HARQ_ALPHA_DOT9                      6
#define RSCMWINS_VAL_SCHED_REQ_WITHOUT_HARQ_ALPHA_ONE                       7

// rscmwins_rngSchedulingRequestWithoutHARQIndex
#define RSCMWINS_VAL_SCHED_REQ_INDEX_ZERO                                   0
#define RSCMWINS_VAL_SCHED_REQ_INDEX_ONE                                    1
#define RSCMWINS_VAL_SCHED_REQ_INDEX_TWO                                    2

// rscmwins_rngSchedReqWithoutHARQSubcarrierIndexFormat
#define RSCMWINS_VAL_SCHED_REQ_WITOUT_HARQ_SUBC_INDEX_FORMAT_FT01           0
#define RSCMWINS_VAL_SCHED_REQ_WITOUT_HARQ_SUBC_INDEX_FORMAT_FT02           1

// rscmwins_rngSchedulingRequestWithoutHARQResourceIndex
#define RSCMWINM_VAL_SCH_REQ_RESOURCE_INDEX_ONE                             0
#define RSCMWINM_VAL_SCH_REQ_RESOURCE_INDEX_TWO                             1
#define RSCMWINM_VAL_SCH_REQ_RESOURCE_INDEX_THREE                           2

//repcap instance
#define RSCMWINS_REPCAP_INSTANCE_I1                                         1
#define RSCMWINS_REPCAP_INSTANCE_I2                                         2
#define RSCMWINS_REPCAP_INSTANCE_I3                                         3
#define RSCMWINS_REPCAP_INSTANCE_I4                                         4
#define RSCMWINS_REPCAP_INSTANCE_I5                                         5
#define RSCMWINS_REPCAP_INSTANCE_I6                                         6
#define RSCMWINS_REPCAP_INSTANCE_I7                                         7
#define RSCMWINS_REPCAP_INSTANCE_I8                                         8
#define RSCMWINS_REPCAP_INSTANCE_I9                                         9
#define RSCMWINS_REPCAP_INSTANCE_I10                                        10
#define RSCMWINS_REPCAP_INSTANCE_I11                                        11
#define RSCMWINS_REPCAP_INSTANCE_I12                                        12
#define RSCMWINS_REPCAP_INSTANCE_I13                                        13
#define RSCMWINS_REPCAP_INSTANCE_I14                                        14
#define RSCMWINS_REPCAP_INSTANCE_I15                                        15
#define RSCMWINS_REPCAP_INSTANCE_I16                                        16

//repcap format
#define RSCMWINS_REPCAP_FORMAT_F1                                           1
#define RSCMWINS_REPCAP_FORMAT_F2                                           2

//repcap IPVersion
#define RSCMWINS_REPCAP_IPVERSION_IPV4                                      0
#define RSCMWINS_REPCAP_IPVERSION_IPV6                                      1
/* END GENERATE */

/*****************************************************************************
 *- Hidden Attribute Declarations -------------------------------------------*
 *****************************************************************************/

#define RSCMWINS_ATTR_OPC_TIMEOUT               (RS_ATTR_OPC_TIMEOUT)           /* ViInt32 */
#define RSCMWINS_ATTR_IO_SESSION                (RS_ATTR_IO_SESSION)            /* ViSession */
#define RSCMWINS_ATTR_OPC_CALLBACK              (RS_ATTR_OPC_CALLBACK)          /* ViAddr */
#define RSCMWINS_ATTR_CHECK_STATUS_CALLBACK     (RS_ATTR_CHECK_STATUS_CALLBACK) /* ViAddr */

/****************************************************************************
 *------------------------ Attribute Value Defines -------------------------*
 ****************************************************************************/

    /*- Instrument specific attribute value definitions --------------------*/
#define RSCMWINS_VAL_SIGNALING_UNIT_SUA1 0
#define RSCMWINS_VAL_SIGNALING_UNIT_SUA2 1
#define RSCMWINS_VAL_SIGNALING_UNIT_SUA3 2
#define RSCMWINS_VAL_SIGNALING_UNIT_SUA4 3
#define RSCMWINS_VAL_SIGNALING_UNIT_SUA5 4
#define RSCMWINS_VAL_SIGNALING_UNIT_SUA6 5

#define RSCMWINS_VAL_ANALYZER_CONNECTOR_RF1C 0
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_RF2C 1
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_RF3C 2
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_RF4C 3
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_RFAC 4
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_RFBC 5
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_R11  6
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_R12  7
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_R13  8
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_R14  9
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_R15  10
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_R16  11
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_R17  12
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_R18  13
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_R21  14
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_R22  15
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_R23  16
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_R24  17
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_R25  18
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_R26  19
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_R27  20
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_R28  21
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_R31  22
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_R32  23
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_R33  24
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_R34  25
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_R35  26
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_R36  27
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_R37  28
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_R38  29
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_R41  30
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_R42  31
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_R43  32
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_R44  33
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_R45  34
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_R46  35
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_R47  36
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_R48  37
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_RA1  38
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_RA2  39
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_RA3  40
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_RA4  41
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_RA5  42
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_RA6  43
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_RA7  44
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_RA8  45
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_RB1  46
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_RB2  47
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_RB3  48
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_RB4  49
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_RB5  50
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_RB6  51
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_RB7  52
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_RB8  53
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_R11C 54
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_R12C 55
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_R13C 56
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_R14C 57
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_R21C 58
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_R22C 59
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_R23C 60
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_R24C 61
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_R31C 62
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_R32C 63
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_R33C 64
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_R34C 65
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_R41C 66
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_R42C 67
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_R43C 68
#define RSCMWINS_VAL_ANALYZER_CONNECTOR_R44C 69

#define RSCMWINS_VAL_CONV_RX1 0
#define RSCMWINS_VAL_CONV_RX2 1
#define RSCMWINS_VAL_CONV_RX3 2
#define RSCMWINS_VAL_CONV_RX4 3

#define RSCMWINS_VAL_TX_CONN_RF1C  0
#define RSCMWINS_VAL_TX_CONN_RF1O  1
#define RSCMWINS_VAL_TX_CONN_RF2C  2
#define RSCMWINS_VAL_TX_CONN_RF3C  3
#define RSCMWINS_VAL_TX_CONN_RF3O  4
#define RSCMWINS_VAL_TX_CONN_RF4C  5
#define RSCMWINS_VAL_TX_CONN_RFAO  6
#define RSCMWINS_VAL_TX_CONN_RFBC  7
#define RSCMWINS_VAL_TX_CONN_IQ2O  8
#define RSCMWINS_VAL_TX_CONN_IQ4O  9
#define RSCMWINS_VAL_TX_CONN_IQ6O  10
#define RSCMWINS_VAL_TX_CONN_IQ8O  11
#define RSCMWINS_VAL_TX_CONN_R118  12
#define RSCMWINS_VAL_TX_CONN_R218  13
#define RSCMWINS_VAL_TX_CONN_R214  14
#define RSCMWINS_VAL_TX_CONN_R258  15
#define RSCMWINS_VAL_TX_CONN_R318  16
#define RSCMWINS_VAL_TX_CONN_R418  17
#define RSCMWINS_VAL_TX_CONN_R11C  18
#define RSCMWINS_VAL_TX_CONN_R11O  19
#define RSCMWINS_VAL_TX_CONN_R12C  20
#define RSCMWINS_VAL_TX_CONN_R13C  21
#define RSCMWINS_VAL_TX_CONN_R13O  22
#define RSCMWINS_VAL_TX_CONN_R14C  23
#define RSCMWINS_VAL_TX_CONN_I12O  24
#define RSCMWINS_VAL_TX_CONN_I14O  25
#define RSCMWINS_VAL_TX_CONN_I16O  26
#define RSCMWINS_VAL_TX_CONN_I18O  27
#define RSCMWINS_VAL_TX_CONN_R21C  28
#define RSCMWINS_VAL_TX_CONN_R21O  29
#define RSCMWINS_VAL_TX_CONN_R22C  30
#define RSCMWINS_VAL_TX_CONN_R23C  31
#define RSCMWINS_VAL_TX_CONN_R23O  32
#define RSCMWINS_VAL_TX_CONN_R24C  33
#define RSCMWINS_VAL_TX_CONN_I22O  34
#define RSCMWINS_VAL_TX_CONN_I24O  35
#define RSCMWINS_VAL_TX_CONN_I26O  36
#define RSCMWINS_VAL_TX_CONN_I28O  37
#define RSCMWINS_VAL_TX_CONN_R31C  38
#define RSCMWINS_VAL_TX_CONN_R31O  39
#define RSCMWINS_VAL_TX_CONN_R32C  40
#define RSCMWINS_VAL_TX_CONN_R33C  41
#define RSCMWINS_VAL_TX_CONN_R33O  42
#define RSCMWINS_VAL_TX_CONN_R34C  43
#define RSCMWINS_VAL_TX_CONN_I32O  44
#define RSCMWINS_VAL_TX_CONN_I34O  45
#define RSCMWINS_VAL_TX_CONN_I36O  46
#define RSCMWINS_VAL_TX_CONN_I38O  47
#define RSCMWINS_VAL_TX_CONN_R41C  48
#define RSCMWINS_VAL_TX_CONN_R41O  49
#define RSCMWINS_VAL_TX_CONN_R42C  50
#define RSCMWINS_VAL_TX_CONN_R43C  51
#define RSCMWINS_VAL_TX_CONN_R43O  52
#define RSCMWINS_VAL_TX_CONN_R44C  53
#define RSCMWINS_VAL_TX_CONN_I42O  54
#define RSCMWINS_VAL_TX_CONN_I44O  55
#define RSCMWINS_VAL_TX_CONN_I46O  56
#define RSCMWINS_VAL_TX_CONN_I48O  57
#define RSCMWINS_VAL_TX_CONN_R1183 58
#define RSCMWINS_VAL_TX_CONN_R1184 59
#define RSCMWINS_VAL_TX_CONN_R11O3 60
#define RSCMWINS_VAL_TX_CONN_R11O4 61
#define RSCMWINS_VAL_TX_CONN_RFAC  62
#define RSCMWINS_VAL_TX_CONN_RA18  63
#define RSCMWINS_VAL_TX_CONN_RB14  64
#define RSCMWINS_VAL_TX_CONN_RB18  65

#define RSCMWINS_VAL_CONV_TX1 0
#define RSCMWINS_VAL_CONV_TX2 1
#define RSCMWINS_VAL_CONV_TX3 2
#define RSCMWINS_VAL_CONV_TX4 3

#define RSCMWINS_VAL_DIRECTION_DL 0
#define RSCMWINS_VAL_DIRECTION_UL 1

#define RSCMWINS_VAL_RESULT_TYPE_ABS 0
#define RSCMWINS_VAL_RESULT_TYPE_REL 1

/****************************************************************************
 *---------------- Instrument Driver Function Declarations -----------------*
 ****************************************************************************/
ViStatus _VI_FUNC rscmwins_init (ViRsrc resourceName, ViBoolean IDQuery,
                                 ViBoolean resetDevice,
                                 ViSession* instrumentHandle);
ViStatus _VI_FUNC rscmwins_InitWithOptions (ViRsrc resourceName, ViBoolean IDQuery,
                                            ViBoolean resetDevice,
                                            ViString optionString,
                                            ViSession* instrumentHandle);
ViStatus _VI_FUNC rscmwins_ConfigureGeneratorState (ViSession instrumentHandle,
                                                    ViInt32 instance,
                                                    ViBoolean enabled);
ViStatus _VI_FUNC rscmwins_QueryCellStateAll (ViSession instrumentHandle,
                                              ViInt32 instance, ViInt32* mainState,
                                              ViInt32* synchronizationState);
ViStatus _VI_FUNC rscmwins_QueryRRCState (ViSession instrumentHandle,
                                          ViInt32 instance, ViInt32* RRCState);
ViStatus _VI_FUNC rscmwins_ConfigureRRCReleaseCause (ViSession instrumentHandle,
                                                     ViInt32 instance,
                                                     ViInt32 releaseCause);
ViStatus _VI_FUNC rscmwins_ConfigurePSAction (ViSession instrumentHandle,
                                              ViInt32 instance, ViInt32 PSAction);
ViStatus _VI_FUNC rscmwins_QueryPSState (ViSession instrumentHandle,
                                         ViInt32 instance, ViInt32* PSState);
ViStatus _VI_FUNC rscmwins_ScenarioCatalog (ViSession instrumentHandle,
                                            ViInt32 instance, ViInt32 arraySize,
                                            ViChar _VI_FAR catalog[]);
ViStatus _VI_FUNC rscmwins_ScenarioActive (ViSession instrumentHandle,
                                           ViInt32 instance, ViInt32* active);
ViStatus _VI_FUNC rscmwins_QueryEventLogAllEntries (ViSession instrumentHandle,
                                                    ViInt32 instance,
                                                    ViInt32 arraySize,
                                                    ViInt32 bufferSize,
                                                    ViChar _VI_FAR timeStamp[],
                                                    ViInt32* eventCategory,
                                                    ViChar _VI_FAR message[],
                                                    ViInt32* numberOfEntries);
ViStatus _VI_FUNC rscmwins_QueryEventLogLastEntry (ViSession instrumentHandle,
                                                   ViInt32 instance,
                                                   ViInt32 timestampBufferSize,
                                                   ViInt32 eventBufferSize,
                                                   ViChar _VI_FAR timeStamp[],
                                                   ViInt32* category,
                                                   ViChar _VI_FAR event[]);
ViStatus _VI_FUNC rscmwins_CleanEventLog (ViSession instrumentHandle,
                                          ViInt32 instance);
ViStatus _VI_FUNC rscmwins_QueryUEInfo (ViSession instrumentHandle,
                                        ViInt32 instance, ViInt32 arraySize,
                                        ViChar _VI_FAR IMSI[],
                                        ViChar _VI_FAR IMEI[]);
ViStatus _VI_FUNC rscmwins_QueryUEInfoDefaultBearersCatalog
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 arraySize,
              ViChar _VI_FAR IDs[]);
ViStatus _VI_FUNC rscmwins_QueryUEInfoAssignedIPAddresses
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 arraySize,
              ViInt32 version, ViChar _VI_FAR IPAddresses[]);
ViStatus _VI_FUNC rscmwins_QueryUECapabilitiesRRCConnectionEstablishment
             (ViSession instrumentHandle, ViInt32 instance, ViInt32* multiTone,
              ViInt32* multiCarrier, ViInt32* cIoTOptimization);
ViStatus _VI_FUNC rscmwins_QueryUECapabilitiesGeneral (ViSession instrumentHandle,
                                                       ViInt32 instance,
                                                       ViInt32* release,
                                                       ViInt32* UECategory,
                                                       ViInt32* multipleDRB);
ViStatus _VI_FUNC rscmwins_QueryUECapabilitiesRF (ViSession instrumentHandle,
                                                  ViInt32 instance,
                                                  ViInt32* multipleNSPmax,
                                                  ViInt32* powerClass14DBm);
ViStatus _VI_FUNC rscmwins_QueryUECapabilitiesRFOperatingBands
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 arraySize,
              ViInt32 _VI_FAR operatingBands[], ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwins_QueryUECapabilitiesRFBandsAll (ViSession instrumentHandle,
                                                          ViInt32 instance,
                                                          ViInt32 arraySize,
                                                          ViInt32 _VI_FAR bands[],
                                                          ViInt32 _VI_FAR powerClass[],
                                                          ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwins_QueryUECapabilitiesRFPowerClasses
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 arraySize,
              ViInt32 _VI_FAR powerClasses[], ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwins_QueryUECapabilitiesPDCP (ViSession instrumentHandle,
                                                    ViInt32 instance,
                                                    ViInt32 arraySize,
                                                    ViChar _VI_FAR supportedROHCProfiles[],
                                                    ViInt32* maxROHCContextSessions);
ViStatus _VI_FUNC rscmwins_QueryUECapabilitiesAllROHCProfiles
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 arraySize,
              ViInt32 bufferSize, ViChar _VI_FAR profiles[],
              ViInt32 _VI_FAR enable[], ViInt32* numberOfEntries);
ViStatus _VI_FUNC rscmwins_QueryUECapabilitiesReferenceROHCProfileNames
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 arraySize,
              ViChar _VI_FAR profileNames[]);
ViStatus _VI_FUNC rscmwins_QueryUECapabilitiesMAC (ViSession instrumentHandle,
                                                   ViInt32 instance,
                                                   ViInt32* inactivityMonitor,
                                                   ViInt32* releaseAssistanceIndication);
ViStatus _VI_FUNC rscmwins_QueryUECapabilitiesPhysicalLayer
             (ViSession instrumentHandle, ViInt32 instance, ViInt32* multiTone,
              ViInt32* multiCarrier, ViInt32* multiCarrierNPRACH,
              ViInt32* twoHARQProcesses, ViInt32* interferenceRandomization);
ViStatus _VI_FUNC rscmwins_QueryUECapabilitiesMultiCarrierPaging
             (ViSession instrumentHandle, ViInt32 instance,
              ViInt32* multiCarrierPaging);
ViStatus _VI_FUNC rscmwins_QueryUECapabilitiesPagingWakeUpSignal
             (ViSession instrumentHandle, ViInt32 instance,
              ViBoolean* wakeUpSignal);
ViStatus _VI_FUNC rscmwins_QueryUECapabilitiesPagingWUSMinGap
             (ViSession instrumentHandle, ViInt32 instance, ViReal64* minGap);
ViStatus _VI_FUNC rscmwins_QueryUECapabilitiesEarlyDataUp
             (ViSession instrumentHandle, ViInt32 instance, ViInt32* earlyDataUp);
ViStatus _VI_FUNC rscmwins_QueryUECapabilitiesSR (ViSession instrumentHandle,
                                                  ViInt32 instance,
                                                  ViInt32* withHARQ,
                                                  ViInt32* withoutHARQ);
ViStatus _VI_FUNC rscmwins_ConfigureUEMeasurementReportEnabled
             (ViSession instrumentHandle, ViInt32 instance, ViBoolean enabled);
ViStatus _VI_FUNC rscmwins_QueryUEMeasurementReportRSRPIndex
             (ViSession instrumentHandle, ViInt32 instance, ViInt32* index);
ViStatus _VI_FUNC rscmwins_QueryUEMeasurementReportRSRPRange
             (ViSession instrumentHandle, ViInt32 instance, ViReal64* lower,
              ViReal64* upper);
ViStatus _VI_FUNC rscmwins_QueryUEMeasurementReportRSRQIndex
             (ViSession instrumentHandle, ViInt32 instance, ViInt32* index);
ViStatus _VI_FUNC rscmwins_QueryUEMeasurementReportRSRQRange
             (ViSession instrumentHandle, ViInt32 instance, ViReal64* lower,
              ViReal64* upper);
ViStatus _VI_FUNC rscmwins_ConfigureRFScenario (ViSession instrumentHandle,
                                                ViInt32 instance,
                                                ViInt32 signalingUnit,
                                                ViInt32 RXConnector,
                                                ViInt32 RXConverter,
                                                ViInt32 TXConnector,
                                                ViInt32 TXConverter);
ViStatus _VI_FUNC rscmwins_QueryRFConfiguredRoutingSettings
             (ViSession instrumentHandle, ViInt32 instance, ViInt32* scenario,
              ViInt32* RXConnector, ViInt32* RXConverter, ViInt32* TXConnector,
              ViInt32* TXConverter);
ViStatus _VI_FUNC rscmwins_ConfigureRFOutput (ViSession instrumentHandle,
                                              ViInt32 instance,
                                              ViReal64 attenuation,
                                              ViReal64 externalDelayCompensation);
ViStatus _VI_FUNC rscmwins_ConfigureRFInput (ViSession instrumentHandle,
                                             ViInt32 instance, ViReal64 attenuation,
                                             ViReal64 externalDelayCompensation);
ViStatus _VI_FUNC rscmwins_ConfigureRFFrequencyOperatingBand
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 operatingBand);
ViStatus _VI_FUNC rscmwins_ConfigureRFFrequencyDL (ViSession instrumentHandle,
                                                   ViInt32 instance,
                                                   ViInt32 channel,
                                                   ViReal64 frequencyOffset);
ViStatus _VI_FUNC rscmwins_ConfigureRFFrequencyUL (ViSession instrumentHandle,
                                                   ViInt32 instance,
                                                   ViInt32 channel,
                                                   ViReal64 frequencyOffset);
ViStatus _VI_FUNC rscmwins_ConfigureRFExpectedUplinkPower
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 ENPMode,
              ViReal64 ENPPower, ViReal64 margin, ViReal64 mixerLevelOffset);
ViStatus _VI_FUNC rscmwins_ConfigureRFAllChannels (ViSession instrumentHandle,
                                                   ViInt32 instance, ViInt32 band,
                                                   ViInt32 channel);
ViStatus _VI_FUNC rscmwins_ConfigureRFDLPowerLevels (ViSession instrumentHandle,
                                                     ViInt32 instance,
                                                     ViReal64 NRSEPRE,
                                                     ViBoolean OCNG, ViReal64 AWGN);
ViStatus _VI_FUNC rscmwins_QueryRFUserDefinedChannel (ViSession instrumentHandle,
                                                      ViInt32 instance,
                                                      ViInt32* ULMaximum,
                                                      ViReal64* DLMaximumFreq,
                                                      ViReal64* ULMaximumFreq,
                                                      ViReal64* ULMinimumFreq);
ViStatus _VI_FUNC rscmwins_ConfigureRFUserDefinedOperatingBand
             (ViSession instrumentHandle, ViInt32 instance, ViBoolean enable,
              ViInt32 bandIndicator, ViReal64 separationValue,
              ViReal64 DLMinChannel, ViReal64 DLMaxChannel, ViReal64 DLMinFreq,
              ViReal64 ULMinChannel);
ViStatus _VI_FUNC rscmwins_ConfigureULPowerControl (ViSession instrumentHandle,
                                                    ViInt32 instance,
                                                    ViReal64 nominalPower,
                                                    ViReal64 maxAllowedPower);
ViStatus _VI_FUNC rscmwins_QueryULPowerControlNPRACHPreamblePower
             (ViSession instrumentHandle, ViInt32 instance,
              ViReal64* NPRACHPreamblePower);
ViStatus _VI_FUNC rscmwins_QueryULPowerControlNPUSCHFormatPower
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 format,
              ViReal64* NPUSCHFormatPower);
ViStatus _VI_FUNC rscmwins_ConfigureULPowerAdvancedEnabled
             (ViSession instrumentHandle, ViInt32 instance, ViBoolean enabled);
ViStatus _VI_FUNC rscmwins_ConfigureULPowerAdvanced (ViSession instrumentHandle,
                                                     ViInt32 instance,
                                                     ViReal64 nrsPower,
                                                     ViReal64 PIRTargetPower,
                                                     ViReal64 p0NominalNPUSCH,
                                                     ViInt32 pathlossCompensationAlpha);
ViStatus _VI_FUNC rscmwins_QueryULPowerAdvancedPathloss (ViSession instrumentHandle,
                                                         ViInt32 instance,
                                                         ViReal64* pathloss);
ViStatus _VI_FUNC rscmwins_ConfigurePhysicalCell (ViSession instrumentHandle,
                                                  ViInt32 instance,
                                                  ViInt32 duplexMode,
                                                  ViInt32 ULSubcarrierSpacing,
                                                  ViInt32 physicalCellID,
                                                  ViInt32 operationMode);
ViStatus _VI_FUNC rscmwins_ConfigurePhysicalCellFlexibleULDLSeparation
             (ViSession instrumentHandle, ViInt32 instance, ViBoolean separation);
ViStatus _VI_FUNC rscmwins_ConfigurePhysicalCellInBandGuardBand
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 LTEBandwidth,
              ViInt32 LTEControlRegionSize, ViInt32 powerOffset, ViInt32 inbandPCI,
              ViInt32 inbandCarrierPosition, ViInt32 guardBandCarrierPosition);
ViStatus _VI_FUNC rscmwins_ConfigurePhysicalCellInbandUplinkCarrierPosition
             (ViSession instrumentHandle, ViInt32 instance, ViBoolean enabled,
              ViInt32 position);
ViStatus _VI_FUNC rscmwins_ConfigurePhysicalCellGuardBandUplinkPosition
             (ViSession instrumentHandle, ViInt32 instance, ViBoolean enabled,
              ViInt32 position);
ViStatus _VI_FUNC rscmwins_QueryPhysicalCellLTEFrequency (ViSession instrumentHandle,
                                                          ViInt32 instance,
                                                          ViReal64* DL,
                                                          ViReal64* UL);
ViStatus _VI_FUNC rscmwins_QueryPhysicalCellNBIoTRasterOffset
             (ViSession instrumentHandle, ViInt32 instance, ViReal64* DL,
              ViReal64* UL);
ViStatus _VI_FUNC rscmwins_ConfigurePhysicalCellNPRACH (ViSession instrumentHandle,
                                                        ViInt32 instance,
                                                        ViBoolean noResponseToPreambles,
                                                        ViInt32 powerRampingStep,
                                                        ViInt32 preambleFormat,
                                                        ViInt32 maxTransmissions);
ViStatus _VI_FUNC rscmwins_ConfigureConfigurePhysicalCellCENumberOfThreshold
             (ViSession instrumentHandle, ViInt32 instance,
              ViInt32 numberOfThreshold);
ViStatus
    _VI_FUNC rscmwins_ConfigureConfigurePhysicalCellCERepetitionsPerPreamble
        (ViSession instrumentHandle, ViInt32 instance, ViInt32 level,
         ViInt32 repetitionsPerPreamble);
ViStatus
    _VI_FUNC rscmwins_ConfigureConfigurePhysicalCellCENPDCCHMaxRepetitions
        (ViSession instrumentHandle, ViInt32 instance, ViInt32 level,
         ViInt32 maxRepetitions);
ViStatus _VI_FUNC rscmwins_ConfigureConfigurePhysicalCellCERSRPThreshold
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 level,
              ViReal64 RSRPThreshold);
ViStatus _VI_FUNC rscmwins_QueryPhysicalCellCELevelReport
             (ViSession instrumentHandle, ViInt32 instance, ViInt32* report);
ViStatus _VI_FUNC rscmwins_ConfigurePhysicalCellWakeUpSignal
             (ViSession instrumentHandle, ViInt32 instance, ViBoolean enableWUS,
              ViBoolean disablePaging, ViInt32 maxDurationFactor, ViInt32 numPOs,
              ViInt32 DRXCycles);
ViStatus _VI_FUNC rscmwins_ConfigurePhysicalCellWakeUpSignalFirstPOPosition
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 position);
ViStatus
    _VI_FUNC rscmwins_ConfigureConfigurePhysicalCellWakeUpSignalTimeOffset
        (ViSession instrumentHandle, ViInt32 instance, ViInt32 DRX,
         ViInt32 eDRXShort, ViBoolean eDRXLongEnabled, ViInt32 eDRXLong);
ViStatus _VI_FUNC rscmwins_ConfigureNetworkIdentity (ViSession instrumentHandle,
                                                     ViInt32 instance, ViInt32 MCC,
                                                     ViInt32 MNC, ViInt32 MNCDigits,
                                                     ViInt32 TAC,
                                                     ViString CIDEUTRAN);
ViStatus _VI_FUNC rscmwins_ConfigureNetworkSecurity (ViSession instrumentHandle,
                                                     ViInt32 instance,
                                                     ViBoolean authentication,
                                                     ViBoolean enabled,
                                                     ViInt32 integrityAlgorithm,
                                                     ViString secretKey,
                                                     ViBoolean milenage,
                                                     ViString OPc);
ViStatus _VI_FUNC rscmwins_ConfigureNetworkUEIdentity (ViSession instrumentHandle,
                                                       ViInt32 instance,
                                                       ViString defaultIMSI);
ViStatus _VI_FUNC rscmwins_ConfigureNetworkTimer (ViSession instrumentHandle,
                                                  ViInt32 instance,
                                                  ViReal64 outOfSync,
                                                  ViBoolean t3324Enabled,
                                                  ViReal64 t3324Value,
                                                  ViBoolean t3412Enabled,
                                                  ViReal64 t3412Value,
                                                  ViReal64 t3412Extended);
ViStatus _VI_FUNC rscmwins_ConfigureNetworkSynchronization
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 syncZone,
              ViReal64 syncOffset);
ViStatus _VI_FUNC rscmwins_ConfigureNetworkTime (ViSession instrumentHandle,
                                                 ViInt32 instance,
                                                 ViInt32 timeSource,
                                                 ViBoolean daylightSavingTime,
                                                 ViInt32 daylightSavingTimeValue,
                                                 ViReal64 localTimeZoneOffset);
ViStatus _VI_FUNC rscmwins_ConfigureNetworkTimeSendNow (ViSession instrumentHandle,
                                                        ViInt32 instance);
ViStatus _VI_FUNC rscmwins_ConfigureNetworkTimeSendTime (ViSession instrumentHandle,
                                                         ViInt32 instance,
                                                         ViBoolean sendTime);
ViStatus _VI_FUNC rscmwins_ConfigureNetworkUTCDateTime (ViSession instrumentHandle,
                                                        ViInt32 instance,
                                                        ViInt32 month, ViInt32 day,
                                                        ViInt32 year, ViInt32 hour,
                                                        ViInt32 minute,
                                                        ViReal64 second);
ViStatus _VI_FUNC rscmwins_ConfigureConnectionType (ViSession instrumentHandle,
                                                    ViInt32 instance,
                                                    ViInt32 connectionType);
ViStatus _VI_FUNC rscmwins_ConfigureConnectionTestMode (ViSession instrumentHandle,
                                                        ViInt32 instance,
                                                        ViBoolean enabled,
                                                        ViInt32 IPVersion);
ViStatus _VI_FUNC rscmwins_ConfigureConnectionDataApplication
             (ViSession instrumentHandle, ViInt32 instance,
              ViInt32 cIoTOptimization, ViInt32 IPVersion);
ViStatus _VI_FUNC rscmwins_ConfigureConnectionDestinationServer
             (ViSession instrumentHandle, ViInt32 instance, ViString IPAddress,
              ViInt32 port);
ViStatus _VI_FUNC rscmwins_ConfigureConnectionRRC (ViSession instrumentHandle,
                                                   ViInt32 instance,
                                                   ViBoolean RRCKeep,
                                                   ViInt32 timer);
ViStatus _VI_FUNC rscmwins_ConfigureConnectionSchedulingType
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 schedulingType);
ViStatus _VI_FUNC rscmwins_ConfigureConnectionPaging (ViSession instrumentHandle,
                                                      ViInt32 instance,
                                                      ViInt32 generalDefaultPagingCycle,
                                                      ViBoolean idleMode,
                                                      ViInt32 timeWindow);
ViStatus _VI_FUNC rscmwins_ConfigureConnectionPCCHConfignB
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 PCCHConfigNB);
ViStatus _VI_FUNC rscmwins_ConfigureConnectionModificationPeriodCoefficient
             (ViSession instrumentHandle, ViInt32 instance,
              ViInt32 periodCoefficient);
ViStatus _VI_FUNC rscmwins_ConfigureConnectionPSMAllowed (ViSession instrumentHandle,
                                                          ViInt32 instance,
                                                          ViBoolean PSMAllowed);
ViStatus _VI_FUNC rscmwins_ConfigureConnectionCycleLength
             (ViSession instrumentHandle, ViInt32 instance,
              ViInt32 generalCycleLength);
ViStatus _VI_FUNC rscmwins_ConfigureConnectionDLRMC (ViSession instrumentHandle,
                                                     ViInt32 instance,
                                                     ViInt32 subcarriers,
                                                     ViInt32 startSubcarrier,
                                                     ViInt32 MCSindex,
                                                     ViInt32 subframes,
                                                     ViInt32 repetitions);
ViStatus _VI_FUNC rscmwins_QueryConnectionDLRMC (ViSession instrumentHandle,
                                                 ViInt32 instance,
                                                 ViInt32* MCSIndex,
                                                 ViInt32* modulation,
                                                 ViInt32* transportBlockSize);
ViStatus
    _VI_FUNC rscmwins_ConfigureConnectionRRCAllowPagingAfterSITransmission
        (ViSession instrumentHandle, ViInt32 instance, ViBoolean enabled);
ViStatus _VI_FUNC rscmwins_ConfigureConnectionInterferenceRandomization
             (ViSession instrumentHandle, ViInt32 instance, ViBoolean enabled);
ViStatus _VI_FUNC rscmwins_ConfigureConnectionPagingCollisionReport
             (ViSession instrumentHandle, ViInt32 instance, ViBoolean enabled);
ViStatus _VI_FUNC rscmwins_ConfigureConnectionEDT (ViSession instrumentHandle,
                                                   ViInt32 instance,
                                                   ViBoolean enabled,
                                                   ViInt32 resourceNumbers,
                                                   ViBoolean userPlanEnabled,
                                                   ViBoolean TBSEnabled,
                                                   ViBoolean TBSSubsetEnabled);
ViStatus _VI_FUNC rscmwins_ConfigureConnectionULRMC (ViSession instrumentHandle,
                                                     ViInt32 instance,
                                                     ViInt32 subcarriers,
                                                     ViInt32 startSubcarrier,
                                                     ViInt32 MCSIndex,
                                                     ViInt32 resourceUnits,
                                                     ViInt32 repetitions);
ViStatus _VI_FUNC rscmwins_QueryConnectionULRMC (ViSession instrumentHandle,
                                                 ViInt32 instance,
                                                 ViInt32* MCSIndex,
                                                 ViInt32* modulation,
                                                 ViInt32* transportBlockSize);
ViStatus _VI_FUNC rscmwins_QueryConnectionULRMCFormat (ViSession instrumentHandle,
                                                       ViInt32 instance,
                                                       ViInt32* subcarriers,
                                                       ViInt32* startSubcarrier,
                                                       ViInt32* modulation,
                                                       ViInt32* resourceUnits,
                                                       ViInt32* repetitions);
ViStatus _VI_FUNC rscmwins_ConfigureConnectionUserDefinedPattern
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 pattern);
ViStatus _VI_FUNC rscmwins_ConfigureConnectionUserDL (ViSession instrumentHandle,
                                                      ViInt32 instance,
                                                      ViInt32 setNumber,
                                                      ViInt32 subcarriers,
                                                      ViInt32 startSubcarrier,
                                                      ViInt32 MCSIndex,
                                                      ViInt32 subframes,
                                                      ViInt32 repetitions);
ViStatus _VI_FUNC rscmwins_ConfigureConnectionUserUL (ViSession instrumentHandle,
                                                      ViInt32 instance,
                                                      ViInt32 setNumber,
                                                      ViInt32 subcarriers,
                                                      ViInt32 startSubcarrier,
                                                      ViInt32 MCSIndex,
                                                      ViInt32 resourceUnits,
                                                      ViInt32 repetitions);
ViStatus _VI_FUNC rscmwins_ConfigureConnectionUserMCSIndex
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 direction,
              ViInt32* MCSIndex, ViInt32* modulation, ViInt32* transportBlockSize);
ViStatus _VI_FUNC rscmwins_QueryConnectionUserFormat (ViSession instrumentHandle,
                                                      ViInt32 instance,
                                                      ViInt32* subcarriers,
                                                      ViInt32* startSubcarrier,
                                                      ViInt32* modulation,
                                                      ViInt32* resourceUnits,
                                                      ViInt32* repetitions);
ViStatus _VI_FUNC rscmwins_ConfigureHARQSettings (ViSession instrumentHandle,
                                                  ViInt32 instance,
                                                  ViBoolean HARQEnable,
                                                  ViInt32 maxNoOfTransmissions,
                                                  ViInt32 noOfHARQProcesses);
ViStatus _VI_FUNC rscmwins_eConfigureConnectionNAC13Enabled
             (ViSession instrumentHandle, ViInt32 instance, ViBoolean enabled);
ViStatus _VI_FUNC rscmwins_ConfigureConnectionNAC13ChannelFrequency
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 DLChannel,
              ViInt32 ULChannel);
ViStatus _VI_FUNC rscmwins_ConfigureConnectionNAC13DLBitmap
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 bitmap,
              ViInt32 bitmapExplicit);
ViStatus _VI_FUNC rscmwins_ConfigureConnectionNAC13Gap (ViSession instrumentHandle,
                                                        ViInt32 instance,
                                                        ViInt32 gap,
                                                        ViInt32 threshold,
                                                        ViInt32 periodicity,
                                                        ViInt32 durationCoefficient);
ViStatus _VI_FUNC rscmwins_ConfigureConnectionNAC13NRSPowerOffset
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 offset);
ViStatus _VI_FUNC rscmwins_ConfigureConnectionNAC14Paging
             (ViSession instrumentHandle, ViInt32 instance, ViBoolean enabled,
              ViInt32 weightAnchor);
ViStatus _VI_FUNC rscmwins_ConfigureConnectionNAC14PagingWeightAnchorEnabled
             (ViSession instrumentHandle, ViInt32 instance, ViBoolean enabled);
ViStatus _VI_FUNC rscmwins_ConfigureConnectionNAC14PagingCarrierState
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 carrier,
              ViBoolean enabled);
ViStatus _VI_FUNC rscmwins_ConfigureConnectionNAC14PagingDLCarrier
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 carrier,
              ViInt32 channelFrequency, ViInt32 channelOffset, ViInt32 gap,
              ViInt32 gapThreshold, ViInt32 gapPeriodicity,
              ViInt32 gapDurationCoefficient, ViInt32 NRSPowerOffset);
ViStatus _VI_FUNC rscmwins_ConfigureConnectionNAC14PagingDLCarrierBitmap
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 carrier,
              ViInt32 bitmap, ViInt32 bitmapExplicit);
ViStatus _VI_FUNC rscmwins_ConfigureConnectionNAC14PagingCarrierPCCH
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 carrier,
              ViBoolean enabled, ViInt32 numOfRepetitions, ViInt32 pagingWeight);
ViStatus
    _VI_FUNC rscmwins_ConfigureConnectionNAC14PagingCarrierPCCHWeightEnabled
        (ViSession instrumentHandle, ViInt32 instance, ViInt32 carrier,
         ViBoolean enabled);
ViStatus _VI_FUNC rscmwins_ConfigureConnectionNAC14PagingCarrierWUS
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 carrier,
              ViBoolean enabled, ViInt32 maxDurationFactor);
ViStatus _VI_FUNC rscmwins_ConfigureConnectionNAC14RACH (ViSession instrumentHandle,
                                                         ViInt32 instance,
                                                         ViBoolean enabled,
                                                         ViBoolean anchorEnabled,
                                                         ViInt32 anchor);
ViStatus _VI_FUNC rscmwins_ConfigureConnectionNAC14RACHCarrierEnabled
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 carrier,
              ViBoolean enabled);
ViStatus _VI_FUNC rscmwins_ConfigureConnectionNAC14RACHULCarrier
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 carrier,
              ViInt32 channelFrequency, ViInt32 channelOffset);
ViStatus _VI_FUNC rscmwins_ConfigureConnectionNPDCCHUESpecificSearchSpace
             (ViSession instrumentHandle, ViInt32 instance,
              ViInt32 maxNoRepetitionsRmax, ViInt32 noRepetitions, ViInt32 startSF,
              ViInt32 offset);
ViStatus _VI_FUNC rscmwins_QueryConnectionNPDCCHUESpecificSearchSpace
             (ViSession instrumentHandle, ViInt32 instance, ViInt32* noRepetitions,
              ViInt32* period, ViInt32* offset);
ViStatus _VI_FUNC rscmwins_ConfigureConnectionNPDCCHCSSMaxNoRepetitionsRmax
             (ViSession instrumentHandle, ViInt32 instance,
              ViInt32 maxNoRepetitionsRmax);
ViStatus _VI_FUNC rscmwins_ConfigureConnectionConnectedDRXState
             (ViSession instrumentHandle, ViInt32 instance, ViBoolean enabled);
ViStatus _VI_FUNC rscmwins_ConfigureConnectionConnectedDRXOnDurationTimer
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 onDurationTimer,
              ViInt32 inactivityTimer, ViInt32 retransmissionTimer, ViInt32 cycle,
              ViInt32 startOffset, ViInt32 ULRetransTimer);
ViStatus _VI_FUNC rscmwins_ConfigureSchedulingRequest (ViSession instrumentHandle,
                                                       ViInt32 instance,
                                                       ViBoolean withHARQ,
                                                       ViBoolean withoutHARQ);
ViStatus _VI_FUNC rscmwins_ConfigureSchedulingRequestWithoutHARQ
             (ViSession instrumentHandle, ViInt32 instance, ViInt32 alpha,
              ViInt32 carrierIndex, ViInt32 resourceIndex, ViReal64 SR,
              ViInt32 indexFormat, ViInt32 formatValue);
ViStatus _VI_FUNC rscmwins_ConfigureSchedulingRequestNoResponseToSREnabled
             (ViSession instrumentHandle, ViInt32 instance, ViBoolean enabled);
ViStatus _VI_FUNC rscmwins_InitiateBLERMeasurement (ViSession instrumentHandle,
                                                    ViInt32 instance);
ViStatus _VI_FUNC rscmwins_StopBLERMeasurement (ViSession instrumentHandle,
                                                ViInt32 instance);
ViStatus _VI_FUNC rscmwins_AbortBLERMeasurement (ViSession instrumentHandle,
                                                 ViInt32 instance);
ViStatus _VI_FUNC rscmwins_QueryBLERState (ViSession instrumentHandle,
                                           ViInt32 instance, ViInt32* BLERState);
ViStatus _VI_FUNC rscmwins_QueryBLERStateAll (ViSession instrumentHandle,
                                              ViInt32 instance, ViInt32* mainState,
                                              ViInt32* synchronizationState,
                                              ViInt32* resourceState);
ViStatus _VI_FUNC rscmwins_ConfigureBLERTimeout (ViSession instrumentHandle,
                                                 ViInt32 instance,
                                                 ViInt32 BLERTimeout);
ViStatus _VI_FUNC rscmwins_ConfigureBLERMeasurement (ViSession instrumentHandle,
                                                     ViInt32 instance,
                                                     ViInt32 repetition,
                                                     ViInt32 numberOfSamples,
                                                     ViInt32 errorRatioCalculation);
ViStatus _VI_FUNC rscmwins_FetchMeasurementBLER (ViSession instrumentHandle,
                                                 ViInt32 instance,
                                                 ViInt32 resultType,
                                                 ViInt32 arraySize,
                                                 ViInt32* reliability,
                                                 ViReal64 _VI_FAR results[],
                                                 ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwins_FetchMeasurementBLERUL (ViSession instrumentHandle,
                                                   ViInt32 instance,
                                                   ViInt32 resultType,
                                                   ViInt32 arraySize,
                                                   ViInt32* reliability,
                                                   ViReal64 _VI_FAR results[],
                                                   ViInt32* returnedValues);
ViStatus _VI_FUNC rscmwins_SetAttributeViInt32 (ViSession instrumentHandle,
                                                ViString repeatedCapabilityName,
                                                ViUInt32 attributeID,
                                                ViInt32 attributeValue);
ViStatus _VI_FUNC rscmwins_SetAttributeViReal64 (ViSession instrumentHandle,
                                                 ViString repeatedCapabilityName,
                                                 ViUInt32 attributeID,
                                                 ViReal64 attributeValue);
ViStatus _VI_FUNC rscmwins_SetAttributeViString (ViSession instrumentHandle,
                                                 ViString repeatedCapabilityName,
                                                 ViUInt32 attributeID,
                                                 ViString attributeValue);
ViStatus _VI_FUNC rscmwins_SetAttributeRawString (ViSession instrumentHandle,
                                                  ViString repeatedCapabilityName,
                                                  ViUInt32 attributeID,
                                                  ViString attributeValue);
ViStatus _VI_FUNC rscmwins_SetAttributeViBoolean (ViSession instrumentHandle,
                                                  ViString repeatedCapabilityName,
                                                  ViUInt32 attributeID,
                                                  ViBoolean attributeValue);
ViStatus _VI_FUNC rscmwins_SetAttributeViSession (ViSession instrumentHandle,
                                                  ViString repeatedCapabilityName,
                                                  ViUInt32 attributeID,
                                                  ViSession attributeValue);
ViStatus _VI_FUNC rscmwins_GetAttributeRepCapName (ViSession instrumentHandle,
                                                   ViUInt32 attributeID,
                                                   ViString repCapNameID,
                                                   ViInt32 index,
                                                   ViInt32 bufferSize,
                                                   ViChar _VI_FAR repCapName[]);
ViStatus _VI_FUNC rscmwins_GetAttributeRepeatedCapabilityIds
             (ViSession instrumentHandle, ViUInt32 attributeID, ViInt32 bufferSize,
              ViChar _VI_FAR repeatedCapabilityId_s[]);
ViStatus _VI_FUNC rscmwins_GetAttributeRepeatedCapabilityIdNames
             (ViSession instrumentHandle, ViUInt32 attributeID,
              ViString repeatedCapabilityId, ViInt32 bufferSize,
              ViChar _VI_FAR repeatedCapabilityIdName_s[]);
ViStatus _VI_FUNC rscmwins_GetAttributeViInt32 (ViSession instrumentHandle,
                                                ViString repeatedCapabilityName,
                                                ViUInt32 attributeID,
                                                ViInt32* attributeValue);
ViStatus _VI_FUNC rscmwins_GetAttributeViReal64 (ViSession instrumentHandle,
                                                 ViString repeatedCapabilityName,
                                                 ViUInt32 attributeID,
                                                 ViReal64* attributeValue);
ViStatus _VI_FUNC rscmwins_GetAttributeViString (ViSession instrumentHandle,
                                                 ViString repeatedCapabilityName,
                                                 ViUInt32 attributeID,
                                                 ViInt32 bufferSize,
                                                 ViChar _VI_FAR attributeValue[]);
ViStatus _VI_FUNC rscmwins_GetAttributeRawString (ViSession instrumentHandle,
                                                  ViString repeatedCapabilityName,
                                                  ViUInt32 attributeID,
                                                  ViInt32 bufferSize,
                                                  ViChar _VI_FAR attributeValue[]);
ViStatus _VI_FUNC rscmwins_GetAttributeViBoolean (ViSession instrumentHandle,
                                                  ViString repeatedCapabilityName,
                                                  ViUInt32 attributeID,
                                                  ViBoolean* attributeValue);
ViStatus _VI_FUNC rscmwins_GetAttributeViSession (ViSession instrumentHandle,
                                                  ViString repeatedCapabilityName,
                                                  ViUInt32 attributeID,
                                                  ViSession* attributeValue);
ViStatus _VI_FUNC rscmwins_CheckAttributeViInt32 (ViSession instrumentHandle,
                                                  ViString repeatedCapabilityName,
                                                  ViUInt32 attributeID,
                                                  ViInt32 attributeValue);
ViStatus _VI_FUNC rscmwins_CheckAttributeViReal64 (ViSession instrumentHandle,
                                                   ViString repeatedCapabilityName,
                                                   ViUInt32 attributeID,
                                                   ViReal64 attributeValue);
ViStatus _VI_FUNC rscmwins_CheckAttributeViString (ViSession instrumentHandle,
                                                   ViString repeatedCapabilityName,
                                                   ViUInt32 attributeID,
                                                   ViString attributeValue);
ViStatus _VI_FUNC rscmwins_CheckAttributeViBoolean (ViSession instrumentHandle,
                                                    ViString repeatedCapabilityName,
                                                    ViUInt32 attributeID,
                                                    ViBoolean attributeValue);
ViStatus _VI_FUNC rscmwins_CheckAttributeViSession (ViSession instrumentHandle,
                                                    ViString repeatedCapabilityName,
                                                    ViUInt32 attributeID,
                                                    ViSession attributeValue);
ViStatus _VI_FUNC rscmwins_reset (ViSession instrumentHandle);
ViStatus _VI_FUNC rscmwins_self_test (ViSession instrumentHandle,
                                      ViInt16* selfTestResult,
                                      ViChar _VI_FAR selfTestMessage[]);
ViStatus _VI_FUNC rscmwins_revision_query (ViSession instrumentHandle,
                                           ViChar _VI_FAR instrumentDriverRevision[],
                                           ViChar _VI_FAR firmwareRevision[]);
ViStatus _VI_FUNC rscmwins_SystemVersion (ViSession instrumentHandle,
                                          ViInt32 length,
                                          ViChar _VI_FAR systemVersion[]);
ViStatus _VI_FUNC rscmwins_error_query (ViSession instrumentHandle,
                                        ViInt32* errorCode,
                                        ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC rscmwins_ErrorList (ViSession instrumentHandle,
                                      ViInt32 bufferSize, ViChar _VI_FAR errors[]);
ViStatus _VI_FUNC rscmwins_error_message (ViSession instrumentHandle,
                                          ViStatus errorCode,
                                          ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC rscmwins_ReliabilityIndicator (ViSession instrumentHandle,
                                                 ViInt32 reliabilityCode,
                                                 ViChar _VI_FAR reliabilityMessage[]);
ViStatus _VI_FUNC rscmwins_Preset (ViSession instrumentHandle);
ViStatus _VI_FUNC rscmwins_ClearStatus (ViSession instrumentHandle);
ViStatus _VI_FUNC rscmwins_IDQueryResponse (ViSession instrumentHandle,
                                            ViChar _VI_FAR IDQueryResponse[]);
ViStatus _VI_FUNC rscmwins_ProcessAllPreviousCommands (ViSession instrumentHandle);
ViStatus _VI_FUNC rscmwins_QueryOPC (ViSession instrumentHandle, ViInt32* OPC);
ViStatus _VI_FUNC rscmwins_SetVISATimeout (ViSession instrumentHandle,
                                           ViUInt32 VISATimeout);
ViStatus _VI_FUNC rscmwins_GetVISATimeout (ViSession instrumentHandle,
                                           ViUInt32* VISATimeout);
ViStatus _VI_FUNC rscmwins_ConfigureErrorChecking (ViSession instrumentHandle,
                                                   ViBoolean optionChecking,
                                                   ViBoolean rangeChecking,
                                                   ViBoolean statusChecking);
ViStatus _VI_FUNC rscmwins_SetTimeout (ViSession instrumentHandle, ViInt32 timeout);
ViStatus _VI_FUNC rscmwins_GetTimeout (ViSession instrumentHandle,
                                       ViInt32* timeout);
ViStatus _VI_FUNC rscmwins_ConfigureAutoSystemErrQuery (ViSession instrumentHandle,
                                                        ViBoolean autoSystErrQuery);
ViStatus _VI_FUNC rscmwins_ConfigureMultiThreadLocking (ViSession instrumentHandle,
                                                        ViBoolean multiThreadLocking);
ViStatus _VI_FUNC rscmwins_GetError (ViSession instrumentHandle, ViStatus* code,
                                     ViInt32 bufferSize,
                                     ViChar _VI_FAR description[]);
ViStatus _VI_FUNC rscmwins_ClearError (ViSession instrumentHandle);
ViStatus _VI_FUNC rscmwins_ReadToFileFromInstrument (ViSession instrumentHandle,
                                                     ViString source,
                                                     ViString destination);
ViStatus _VI_FUNC rscmwins_WriteFromFileToInstrument (ViSession instrumentHandle,
                                                      ViString source,
                                                      ViString destination);
ViStatus _VI_FUNC rscmwins_WriteInstrData (ViSession instrumentHandle,
                                           ViString writeBuffer);
ViStatus _VI_FUNC rscmwins_ReadInstrData (ViSession instrumentHandle,
                                          ViInt32 numberOfBytesToRead,
                                          ViChar _VI_FAR readBuffer[],
                                          ViUInt32* numBytesRead);
ViStatus _VI_FUNC rscmwins_WriteCommandWithOPCSync (ViSession instrumentHandle,
                                                    ViString writeBuffer,
                                                    ViUInt32 timeout);
ViStatus _VI_FUNC rscmwins_QueryWithOPCSync (ViSession instrumentHandle,
                                             ViString writeBuffer, ViUInt32 timeout,
                                             ViInt32 bufferSize,
                                             ViChar _VI_FAR readBuffer[],
                                             ViUInt32* numBytesRead);
ViStatus _VI_FUNC rscmwins_QueryViBoolean (ViSession instrumentHandle,
                                           ViString command, ViBoolean* value);
ViStatus _VI_FUNC rscmwins_QueryViInt32 (ViSession instrumentHandle,
                                         ViString command, ViInt32* value);
ViStatus _VI_FUNC rscmwins_QueryViReal64 (ViSession instrumentHandle,
                                          ViString command, ViReal64* value);
ViStatus _VI_FUNC rscmwins_QueryViString (ViSession instrumentHandle,
                                          ViString command, ViInt32 bufferSize,
                                          ViChar _VI_FAR value[]);
ViStatus _VI_FUNC rscmwins_close (ViSession instrumentHandle);

/****************************************************************************
 *------------------------ Error And Completion Codes ----------------------*
 ****************************************************************************/

#define RSCMWINS_WARN_MEASURE_UNCALIBRATED    (RS_CLASS_WARN_BASE + 0x0001L)
#define RSCMWINS_WARN_OVER_RANGE              (RS_CLASS_WARN_BASE + 0x0002L)

#define RSCMWINS_ERROR_INCORRECT_STATE        (RS_CLASS_ERROR_BASE + 0x0003L)
#define RSCMWINS_ERROR_INCORRECT_RESPONSE     (RS_CLASS_ERROR_BASE + 0x0002L)
#define RSCMWINS_ERROR_MAX_TIME_EXCEEDED      (RS_CLASS_ERROR_BASE + 0x0001L)
#define RSCMWINS_ERROR_RELIABILITY_INDICATOR  (RS_SPECIFIC_ERROR_BASE + 0x0004L)

#define RSCMWINS_WARNMSG_MEASURE_UNCALIBRATED "Uncalibrated measurement"
#define RSCMWINS_WARNMSG_OVER_RANGE           "Measurement overrange"

#define RSCMWINS_ERRMSG_INCORRECT_STATE     "Instrument in incorrect state"
#define RSCMWINS_ERRMSG_INCORRECT_RESPONSE      "Response incorrect; report problem to R&S support!"
#define RSCMWINS_ERRMSG_MAX_TIME_EXCEEDED     "Max Time Exceeded"
#define RSCMWINS_ERRMSG_RELIABILITY_INDICATOR "Reliability Indicator error"

#define RSCMWINS_ERROR_CODES_AND_MSGS \
    {RSCMWINS_WARN_MEASURE_UNCALIBRATED,  RSCMWINS_WARNMSG_MEASURE_UNCALIBRATED},\
    {RSCMWINS_WARN_OVER_RANGE,            RSCMWINS_WARNMSG_OVER_RANGE},\
    {RSCMWINS_ERROR_INCORRECT_STATE ,   RSCMWINS_ERRMSG_INCORRECT_STATE },\
    {RSCMWINS_ERROR_INCORRECT_RESPONSE,     RSCMWINS_ERRMSG_INCORRECT_RESPONSE},\
    {RSCMWINS_ERROR_MAX_TIME_EXCEEDED,    RSCMWINS_ERRMSG_MAX_TIME_EXCEEDED},\
    {RSCMWINS_ERROR_RELIABILITY_INDICATOR, RSCMWINS_ERRMSG_RELIABILITY_INDICATOR}

/****************************************************************************
 *---------------------------- End Include File ----------------------------*
 ****************************************************************************/

#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif
#endif /* __RSCMWINS_HEADER */
