/*****************************************************************************
 *------------------------ Utility  -----------------------------------------*
 *****************************************************************************/
#include <float.h>
#include <math.h>
#include "rscmwins.h"

ViStatus rscmwins_bin_WriteCallback(ViSession          instrSession,
                                    ViConstString      repCapName,
                                    RsCoreAttributePtr attr,
                                    void*              value);
ViStatus rscmwins_bin_ReadCallback(ViSession          instrSession,
                                   ViConstString      repCapName,
                                   RsCoreAttributePtr attr);

/*****************************************************************************
 *- Callback Declarations ---------------------------------------------------*
 *****************************************************************************/
#pragma warning( disable : 4152 )
/*****************************************************************************
 * Function: rscmwins_InitAttributes
 * Purpose:  This function inits attributes to the desired values if needed.
 *****************************************************************************/
ViStatus rscmwins_InitAttributes(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    // - Class Driver Identification -
    checkErr(RsCore_SetAttributeViString(instrSession, "", RS_ATTR_CLASS_DRIVER_DESCRIPTION, 0, RSCMWINS_CLASS_DRIVER_DESCRIPTION));
    checkErr(RsCore_SetAttributeViString(instrSession, "", RS_ATTR_CLASS_DRIVER_PREFIX, 0, RSCMWINS_CLASS_DRIVER_PREFIX));
    checkErr(RsCore_SetAttributeViString(instrSession, "", RS_ATTR_CLASS_DRIVER_VENDOR, 0, RSCMWINS_CLASS_DRIVER_VENDOR));
    checkErr(RsCore_SetAttributeViString(instrSession, "", RS_ATTR_CLASS_DRIVER_REVISION, 0, RSCMWINS_CLASS_DRIVER_REVISION));
    checkErr(RsCore_SetAttributeViInt32(instrSession, "", RS_ATTR_CLASS_DRIVER_CLASS_SPEC_MAJOR_VERSION, 0, RSCMWINS_CLASS_SPEC_MAJOR_VERSION));
    checkErr(RsCore_SetAttributeViInt32(instrSession, "", RS_ATTR_CLASS_DRIVER_CLASS_SPEC_MINOR_VERSION, 0, RSCMWINS_CLASS_SPEC_MINOR_VERSION));

    // - Driver Identification -
    checkErr(RsCore_SetAttributeViString(instrSession, "", RS_ATTR_SPECIFIC_DRIVER_DESCRIPTION, 0, RSCMWINS_SPECIFIC_DRIVER_DESCRIPTION));
    checkErr(RsCore_SetAttributeViString(instrSession, "", RS_ATTR_SPECIFIC_DRIVER_PREFIX, 0, RSCMWINS_SPECIFIC_DRIVER_PREFIX));
    checkErr(RsCore_SetAttributeViString(instrSession, "", RS_ATTR_SPECIFIC_DRIVER_LOCATOR, 0, RSCMWINS_SPECIFIC_DRIVER_LOCATOR));
    checkErr(RsCore_SetAttributeViString(instrSession, "", RS_ATTR_SPECIFIC_DRIVER_VENDOR, 0, RSCMWINS_SPECIFIC_DRIVER_VENDOR));
    checkErr(RsCore_SetAttributeViInt32(instrSession, "", RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION, 0, RSCMWINS_CLASS_SPEC_MAJOR_VERSION));
    checkErr(RsCore_SetAttributeViInt32(instrSession, "", RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION, 0, RSCMWINS_CLASS_SPEC_MINOR_VERSION));

    // - Driver Capabilities -
    checkErr(RsCore_SetAttributeViString(instrSession, "", RS_ATTR_SUPPORTED_INSTRUMENT_MODELS, 0, RSCMWINS_SUPPORTED_INSTRUMENT_MODELS));
    checkErr(RsCore_SetAttributeViString(instrSession, "", RS_ATTR_GROUP_CAPABILITIES, 0, RSCMWINS_GROUP_CAPABILITIES));
    checkErr(RsCore_SetAttributeViString(instrSession, "", RS_ATTR_FUNCTION_CAPABILITIES, 0, RSCMWINS_FUNCTION_CAPABILITIES));

    // - Version Info -
    checkErr(RsCore_SetAttributeViInt32(instrSession, "", RS_ATTR_SPECIFIC_DRIVER_MAJOR_VERSION, 0, RSCMWINS_MAJOR_VERSION));
    checkErr(RsCore_SetAttributeViInt32(instrSession, "", RS_ATTR_SPECIFIC_DRIVER_MINOR_VERSION, 0, RSCMWINS_MINOR_VERSION));
    checkErr(RsCore_SetAttributeViInt32(instrSession, "", RS_ATTR_SPECIFIC_DRIVER_MINOR_MINOR_VERSION, 0, RSCMWINS_MINOR_MINOR_VERSION));

    checkErr(RsCore_SetAttributeViInt32(instrSession, "", RS_ATTR_CLASS_DRIVER_MAJOR_VERSION, 0, RSCMWINS_CLASS_SPEC_MAJOR_VERSION));
    checkErr(RsCore_SetAttributeViInt32(instrSession, "", RS_ATTR_CLASS_DRIVER_MINOR_VERSION, 0, RSCMWINS_CLASS_SPEC_MINOR_VERSION));

    checkErr(RsCore_SetSpecificDriverRevision(instrSession, RS_ATTR_SPECIFIC_DRIVER_REVISION));

Error:
    return error;
}

/*****************************************************************************
 * Function: rscmwins_DefaultInstrSetup
 * Purpose:  This function sends a default setup to the instrument. The
 *           rscmwins_reset function calls this function. The
 *           rscmwins_RsInit function calls this function when the
 *           user passes VI_FALSE for the reset parameter. This function is
 *           useful for configuring settings that other instrument driver
 *           functions require.
 *
 *           Note:  Call this function only when the session is locked.
 *****************************************************************************/
ViStatus rscmwins_DefaultInstrSetup(ViSession instrSession)
{
    ViStatus         error = VI_SUCCESS;
    RsCoreSessionPtr rsSession = NULL;

    checkErr(RsCore_GetRsSession(instrSession, &rsSession));

    // Set all the attributes to the default state. Do not update inherent attributes!
    checkErr(RsCore_ApplyAttributeDefaults(instrSession, VI_FALSE));

    // Init attributes
    checkErr(rscmwins_InitAttributes(instrSession));

    rsSession->fastSweepInstrument = 0;
    checkErr(RsCore_ResetRegistersEseSre(instrSession));
    checkErr(RsCore_Write(instrSession, ":FORM:BASE ASC,10"));
    checkErr(RsCore_Write(instrSession, ":SYST:DISP:UPD OFF"));
    checkErr(RsCore_QueryViInt32(instrSession, "*OPC?", NULL));

Error:
    return error;
}

/*****************************************************************************
 * Function: rscmwins_CheckStatus
 * Purpose:  This function checks the status of the instrument to detect
 *           whether the instrument has encountered an error. This function
 *           is called at the end of most exported driver functions. If the
 *           instrument reports an error, this function returns
 *           RS_ERROR_INSTRUMENT_SPECIFIC. The user can set the
 *           rscmwins_ATTR_QUERY_INSTRUMENT_STATUS attribute to VI_FALSE to disable this
 *           check and increase execution speed.
 *
 *           Note:  Call this function only when the session is locked.
 *****************************************************************************/
ViStatus rscmwins_CheckStatus(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    if (RsCore_QueryInstrStatus(instrSession) && !RsCore_Simulating(instrSession))
    {
        checkErr(RsCore_CheckStatus(instrSession, VI_SUCCESS));
    }

Error:
    return error;
}

/*****************************************************************************
 * Function: String Index
 * Purpose:  Returns the index of string in string array
*****************************************************************************/
ViInt32 rscmwins_FindStringIndex(ViString array[], ViChar buff[])
{
    ViInt32 index = 0;

    while (array[index])
    {
        if (!strcmp(buff, array[index]))
            break;
        index++;
    }
    /* If found string is not found returns -1. */
    if (!array[index]) return -1;

    return index;
}

/*****************************************************************************
 * Function: rscmwins_instanceRepCap
 * Purpose:  This function checks instance repeated capability and
 *           creates proper string.
 *****************************************************************************/
ViStatus rscmwins_instanceRepCap(ViSession instrSession,
                                 ViInt32   instance,
                                 ViChar    repCap[])
{
    ViStatus error = VI_SUCCESS;

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
            2, "Instance");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "i%ld", instance);

Error:
    return error;
}

/*****************************************************************************
 * Function: rscmwins_QueryMeasStatus
 * Purpose:  This function queries measurement status
 *****************************************************************************/
ViStatus _VI_FUNC rscmwins_QueryMeasStatus(ViSession instrSession,
                                           ViString  cmd,
                                           ViInt32*  mainState,
                                           ViInt32*  syncState,
                                           ViInt32*  resourcesState)
{
    ViStatus error = VI_SUCCESS;
    ViChar   response [RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar*  p2buf;
    ViString mainStateArr[] = {"OFF", "RDY", "RUN",NULL};
    ViString syncStateArr[] = {"PEND", "ADJ", "INV",NULL};
    ViString resStateArr[] = {"QUE", "ACT", "INV",NULL};

    checkErr(RsCore_QueryViString(instrSession, cmd, response));

    p2buf = strtok(response, ",");
    if (p2buf == NULL)
        return RSCMWINS_ERROR_INCORRECT_STATE;
    *mainState = RsCore_FindStringIndex(mainStateArr, p2buf);
    if (*mainState < 0)
        return RSCMWINS_ERROR_INCORRECT_STATE;

    p2buf = strtok(NULL, ",");
    if (p2buf == NULL)
        return RSCMWINS_ERROR_INCORRECT_STATE;
    *syncState = RsCore_FindStringIndex(syncStateArr, p2buf);
    if (*syncState < 0)
        return RSCMWINS_ERROR_INCORRECT_STATE;

    p2buf = strtok(NULL, ",\n");
    if (p2buf == NULL)
        return RSCMWINS_ERROR_INCORRECT_STATE;
    *resourcesState = RsCore_FindStringIndex(resStateArr, p2buf);
    if (*resourcesState < 0)
        return RSCMWINS_ERROR_INCORRECT_STATE;

Error:
    return error;
}

/*****************************************************************************
 * Function: rscmwins_GetMeas
 * Purpose:  This function queries measurement data
 *****************************************************************************/
ViStatus _VI_FUNC rscmwins_GetMeas(ViSession instrSession,
                                   ViString  cmd,
                                   ViInt32   timeout,
                                   ViInt32   arraySize,
                                   ViInt32*  reliability,
                                   ViReal64  result[],
                                   ViInt32*  returnedValues)
{
    ViStatus error = VI_SUCCESS;
    ViChar*  ext_buf = NULL;
    ViChar*  p2buf;
    ViInt32  i = 0;

    if (timeout == 0)
    {
        checkErr(RsCore_QueryViStringUnknownLength(instrSession, cmd, &ext_buf));
    }
    else
    {
        checkErr(RsCore_QueryViStringUnknownLengthWithOpc(instrSession, cmd, timeout, &ext_buf));
    }

    checkErr(rscmwins_CheckStatus(instrSession));

    p2buf = strtok(ext_buf, ",");
    if (p2buf == NULL)
        return RSCMWINS_ERROR_INCORRECT_RESPONSE;
    if (reliability != NULL)
        *reliability = atol(p2buf);

    p2buf = strtok(NULL, ",\n");
    while (p2buf != NULL)
    {
        if (i < arraySize)
        {
            result[i++] = RsCore_Convert_String_To_ViReal64(p2buf);
        }
        p2buf = strtok(NULL, ",\n");
    }
    if (returnedValues) *returnedValues = i;

Error:
    if (ext_buf) free(ext_buf);
    return error;
}

/*****************************************************************************
 * Function: rscmwins_GetMeasTrace
 * Purpose:  This function queries measurement data trace
 *****************************************************************************/
ViStatus _VI_FUNC rscmwins_GetMeasTrace(ViSession instrSession,
                                        ViString  cmd,
                                        ViInt32   timeout,
                                        ViInt32   arraySize,
                                        ViInt32*  reliability,
                                        ViReal64  result[],
                                        ViInt32*  returnedValues)
{
    ViStatus error = VI_SUCCESS;
    ViChar*  ext_buf = NULL;
    ViChar*  p2buf;
    ViInt32  i = 0;

    checkErr(RsCore_QueryViStringUnknownLengthWithOpc(instrSession, cmd, timeout, &ext_buf));

    p2buf = strtok(ext_buf, ",");
    if (p2buf == NULL)
        return RSCMWINS_ERROR_INCORRECT_RESPONSE;
    if (reliability != NULL)
        *reliability = atol(p2buf);

    p2buf = strtok(NULL, ",\n");
    while (p2buf != NULL)
    {
        if (i < arraySize)
        {
            result[i++] = RsCore_Convert_String_To_ViReal64(p2buf);
        }
        p2buf = strtok(NULL, ",\n");
    }
    if (returnedValues) *returnedValues = i;

    checkErr(rscmwins_CheckStatus(instrSession));

Error:
    return error;
}

/*****************************************************************************
 * Function: rscmwins_GetSingleMeasInteger
 * Purpose:  This function queries measurement data
 *****************************************************************************/
ViStatus _VI_FUNC rscmwins_GetSingleMeasInteger(ViSession instrSession,
                                                ViString  cmd,
                                                ViInt32*  reliability,
                                                ViInt32*  result)
{  
    ViStatus error = VI_SUCCESS;
    ViChar*  ext_buf = NULL;
    ViChar*  p2buf;

    checkErr(RsCore_QueryViStringUnknownLength(instrSession, cmd, &ext_buf));

    p2buf = strtok(ext_buf, ",");
    if (p2buf == NULL)
        return RSCMWINS_ERROR_INCORRECT_RESPONSE;
    if (reliability != NULL)
        *reliability = atol(p2buf);

    p2buf = strtok(NULL, ",\n");
    *result = RsCore_Convert_String_To_ViInt32(p2buf);

    checkErr(rscmwins_CheckStatus(instrSession));

Error:
    return error;
}

/*****************************************************************************
 * Function: rscmwins_hex_ReadCallback
 * Purpose:  This function overrides standard calback funtion.
 *****************************************************************************/
ViStatus rscmwins_hex_ReadCallback(ViSession          instrSession,
                                   ViConstString      repCapName,
                                   RsCoreAttributePtr attr)
{
    ViStatus error = VI_SUCCESS;
    ViChar*  cmd = NULL;
    ViChar   responseFixed[RS_MAX_MESSAGE_BUF_SIZE] = "";

    // If no command available, exit the function
    if (isNullOrEmpty(attr->command))
        goto Error;

    // Command string building from repeated capabilities
    checkErr(RsCore_BuildAttrCommandString(instrSession, attr, repCapName, &cmd));

    if (attr->access != RS_VAL_READ_ONLY)
        RsCore_StrCatDynamicString(instrSession, &cmd, "?", NULL, NULL);

    checkErr(RsCore_QueryAttributeCommand(instrSession, attr, cmd, responseFixed));

    // In simulation, end here. Do not touch the cache value.
    // It is read by the GetAttribute and returned to the caller.
    if (RsCore_Simulating(instrSession))
        goto Error;

    // No range table, covert the response directly to the appropriate type
    switch (attr->dataType)
    {
    case RS_VAL_INT32:
        (void)sscanf (responseFixed, "#H%X", (ViInt32*)attr->p2value); //*((ViInt32*)
        break;
    default:
        checkErr(RsCore_GenerateInvalidDataTypeError(instrSession, attr->dataType, NULL));
    }

Error:
    if (cmd)
        free(cmd);

    return error;
}

/*****************************************************************************
 * Function: rscmwins_hex_WriteCallback
 * Purpose:  This function overrides standard calback funtion.
 *****************************************************************************/
ViStatus rscmwins_hex_WriteCallback(ViSession          instrSession,
                                    ViConstString      repCapName,
                                    RsCoreAttributePtr attr,
                                    void*              value)
{
    ViStatus error = VI_SUCCESS;
    ViChar   *cmd = NULL;
    ViChar   *pbuf = NULL;

    // Build the command string
    checkErr(RsCore_BuildAttrCommandString(instrSession, attr, repCapName, &cmd));
    pbuf = (ViChar*) malloc (strlen (cmd) + strlen ((ViString) value) + 2);
    switch (attr -> dataType)
    {
        case RS_VAL_INT32:
            sprintf(pbuf, "%s #H%X", cmd, *(ViInt32 *)value);
            checkErr(RsCore_WriteAttributeCommand(instrSession, attr, pbuf));
            break;
        default:
            checkErr(RsCore_GenerateInvalidDataTypeError(instrSession, attr->dataType, NULL));
    }

Error:
    if (pbuf) free (pbuf);
    if (cmd) free (cmd);

    return error;
}

ViStatus rscmwins_binPatternToInt32_ReadCallback(ViSession          instrSession,
                                                 ViConstString      repCapName,
                                                 RsCoreAttributePtr attr)
{
    return rscmwins_bin_ReadCallback(instrSession, repCapName, attr);
}

/*****************************************************************************
 * Function: rscmwins_bin_ReadCallback
 * Purpose:  This function overrides standard calback funtion.
 *****************************************************************************/
ViStatus rscmwins_bin_ReadCallback(ViSession          instrSession,
                                   ViConstString      repCapName,
                                   RsCoreAttributePtr attr)
{
    ViStatus error = VI_SUCCESS;
    ViInt32  isBin = 0;
    ViString cmd = NULL;
    ViChar   responseFixed[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar   buffer[RS_MAX_MESSAGE_BUF_SIZE];
    ViInt32  buffLen = 0;
    ViUInt64 value = 0;
    ViInt32  value32 = 0;
    ViInt64  value64 = 0;

    // If no command available, exit the function
    if (isNullOrEmpty(attr->command))
        goto Error;

    if (attr->dataType != RS_VAL_INT32 && attr->dataType != RS_VAL_INT64)
    {
        checkErr(RsCore_GenerateInvalidDataTypeError(instrSession, attr->dataType, "rscmwins_bin_ReadCallback only accepts type RS_VAL_INT32 or RS_VAL_INT64"));
    }

    // Command string building from repeated capabilities
    checkErr(RsCore_BuildAttrCommandString(instrSession, attr, repCapName, &cmd));
    checkErr(RsCore_QueryAttributeCommand(instrSession, attr, cmd, responseFixed));

    // In simulation, end here. Do not touch the cache value.
    // It is read by the GetAttribute and returned to the caller.
    if (RsCore_Simulating(instrSession))
        goto Error;

    isBin = sscanf(responseFixed, "#B%[01]", buffer);
    if (isBin == 1)
    {
        buffLen = (ViInt32)strlen(buffer);
        for (ViInt32 i = 0; i < buffLen; i++)
        {
            value = value | ((buffer[buffLen - i - 1] == '1') << i);
        }
        switch (attr->dataType)
        {
        case RS_VAL_INT32:
            value32 = (ViInt32)value;
            checkErr(RsCore_SetAttributeP2Value(instrSession, attr, &value32));
            break;
        case RS_VAL_INT64:
            value64 = (ViInt64)value;
            checkErr(RsCore_SetAttributeP2Value(instrSession, attr, &value64));
            break;
        default:
            break;
        }
    }
    else
    {
        checkErr(RS_ERROR_UNEXPECTED_RESPONSE);
    }

Error:
    if (cmd)
        free(cmd);

    return error;
}

/*****************************************************************************
 * Function: rscmwins_bin_WriteCallback
 * Purpose:  This function overrides standard calback funtion.
 *****************************************************************************/
#define BYTE_TO_BINARY_PATTERN_10CHARS "%c%c%c%c%c%c%c%c%c%c"
#define BYTE_TO_BINARY_10CHARS(val)  \
  (val & 0x00000200 ? '1' : '0'), \
  (val & 0x00000100 ? '1' : '0'), \
  (val & 0x00000080 ? '1' : '0'), \
  (val & 0x00000040 ? '1' : '0'), \
  (val & 0x00000020 ? '1' : '0'), \
  (val & 0x00000010 ? '1' : '0'), \
  (val & 0x00000008 ? '1' : '0'), \
  (val & 0x00000004 ? '1' : '0'), \
  (val & 0x00000002 ? '1' : '0'), \
  (val & 0x00000001 ? '1' : '0')
ViStatus rscmwins_bin_WriteCallback(ViSession          instrSession,
                                    ViConstString      repCapName,
                                    RsCoreAttributePtr attr,
                                    void*              value)
{
    ViStatus error = VI_SUCCESS;
    ViChar*  cmd = NULL;

    // If no command is available, exit the function
    if (isNullOrEmpty(attr->command))
        goto Error;

    checkErr(RsCore_BuildAttrCommandString(instrSession, attr, repCapName, &cmd));

    if (attr->rangeTableCallback)
    {
        checkErr((attr->rangeTableCallback)(instrSession, repCapName, attr, &(attr->rangeTable)));
    }

    if ((attr->rangeTable) && (attr->rangeTable->type == RS_VAL_DISCRETE))
    {
        ViChar* p2cmdString = NULL;

        // Allowed data types are only ViInt32 or ViInt64
        switch (attr->dataType)
        {
        case RS_VAL_INT32:
            checkErr(RsCore_FindRangeTableCmdString(instrSession, attr->rangeTable, *(ViInt32*)value, &p2cmdString));
            break;
        default:
            checkErr(RsCore_GenerateInvalidDataTypeError(instrSession, attr->dataType, NULL));
        }

        RsCore_StrCatDynamicString(instrSession, &cmd, " #B", p2cmdString, NULL);
    }
    else
    {
        // No range table, cmdString is composed based on the data type
        const int lenValueString = 13; // Allow 64 bit values plus 3 bytes
        ViChar valueString[13] = "";
        switch (attr->dataType)
        {
        case RS_VAL_INT32:
            snprintf(valueString, lenValueString, "#B"BYTE_TO_BINARY_PATTERN_10CHARS, BYTE_TO_BINARY_10CHARS(*(ViInt32*)value));
            break;
        default:
            checkErr(RsCore_GenerateInvalidDataTypeError(instrSession, attr->dataType, NULL));
        }

        RsCore_StrCatDynamicString(instrSession, &cmd, " ", valueString, NULL);
    }

    checkErr(RsCore_WriteAttributeCommand(instrSession, attr, cmd));

Error:
    if (cmd)
        free(cmd);

    return error;
}

ViStatus rscmwins_Int32ToBinPattern_WriteCallback(ViSession          instrSession,
                                                  ViConstString      repCapName,
                                                  RsCoreAttributePtr attr,
                                                  void*              value)
{
    return rscmwins_bin_WriteCallback(instrSession, repCapName, attr, value);
}
